<!DOCTYPE xsl:stylesheet  [
<!ENTITY ndash "&#8211;">
]>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:m1="http://www.sec.gov/edgar/rega/oneafiler"
	xmlns:ns1="http://www.sec.gov/edgar/common" xmlns:n1="http://www.sec.gov/edgar/common_drp"
	xmlns:ns2="http://www.sec.gov/edgar/statecodes" xmlns:ns3="http://www.sec.gov/edgar/regacommon">

	<!-- Item 1 templates -->
	<xsl:template name="Item1">
		<xsl:for-each select="m1:employeesInfo">
			<h3>
				<em>Issuer Infomation </em>
			</h3>
			<xsl:call-template name="EmployeesInfo" />
		</xsl:for-each>
		<h3>
			<em>Contact Infomation </em>
		</h3>
		<xsl:call-template name="IssuerContactInfo" />

		<h3>
			<em>Financial Statements </em>
		</h3>
		<xsl:call-template name="IssuerFinancialStatements" />
        
        <xsl:if test="(count(m1:commonEquity) or count(m1:preferredEquity) or count(m1:debtSecurities)) &gt; 0">
		<h3>
			<em>Outstanding Securities </em>
		</h3>
		<xsl:call-template name="OutstandingSecurities" />
        </xsl:if>
	</xsl:template>


	<xsl:template name="EmployeesInfo">

		<table role="presentation" >
			<tr>
				<td class="label">Exact name of issuer as specified in the issuer's
					charter
				</td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="m1:issuerName" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Jurisdiction of Incorporation / Organization </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:call-template name="stateDescription">
								<xsl:with-param name="stateCode"
									select="(./m1:jurisdictionOrganization)" />
							</xsl:call-template>
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Year of Incorporation </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="m1:yearIncorporation" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">CIK </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="m1:cik" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Primary Standard Industrial Classification Code </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:call-template name="sicDescription">
								<xsl:with-param name="sicCode" select="(./m1:sicCode)" />
							</xsl:call-template>
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">I.R.S. Employer Identification Number  </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="m1:irsNum" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total number of full-time employees  </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="m1:fullTimeEmployees" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total number of part-time employees  </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="m1:partTimeEmployees" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="IssuerContactInfo">
		<table role="presentation" >
			<tr>
				<h4>
					<em>Address of Principal Executive Offices</em>
				</h4>
			</tr>
			<tr>
				<td class="label">Address 1 </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:street1)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Address 2 </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:street2)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">City </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:city)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">State/Country   </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:call-template name="stateDescription">
								<xsl:with-param name="stateCode"
									select="string(./m1:issuerInfo/m1:stateOrCountry)" />
							</xsl:call-template>
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Mailing Zip/ Postal Code  </td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="string(m1:issuerInfo/m1:zipCode)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Phone</td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="string(m1:issuerInfo/m1:phoneNumber)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
		</table>
		<table role="presentation" >
			<tr>
				<h4>Provide the following information for the person the
					Securities
					and Exchange Commission's staff should call in
					connection with any
					pre-qualification review of the offering
					statement.
				</h4>
			</tr>
			<tr>
				<td class="label">Name </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:connectionName)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Address 1 </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:connectionStreet1)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Address 2 </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:connectionStreet2)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">City </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:value-of select="string(m1:issuerInfo/m1:connectionCity)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">State/Country </td>
				<td>
					<p>
						<div class="fakeBox">
							<xsl:call-template name="stateDescription">
								<xsl:with-param name="stateCode"
									select="string(./m1:issuerInfo/m1:connectionStateOrCountry)" />
							</xsl:call-template>
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Mailing Zip/ Postal Code</td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="string(m1:issuerInfo/m1:connectionZipCode)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Phone</td>
				<td>
					<p>
						<div align="left">
							<div class="fakeBox2">
								<xsl:value-of select="string(m1:issuerInfo/m1:connectionPhoneNumber)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
		</table>


		<table role="presentation" >
			<tr>
				<h4>Provide up to two e-mail addresses to which
					the
					Securities and
					Exchange Commission's staff may send any comment
					letters relating to
					the offering statement. After qualification of
					the offering
					statement, such e-mail addresses are not required to
					remain active.
				</h4>
			</tr>
			<xsl:for-each select="m1:issuerInfo/m1:commentsEmailAddress">
				<tr>
					<td class="label">Email Address</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="." />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
			</xsl:for-each>
		</table>

	</xsl:template>

	<xsl:template name="IssuerFinancialStatements">
		<table role="presentation" >
			<tr>
				<h4>
					Use the financial statements for the most recent period
					contained in
					this offering statement to provide the following
					information about
					the issuer. The following table does not include
					all of the line
					items from the financial statements. Long Term Debt
					would include
					notes payable, bonds, mortgages, and similar
					obligations. To
					determine "Total Revenues" for all companies
					selecting "Other" for
					their industry group, refer to Article
					5-03(b)(1) of Regulation
					S-X. For companies selecting "Insurance",
					refer to Article 7-04 of
					Regulation S-X for calculation of "Total
					Revenues" and paragraphs 5
					and 7 of Article 7-04 for "Costs and
					Expenses Applicable to
					Revenues".
				</h4>
		    </tr>
			<tr>
				<td class="label">
					Industry Group (select one)
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when test="count(m1:issuerInfo/m1:industryGroup) &gt; 0">
								<xsl:choose>
									<xsl:when test="string(m1:issuerInfo/m1:industryGroup) = 'Banking'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Banking
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Insurance
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Other
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:issuerInfo/m1:industryGroup) = 'Insurance'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Banking
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Insurance
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Other
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="string(m1:issuerInfo/m1:industryGroup) = 'Other'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Banking
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Insurance
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Other
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Banking
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Insurance
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Other
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>			
		</table>
		<table role="presentation" >
			<tr>
				<h4>
					<em>Balance Sheet Information</em>
				</h4>
			</tr>
			<tr>
				<td class="label">Cash and Cash Equivalents</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:cashEquivalents)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Investment Securities</td>
				<td>
					<div align="left">
						<div class="fakeBox2">
							$
							<xsl:value-of select="string(m1:issuerInfo/m1:investmentSecurities)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">Total Investments</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalInvestments)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Accounts and Notes Receivable</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:accountsReceivable)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Loans</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:loans)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Property, Plant and Equipment (PP&amp;E):</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:propertyPlantEquipment)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Property and Equipment</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:propertyAndEquipment)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Assets</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalAssets)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Accounts Payable and Accrued Liabilities</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:accountsPayable)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Policy Liabilities and Accruals</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of
									select="string(m1:issuerInfo/m1:policyLiabilitiesAndAccruals)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Deposits</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:deposits)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Long Term Debt</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:longTermDebt)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Liabilities</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalLiabilities)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Stockholders' Equity</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalStockholderEquity)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Liabilities and Equity</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of
									select="string(m1:issuerInfo/m1:totalLiabilitiesAndEquity)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
		</table>
		<table role="presentation" >
			<tr>
				<h4>
					<em>Statement of Comprehensive Income Information</em>
				</h4>
			</tr>
			<tr>
				<td class="label">Total Revenues</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalRevenues)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Interest Income</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalInterestIncome)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Costs and Expenses Applicable to Revenues</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of
									select="string(m1:issuerInfo/m1:costAndExpensesApplToRevenues)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Total Interest Expenses</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:totalInterestExpenses)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Depreciation and Amortization</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of
									select="string(m1:issuerInfo/m1:depreciationAndAmortization)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Net Income</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:netIncome)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Earnings Per Share - Basic</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:earningsPerShareBasic)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
			<tr>
				<td class="label">Earnings Per Share - Diluted</td>
				<td>
					<p>
						<div align="left">

							<div class="fakeBox2">
								$
								<xsl:value-of select="string(m1:issuerInfo/m1:earningsPerShareDiluted)" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>

						</div>
					</p>
				</td>
			</tr>
		</table>
		<table role="presentation" >
			<tr>
				<td class="label">Name of Auditor (if any)</td>
				<td>
					<p>
						<div class="fakeBox3">
							<xsl:value-of select="string(m1:issuerInfo/m1:nameAuditor)" />
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</div>
					</p>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="OutstandingSecurities">
		<xsl:for-each select="m1:commonEquity">
			<table role="presentation" >
				<tr>
					<h4>
						<em>Common Equity</em>
					</h4>
				</tr>
				<tr>
					<td class="label">Name of Class (if any) Common Equity 
					</td>

					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:commonEquityClassName" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Common Equity Units Outstanding
					</td>

					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:outstandingCommonEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Common Equity CUSIP (if any):
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:commonCusipEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Common Equity Units Name of Trading Center or Quotation Medium (if any)
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:publiclyTradedCommonEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
			</table>
		</xsl:for-each>

		<xsl:for-each select="m1:preferredEquity">
			<table role="presentation" >
				<h4>
					<em>Preferred Equity</em>
				</h4>
				<tr>
					<td class="label">Preferred Equity Name of Class (if any)
					</td>

					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:preferredEquityClassName" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Preferred Equity Units Outstanding
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:outstandingPreferredEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Preferred Equity CUSIP (if any)
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:preferredCusipEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Preferred Equity Name of Trading Center or Quotation Medium (if any)
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:publiclyTradedPreferredEquity" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
			</table>
		</xsl:for-each>

		<xsl:for-each select="m1:debtSecurities">
			<table role="presentation" >
				<h4>
					<em>Debt Securities</em>
				</h4>
				<tr>
					<td class="label">Debt Securities Name of Class (if any)
					</td>

					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:debtSecuritiesClassName" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Debt Securities Units Outstanding
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:outstandingDebtSecurities" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Debt Securities CUSIP (if any):
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:cusipDebtSecurities" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
				<tr>
					<td class="label">Debt Securities Name of Trading Center or Quotation Medium (if any)
					</td>
					<td>
						<p>
							<div class="fakeBox">
								<xsl:value-of select="m1:publiclyTradedDebtSecurities" />
								<span>
									<xsl:text>&#160;</xsl:text>
								</span>
							</div>
						</p>
					</td>
				</tr>
			</table>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>