<!DOCTYPE xsl:stylesheet  [
<!ENTITY ndash "&#8211;">
]>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:m1="http://www.sec.gov/edgar/rega/oneafiler"
	xmlns:ns1="http://www.sec.gov/edgar/common" xmlns:n1="http://www.sec.gov/edgar/common_drp"
	xmlns:ns2="http://www.sec.gov/edgar/statecodes" xmlns:ns3="http://www.sec.gov/edgar/regacommon">

	<!-- Item 4 templates -->

	<xsl:template name="Item4">
		<h3>
			<em>Summary Infomation </em>
		</h3>
		<xsl:call-template name="SummaryInfo" />
		<h4>
			The information called for by this item below may be omitted if
			undetermined at the time of filing or submission, except that if a
			price range has been included in the offering statement, the midpoint
			of that range must be used to respond. Please refer to Rule 251(a)
			for the definition of "aggregate offering price" or "aggregate sales"
			as used in this item. Please leave the field blank if undetermined at
			this time and include a zero if a particular item is not applicable
			to the offering.

		</h4>
		<xsl:call-template name="PriceSecurity" />
		<h4>
			<em>Anticipated fees in connection with this offering and names of
				service providers
			</em>
		</h4>
		<xsl:call-template name="AnticipatedFees" />
	</xsl:template>

	<xsl:template name="SummaryInfo">
		<table role="presentation" >
			<tr>
				<td class="label">
					Check the appropriate box to indicate whether you are
					conducting
					a Tier 1 or Tier 2 offering
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:indicateTier1Tier2Offering) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:indicateTier1Tier2Offering) = 'Tier1'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Tier1
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Tier2
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:indicateTier1Tier2Offering) = 'Tier2'">
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Tier1
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Tier2
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Tier1
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Tier2
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Check the appropriate box to indicate whether the
					financial statements
					have been audited
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:financialStatementAuditStatus) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:financialStatementAuditStatus) = 'Unaudited'">
										<img src="/Images/radio-checked.jpg"
											alt="Radio button checked" />
										Unaudited
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Audited
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:financialStatementAuditStatus) = 'Audited'">
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Unaudited
										<img src="/Images/radio-checked.jpg"
											alt="Radio button checked" />
										Audited
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg"
									alt="Radio button not checked" />
								Unaudited
								<img src="/Images/radio-unchecked.jpg"
									alt="Radio button not checked" />
								Audited
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
		</table>
		<table role="presentation" >
			<tr>
				<td class="label">
					Types of Securities Offered in this Offering Statement
					(select
					all that apply)
				</td>
			</tr>
		</table>
		<xsl:for-each select="m1:summaryInfo/m1:securitiesOfferedTypes">
			<table role="presentation" >
				<tr>
					<td>
						<img src="/Images/box-checked.jpg" alt="Checkbox checked" />
						<xsl:value-of select="." />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</td>
				</tr>
			</table>
		</xsl:for-each>

		<xsl:for-each
			select="m1:summaryInfo[m1:securitiesOfferedTypes='Other(describe)']">
			<table role="presentation" >
				<tr>
					<td>Provide a description</td>
					<td>
						<p>
							<div class="fakeBox3">
								<xsl:value-of select="(m1:securitiesOfferedOtherDesc)" />
							</div>
							<span>
								<xsl:text>&#160;</xsl:text>
							</span>
						</p>
					</td>
				</tr>
			</table>
		</xsl:for-each>

		<table role="presentation"  class="formTable">
			<tr>
				<td class="label">
					Does the issuer intend to offer the securities on a
					delayed or continuous basis pursuant to Rule 251(d)(3)?
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:offerDelayedContinuousFlag) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offerDelayedContinuousFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offerDelayedContinuousFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Does the issuer intend this offering to last more than
					one year?
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when test="count(m1:summaryInfo/m1:offeringYearFlag) &gt; 0">
								<xsl:choose>
									<xsl:when test="string(m1:summaryInfo/m1:offeringYearFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="string(m1:summaryInfo/m1:offeringYearFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Does the issuer intend to price this offering after
					qualification
					pursuant to Rule 253(b)?
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:offeringAfterQualifFlag) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offeringAfterQualifFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offeringAfterQualifFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Will the issuer be conducting a best efforts offering?
				</td>

				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:offeringBestEffortsFlag) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offeringBestEffortsFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:offeringBestEffortsFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Has the issuer used solicitation of interest
					communications in
					connection with the proposed offering?
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:solicitationProposedOfferingFlag) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:solicitationProposedOfferingFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:solicitationProposedOfferingFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg"
											alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg"
									alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg"
									alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">
					Does the proposed offering involve the resale of
					securities by
					affiliates of the issuer?
				</td>
				<td>
					<span class="yesNo">
						<xsl:choose>
							<xsl:when
								test="count(m1:summaryInfo/m1:resaleSecuritiesAffiliatesFlag) &gt; 0">
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:resaleSecuritiesAffiliatesFlag) = 'Y'">
										<img src="/Images/radio-checked.jpg" alt="Radio button checked" />
										Yes
										<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
										No
									</xsl:when>
								</xsl:choose>
								<xsl:choose>
									<xsl:when
										test="string(m1:summaryInfo/m1:resaleSecuritiesAffiliatesFlag) = 'N'">
										<img src="/Images/radio-unchecked.jpg"
											alt="Radio button not checked" />
										Yes
										<img src="/Images/radio-checked.jpg"
											alt="Radio button checked" />
										No
									</xsl:when>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								Yes
								<img src="/Images/radio-unchecked.jpg" alt="Radio button not checked" />
								No
							</xsl:otherwise>
						</xsl:choose>
					</span>
				</td>
			</tr>
			<tr>
				<td class="label">Number of securities offered
				</td>
				<td>
					<div class="fakeBox2">
						<xsl:value-of select="string(m1:summaryInfo/m1:securitiesOffered)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>
				</td>
			</tr>
			<tr>
				<td class="label">Number of securities of that class outstanding
				</td>
				<td>
					<div class="fakeBox2">
						<xsl:value-of select="string(m1:summaryInfo/m1:outstandingSecurities)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="PriceSecurity">
		<table role="presentation" >
			<tr>
				<td class="label">Price per security
				</td>
				<td>
					<div class="fakeBox2" align="left">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:pricePerSecurity)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">The portion of the aggregate offering price
					attributable to securities being offered on behalf of the issuer
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:issuerAggregateOffering)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">The portion of the aggregate offering price
					attributable to securities being offered on behalf of selling
					securityholders
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:securityHolderAggegate)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">The portion of the aggregate offering price
					attributable to all the securities of the issuer sold pursuant to a
					qualified offering statement within the 12 months before the
					qualification of this offering statement
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of
							select="string(m1:summaryInfo/m1:qualificationOfferingAggregate)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">The estimated portion of aggregate sales attributable
					to securities that may be sold pursuant to any other qualified
					offering statement concurrently with securities being sold under
					this offering statement
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of
							select="string(m1:summaryInfo/m1:concurrentOfferingAggregate)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">Total (the sum of the aggregate offering price and
					aggregate sales in the four preceding paragraphs)
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:totalAggregateOffering)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="AnticipatedFees">
		<table role="presentation" >
			<tr>
				<td class="label">Underwriters - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:underwritersServiceProviderName)" />
					</div>
				</td>

				<td class="label">Underwriters - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:underwritersFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>

			<tr>
				<td class="label">Sales Commissions - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:salesCommissionsServiceProviderName)" />
					</div>
				</td>

				<td class="label">Sales Commissions - Fee
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of
							select="string(m1:summaryInfo/m1:salesCommissionsServiceProviderFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>

			<tr>
				<td class="label">Finders' Fees - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:findersFeesServiceProviderName)" />
					</div>
				</td>

				<td class="label">Finders' Fees - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:finderFeesFee)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>

			<tr>
				<td class="label">Accounting or Audit  - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:auditorServiceProviderName)" />
					</div>
				</td>

				<td class="label">Accounting or Audit  - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:auditorFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>

			<tr>
				<td class="label">Legal - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of select="string(m1:summaryInfo/m1:legalServiceProviderName)" />
					</div>
				</td>

				<td class="label">Legal - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:legalFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>

			<tr>
				<td class="label">Promoters - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:promotersServiceProviderName)" />
					</div>
				</td>

				<td class="label">Promoters - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:promotersFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>
				</td>
			</tr>

			<tr>
				<td class="label">Blue Sky Compliance - Name of Service Provider
				</td>
				<td>
					<div class="fakeBox4">
						<xsl:value-of
							select="string(m1:summaryInfo/m1:blueSkyServiceProviderName)" />
					</div>
				</td>

				<td class="label">Blue Sky Compliance - Fees
				</td>
				<td>
					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:blueSkyFees)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>

				</td>
			</tr>
			<tr>
				<td class="label">CRD Number of any broker or dealer listed:
				</td>
				<td>
					<div class="fakeBox">
						<xsl:value-of select="string(m1:summaryInfo/m1:brokerDealerCrdNumber)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>
				</td>
			</tr>
		</table>
		<table role="presentation" >
			<tr>
				<td class="label">Estimated net proceeds to the issuer
				</td>
				<td>

					<div class="fakeBox2">
						$
						<xsl:value-of select="string(m1:summaryInfo/m1:estimatedNetAmount)" />
						<span>
							<xsl:text>&#160;</xsl:text>
						</span>
					</div>
				</td>
			</tr>

			<tr>
				<td class="label">Clarification of responses (if necessary)
				</td>
				<td>
					<div class="fakeBox3">
						<xsl:value-of select="string(m1:summaryInfo/m1:clarificationResponses)" />
					</div>
					<span>
						<xsl:text>&#160;</xsl:text>
					</span>

				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>