<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:n1="http://www.sec.gov/edgar/thirteenffiler" 
xmlns:n2="http://www.sec.gov/edgar/document/thirteenf/informationtable" 
xmlns:ns1="http://www.sec.gov/edgar/common" >
<!--
   XSL Stylesheet for Form 13F Sections
   Version 1.0.0.2 - Dated May 2013
   Created By: SAIC 
   Created for: SEC
   -->
   
   <xsl:template name="Form13Fsections">
     <xsl:call-template name="CalendarEnd"/>
     <xsl:call-template name="AmendmentInfo"/>
     <xsl:call-template name="FilingManager"/>
     <xsl:call-template name="SigningManager"/>
     <xsl:call-template name="ReportType"/>
     <xsl:call-template name="OtherManagers"/>
    </xsl:template>
   
   <xsl:template name="CalendarEnd">
     <table border="0" summary="Calendar Year or Quarter End">
         <tbody>
            <tr>
               <td class="FormText">Report for the Calendar Year or Quarter Ended:</td>
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:reportCalendarOrQuarter" mode="NormalTDR"/>
            </tr>
         </tbody>
      </table>
   </xsl:template>
   
   <xsl:template name="AmendmentInfo">
         <table border="0" summary="Amendment Information">
            <tbody>
               <tr>
                  <xsl:call-template name="BuildSoloRadioTD">
                     <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:isAmendment" />
                     <xsl:with-param name="LeftLabel" select="'Check here if Amendment'" />
                  </xsl:call-template>
                  <td class="FormText">Amendment Number:</td>
                  <xsl:apply-templates select="n1:formData/n1:coverPage/n1:amendmentNo" mode="NormalTDR"/>
               </tr>
               <tr>
               <td class="FormText">This Amendment (Check only one.):</td>
               <xsl:call-template name="BuildSoloRadioTD">
                  <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:amendmentInfo/n1:amendmentType = 'RESTATEMENT'" />
                  <xsl:with-param name="Label" select="'is a restatement.'" />
               </xsl:call-template>
               </tr>
               <tr><td></td>
                <xsl:call-template name="BuildSoloRadioTD">
                  <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:amendmentInfo/n1:amendmentType = 'NEW HOLDINGS'" />
                  <xsl:with-param name="Label" select="'adds new holdings entries.'" />
               </xsl:call-template>
               </tr>
             </tbody>
          </table>
   </xsl:template>
   
   <xsl:template name="FilingManager">
     <table border="0" summary="Filing Manager Information" width="50%">
         <tbody>
            <tr>
               <td colspan="2" class="FormTitle3">Institutional Investment Manager Filing this Report:</td>
            </tr>
            <tr>
               <td width="30%" class="FormText">Name:</td>
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:name" mode="NormalTDL"/>
            </tr>
            <tr>
               <td width="30%" class="FormText">Address:</td>
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:address/ns1:street1" mode="NormalTDL"/>
            </tr>
            <tr>
               <td></td>
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:address/ns1:street2" mode="NormalTDL"/>
            </tr>
            <tr>
               <td></td>
               <td>
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:address/ns1:city" mode="Normal"/>, 
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:address/ns1:stateOrCountry" mode="Normal"/>&#160;
               <xsl:apply-templates select="n1:formData/n1:coverPage/n1:filingManager/n1:address/ns1:zipCode" mode="NormalZip"/>
               </td>
             </tr>
             <tr>
                <td width="30%" class="FormText">Form 13F File Number:</td>
                <xsl:apply-templates select="n1:formData/n1:coverPage/n1:form13FFileNumber" mode="NormalTDL"/>
             </tr>
         </tbody>
      </table>
   </xsl:template>
   
   <xsl:template name="SigningManager">
      <p class="FormTitle3">The institutional investment manager filing this report and the person by whom it is signed hereby represent that the person signing the report is authorized to submit it, that all information contained herein is true, correct and complete, and that it is understood that all required items, statements, schedules, lists, and tables, are considered integral parts of this form.</p>
      <table width="50%" border="0" summary="Signature Block Information">
         <tbody>
            <tr>
               <td colspan="5" class="FormText">Person Signing this Report on Behalf of Reporting Manager:</td>
            </tr>
             <tr>
               <td width="30%" colspan="2" class="FormText">Name:</td>
               <td colspan="3">
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:name" mode="Normal"/>
               </td>
            </tr>
            <tr>
               <td class="FormText" colspan="2">Title:</td>
               <td colspan="3">
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:title" mode="Normal"/>
               </td>
            </tr>
             <tr>
               <td class="FormText" colspan="2">Phone:</td>
               <td colspan="3">
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:phone" mode="NormalText"/>
               </td>
            </tr>
            <tr>
               <td colspan="5" class="FormTitle3">Signature, Place, and Date of Signing:</td>
            </tr>
            <tr>
               <td width="50%" colspan="3" class="FormData">
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:signature" mode="Normal"/>
               </td>
               <td class="FormData">
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:city" mode="Normal"/>,&#160;
                  <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:stateOrCountry" mode="Normal"/>
               </td>
               <xsl:apply-templates select="n1:formData/n1:signatureBlock/n1:signatureDate" mode="NormalTDL"/>
            </tr>
            <tr>
               <td colspan="3" class="FormTextC" align="center">[Signature]</td>
               <td class="FormTextC" align="center">[City, State]</td>
               <td class="FormTextC" align="center">[Date]</td>
            </tr>
            <tr>
               <td colspan="5" style="padding-top: 2em;">
                  <xsl:apply-templates select="n1:formData/n1:coverPage/n1:additionalInformation" mode="Normal"/>
               </td>
            </tr>
         </tbody>
       </table>
   </xsl:template>
   
  <xsl:template name="ReportType">
     <table border="0" summary="Report Type Information">
         <tbody>
            <tr>
               <td colspan="2" class="FormTitle3">Report Type (Check only one.):</td>
            </tr>
            <tr>
               <xsl:call-template name="BuildSoloRadioTD">
                  <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:reportType='13F HOLDINGS REPORT'" />
                  <xsl:with-param name="Label" select="'13F HOLDINGS REPORT. (Check here if all holdings of this reporting manager are reported in this report.)'" />
               </xsl:call-template>
            </tr>
            <tr>
               <xsl:call-template name="BuildSoloRadioTD">
                  <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:reportType='13F NOTICE'" />
                  <xsl:with-param name="Label" select="'13F NOTICE. (Check here if no holdings reported are in this report, and all holdings are reported by other reporting manager(s).)'" />
               </xsl:call-template>
            </tr>
            <tr>
               <xsl:call-template name="BuildSoloRadioTD">
                  <xsl:with-param name="TestThis" select="n1:formData/n1:coverPage/n1:reportType='13F COMBINATION REPORT'" />
                  <xsl:with-param name="Label" select="'13F COMBINATION REPORT. (Check here if a portion of the holdings for this reporting manager are reported in this report and a portion are reported by other reporting manager(s).)'" />
               </xsl:call-template>
            </tr>
         </tbody>
      </table>
   </xsl:template>
   
   <xsl:template name="OtherManagers">
     <xsl:if test="count(n1:formData/n1:coverPage/n1:otherManagersInfo/n1:otherManager)&gt;0">
     <table width="100%" border="0" summary="Other Managers Information">
         <tbody>
            <tr>
               <td colspan="4" class="FormTitle3">List of Other Managers Reporting for this Manager:<Br/>
                [If there are no entries in this list, omit this section.]</td>
            </tr>
            <tr>
               <td width="2%"></td>
               <td width="5%" class="FormText"></td>
<!--               <td>CIK</td>-->
               <td width="10%" class="FormText">Form 13F File Number</td>
               <td class="FormText">Name</td>
            </tr>
            <xsl:for-each select="n1:formData/n1:coverPage/n1:otherManagersInfo/n1:otherManager">
               <tr>
                  <td colspan="2"></td>
<!--                  <td>-->
<!--                     <xsl:call-template name="createCIKLink" >-->
<!--                        <xsl:with-param name="aCIK" select="n1:cik"></xsl:with-param>-->
<!--                        <xsl:with-param name="label" select="n1:cik"></xsl:with-param>-->
<!--                     </xsl:call-template>-->
<!--                  </td>-->
                  <xsl:choose>
                     <xsl:when test="string-length(n1:form13FFileNumber) &gt;0">
                        <xsl:apply-templates select="n1:form13FFileNumber" mode="NormalTDL" />
                     </xsl:when>
                     <xsl:otherwise><td>&#160;</td></xsl:otherwise>
                  </xsl:choose>
                  <xsl:apply-templates select="n1:name" mode="NormalTDL"/>
               </tr>
            </xsl:for-each>
         </tbody>
      </table>
      </xsl:if>
   </xsl:template>
   
   <xsl:template name="ReportSummary">
     <table width="100%" border="0" summary="Report Summary Information">
         <tbody>
            <tr>
               <td colspan="6" align="center" class="FormTitle">Form 13F Summary Page</td>
            </tr>
            <tr>
               <td width="1%"></td><td colspan="5" class="FormTitle3">Report Summary:</td>
            </tr>
            <tr>
               <td></td>
               <td width="30%" colspan="2" class="FormText">Number of Other Included Managers:</td>
               <td width="10%" align="right">
                  <xsl:apply-templates select="n1:formData/n1:summaryPage/n1:otherIncludedManagersCount" mode="Normal"/>
               </td>
               <td></td><td></td>
            </tr>
            <tr>
               <td></td>
               <td colspan="2" class="FormText">Form 13F Information Table Entry Total:</td>
               <td align="right">
                  <xsl:apply-templates select="n1:formData/n1:summaryPage/n1:tableEntryTotal" mode="Normal"/>
               </td>
            </tr>
            <tr>
               <td></td>
               <td colspan="2" class="FormText">Form 13F Information Table Value Total:</td>
               <td align="right">
                  <xsl:apply-templates select="n1:formData/n1:summaryPage/n1:tableValueTotal" mode="Normal"/>
               </td>
            </tr>
            <tr>
               <td colspan="3"></td><td class="FormTextC">(thousands)</td>
            </tr>
            <tr>
               <td colspan="6">
                 <xsl:if test="n1:formData/n1:summaryPage/n1:isConfidentialOmitted=1 or n1:formData/n1:summaryPage/n1:isConfidentialOmitted='true' or n1:formData/n1:summaryPage/n1:isConfidentialOmitted='1' or n1:formData/n1:summaryPage/n1:isConfidentialOmitted='YES'">
                 <div class="FormData">Confidential information has been omitted from the public Form 13F report and filed separately with the U.S. Securities and Exchange Commission.</div>
                 </xsl:if>
               </td>
            </tr>
         </tbody>
      </table>
      <table width="100%" border="0" summary="Report Summary Other Included Managers">
         <tbody>
            <tr>
               <td width="100%" colspan="4" class="FormTitle3">List of Other Included Managers:</td>
            </tr>
            <tr>
               <td colspan="4" class="FormText">Provide a numbered list of the name(s) and Form 13F file number(s) 
               of all institutional investment managers with respect to which this report is filed, other than the 
               manager filing this report.</td>
            </tr>
            <tr>
               <td colspan="4" class="FormText">[If there are no entries in this list, state “NONE” and omit the 
               column headings and list entries.]</td>
            </tr>
            <xsl:if test="count(n1:formData/n1:summaryPage/n1:otherManagers2Info/n1:otherManager2)=0">
               <tr><td class="FormText">NONE</td></tr>
            </xsl:if>
            <xsl:if test="count(n1:formData/n1:summaryPage/n1:otherManagers2Info/n1:otherManager2)&gt;0">
               <tr>
                  <td width="2%"></td>
                  <td width="5%" class="FormText">No.</td>
<!--                  <td>CIK</td> -->
                  <td width="10%" class="FormText">Form 13F File Number</td>
                  <td class="FormText">Name</td>
               </tr>
               <xsl:for-each select="n1:formData/n1:summaryPage/n1:otherManagers2Info/n1:otherManager2">
                  <tr>
                     <td></td>
                     <xsl:apply-templates select="n1:sequenceNumber" mode="NormalTDL"/>
<!--                     <td>-->
<!--                        <xsl:call-template name="createCIKLink" >-->
<!--                           <xsl:with-param name="aCIK" select="n1:otherManager/n1:cik"></xsl:with-param>-->
<!--                           <xsl:with-param name="label" select="n1:otherManager/n1:cik"></xsl:with-param>-->
<!--                        </xsl:call-template>-->
<!--                     </td>-->
                      <xsl:choose>
                         <xsl:when test="string-length(n1:otherManager/n1:form13FFileNumber)&gt;0">
                            <xsl:apply-templates select="n1:otherManager/n1:form13FFileNumber" mode="NormalTDL" />
                         </xsl:when>
                         <xsl:otherwise><td>&#160;</td></xsl:otherwise>
                      </xsl:choose>
                     <xsl:apply-templates select="n1:otherManager/n1:name" mode="NormalTDL"/>
                  </tr>
               </xsl:for-each>
            </xsl:if>
         </tbody>
      </table>
   </xsl:template>
   
   <xsl:template name="Form13FInfoTable">
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="Form 13F-NT Header Information">
         <tbody>
            <tr>
               <td class="FormTextC">COLUMN 1</td>
               <td class="FormTextC">COLUMN 2</td>
               <td class="FormTextC">COLUMN 3</td>
               <td class="FormTextR">COLUMN 4</td>
               <td class="FormTextC" colspan="3">COLUMN 5</td>
               <td class="FormTextC">COLUMN 6</td>
               <td class="FormTextR">COLUMN 7</td>
               <td class="FormTextC" colspan="3">COLUMN 8</td>
            </tr>
            <tr>
               <td class="FormText"></td>
               <td class="FormText"></td>
               <td class="FormText"></td>
               <td class="FormTextR">VALUE</td>
               <td class="FormTextR">SHRS OR</td>
               <td class="FormText">SH/</td>
               <td class="FormText">PUT/</td>
               <td class="FormText">INVESTMENT</td>
               <td class="FormTextR">OTHER</td>
               <td class="FormTextC" colspan="3">VOTING AUTHORITY</td>
            </tr>
            <tr>
               <td class="FormText">NAME OF ISSUER</td>
               <td class="FormText">TITLE OF CLASS</td>
               <td class="FormText">CUSIP</td>
               <td class="FormTextR">(x$1000)</td>
               <td class="FormTextR">PRN AMT</td>
               <td class="FormText">PRN</td>
               <td class="FormText">CALL</td>
               <td class="FormText">DISCRETION</td>
               <td class="FormTextR">MANAGER</td>
               <td class="FormTextR">SOLE</td>
               <td class="FormTextR">SHARED</td>
               <td class="FormTextR">NONE</td>
            </tr>
            <xsl:apply-templates select="n2:infoTable"/>
         </tbody>
      </table>
   </xsl:template>
   
   <xsl:template match="n2:infoTable">
      <tr>
         <xsl:apply-templates select="n2:nameOfIssuer" mode="NormalTDL"/>
         <xsl:apply-templates select="n2:titleOfClass" mode="NormalTDL"/>
         <xsl:apply-templates select="n2:cusip" mode="NormalTDLZ"/>
         <xsl:apply-templates select="n2:value" mode="NormalTDR"/>
         <xsl:apply-templates select="n2:shrsOrPrnAmt/n2:sshPrnamt" mode="NormalTDR"/>
         <xsl:apply-templates select="n2:shrsOrPrnAmt/n2:sshPrnamtType" mode="NormalTDL"/>
         <xsl:choose>
            <xsl:when test="string-length(n2:putCall) &gt;0">
               <xsl:apply-templates select="n2:putCall" mode="NormalTDL" />
            </xsl:when>
            <xsl:otherwise><td>&#160;</td></xsl:otherwise>
         </xsl:choose>
         <xsl:apply-templates select="n2:investmentDiscretion" mode="NormalTDL"/>
         <xsl:choose>
            <xsl:when test="string-length(n2:otherManager) &gt;0">
               <xsl:apply-templates select="n2:otherManager" mode="NormalTDL" />
            </xsl:when>
            <xsl:otherwise><td>&#160;</td></xsl:otherwise>
         </xsl:choose>
         <xsl:apply-templates select="n2:votingAuthority/n2:Sole" mode="NormalTDR"/>
         <xsl:apply-templates select="n2:votingAuthority/n2:Shared" mode="NormalTDR"/>
         <xsl:apply-templates select="n2:votingAuthority/n2:None" mode="NormalTDR"/>
      </tr>
   </xsl:template>
   
   <xsl:template name="BuildCheckBoxTD">
      <xsl:param name="TestThis" />
      <xsl:param name="Label" />
      <xsl:param name="LeftLabel"/>
      <td>
         <xsl:call-template name="BuildCheckBox">
            <xsl:with-param name="TestThis" select="$TestThis" />
            <xsl:with-param name="Label" select="$Label" />
            <xsl:with-param name="LeftLabel" select="$LeftLabel" />
         </xsl:call-template>
      </td>
   </xsl:template>
   
   <xsl:template name="BuildCheckBoxTR">
      <xsl:param name="TestThis" />
      <xsl:param name="Label" />
      <xsl:param name="LeftLabel"/>
      <xsl:param name="AppendEmptyCell" select="true()"/>
      <tr>
         <xsl:if test="$AppendEmptyCell">
            <td> </td>
         </xsl:if>
         <xsl:call-template name="BuildCheckBoxTD">
            <xsl:with-param name="TestThis" select="$TestThis" />
            <xsl:with-param name="Label" select="$Label" />
            <xsl:with-param name="LeftLabel" select="$LeftLabel" />
         </xsl:call-template>
      </tr>
   </xsl:template>
   
   <xsl:template name="SA1-SA2-Label">
      <xsl:param name="colspan" />
      <xsl:if test="not($colspan='')">
         <tr>
            <xsl:element name="th">
               <xsl:attribute name="class">FormText</xsl:attribute>
               <xsl:attribute name="colspan"><xsl:value-of select="$colspan" /></xsl:attribute>Street Address 1</xsl:element>
            <xsl:element name="th">
               <xsl:attribute name="class">FormText</xsl:attribute>
               <xsl:attribute name="colspan"><xsl:value-of select="$colspan" /></xsl:attribute>Street Address 2</xsl:element>
         </tr>
      </xsl:if>
      <xsl:if test="$colspan=''">
         <tr>
            <th class="FormText">Street Address 1</th>
            <th class="FormText">Street Address 2</th>
         </tr>
      </xsl:if>
   </xsl:template>

   <xsl:template name="GetCityStateZip">
      <xsl:param name="Node" />
      <xsl:apply-templates select="$Node/city" mode="NormalTDL"/>
      <xsl:choose>
         <xsl:when test="count( $Node/stateOrCountryDescription ) &gt;0">
            <xsl:apply-templates select="$Node/stateOrCountryDescription" mode="NormalTDL"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:apply-templates select="$Node/stateOrCountry" mode="NormalTDL"/>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="$Node/zipCode" mode="NormalTDLZ"/>
   </xsl:template>
</xsl:stylesheet>
