<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xsi:schemaLocation="http://www.sec.gov/edgar/thirteenffiler eis_13F_Filer.xsd" 
xmlns:n2="http://www.sec.gov/edgar/document/thirteenf/informationtable" 
xmlns:n1="http://www.sec.gov/edgar/thirteenffiler" 
xmlns:ns1="http://www.sec.gov/edgar/common" 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

   <xsl:import href="SEC-Common.xsl"/>
   <xsl:import href="Form13F-Sections.xsl"/>
   <!--
   XSL Stylesheet for SEC Form 13F-HR and Form 13F-NT 
   Uses XSL Stylesheets:  Form13F-Sections.xsl, SEC-Common.xsl

   Version 1.0 - Dated May 2013
   Created By: SAIC 
   Created for: SEC
   -->
   <xsl:variable name="this" select="/"/>
   <xsl:output method="html" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" media-type="application/xml"/>
   <xsl:template match="/n1:edgarSubmission">
      <html>
         <head>
            <title>SEC FORM <xsl:value-of select="n1:headerData/n1:submissionType"/></title>
            <xsl:call-template name="CSS"/>
         </head>
         <body>
            <xsl:choose>
               <xsl:when test="(n1:headerData/n1:submissionType='13F-HR') or (n1:headerData/n1:submissionType='13F-HR/A')">
                  <xsl:call-template name="Form13F_HRHeader">
                     <xsl:with-param name="FormTitle">FORM 13F</xsl:with-param>
                     <xsl:with-param name="FormTitle1">FORM 13F COVER PAGE</xsl:with-param>
                  </xsl:call-template>
                  <xsl:call-template name="Form13Fsections"/>
                  <xsl:call-template name="ReportSummary"/>
               </xsl:when>
               <xsl:when test="(n1:headerData/n1:submissionType='13F-NT') or (n1:headerData/n1:submissionType='13F-NT/A')">
                  <xsl:call-template name="Form13F_NTHeader">
                     <xsl:with-param name="FormTitle">FORM 13F</xsl:with-param>
                     <xsl:with-param name="FormTitle1">FORM 13F COVER PAGE</xsl:with-param>
                  </xsl:call-template>
                  <xsl:call-template name="Form13Fsections"/>
               </xsl:when>
               <xsl:otherwise>NO HEADER FOUND MATCHING TYPE</xsl:otherwise>
            </xsl:choose>
            
            <hr/>
         </body>
      </html>
   </xsl:template>
   
   <xsl:template match="/n2:informationTable">
      <html>
         <head>
            <title>SEC FORM 13-F Information Table</title>
            <xsl:call-template name="CSS"/>
         </head>
         <body>
            <xsl:call-template name="Form13F_HRHeader">
               <xsl:with-param name="FormTitle">FORM 13F</xsl:with-param>
               <xsl:with-param name="FormTitle1">FORM 13F INFORMATION TABLE</xsl:with-param>
            </xsl:call-template>
            <xsl:call-template name="Form13FInfoTable"/>
         </body>
      </html>
   </xsl:template>

   <xsl:template name="Form13F_HRHeader">
      <xsl:param name="FormTitle" />
      <xsl:param name="FormTitle1" />
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="Form 13F-HR Header Information">
         <tr>
            <td colspan="4" style="border: solid;text-align: center;"><p>The Securities and Exchange Commission has not necessarily reviewed the information in this filing and has not determined if it is accurate and complete.<br />The reader should not assume that the information is accurate and complete.</p></td>
         </tr>
         <xsl:call-template name="Form13F_Legend"/>
         <tr>
            <td width="10%" colspan="2" valign="top" align="left"/>
            <td rowspan="1" width="70%" valign="middle" align="center">
               <xsl:call-template name="TitleBox">
                  <xsl:with-param name="FormTitle"><xsl:value-of select="$FormTitle" /></xsl:with-param>
                  <xsl:with-param name="FormTitle1"><xsl:value-of select="$FormTitle1" /></xsl:with-param>
               </xsl:call-template>
            </td>
            <td rowspan="1" width="20%" valign="top" align="center">
               <xsl:call-template name="OMBBox">
                  <xsl:with-param name="OMBNumber" select="'3235-0006'"/>
                  <xsl:with-param name="OMBExpireDate" select="'Oct 31, 2018'"/>
                  <xsl:with-param name="OMBHours" select="'23.8'"/>
               </xsl:call-template>
            </td> 
         </tr>
      </table>
      <hr/>
   </xsl:template>
   
   <xsl:template name="Form13F_NTHeader">
      <xsl:param name="FormTitle" />
      <xsl:param name="FormTitle1" />
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="Form 13F-NT Header Information">
         <tr>
            <td colspan="4" style="border: solid;text-align: center;"><p>The Securities and Exchange Commission has not necessarily reviewed the information in this filing and has not determined if it is accurate and complete.<br />The reader should not assume that the information is accurate and complete.</p></td>
         </tr>
         <xsl:call-template name="Form13F_Legend"/>
         <tr>
            <td width="10%" colspan="2" valign="top" align="left"/>
            <td rowspan="1" width="70%" valign="middle" align="center">
               <xsl:call-template name="TitleBox">
                  <xsl:with-param name="FormTitle"><xsl:value-of select="$FormTitle" /></xsl:with-param>
                  <xsl:with-param name="FormTitle1"><xsl:value-of select="$FormTitle1" /></xsl:with-param>
               </xsl:call-template>
            </td>
            <td rowspan="1" width="20%" valign="top" align="center">
               <xsl:call-template name="OMBBox">
                  <xsl:with-param name="OMBNumber" select="'3235-0006'"/>
                  <xsl:with-param name="OMBExpireDate" select="'Oct 31, 2018'"/>
                  <xsl:with-param name="OMBHours" select="'23.8'"/>
               </xsl:call-template>
            </td>
         </tr>
      </table>
      <hr/>
   </xsl:template>
		
   <xsl:template name="Form13F_Legend">
      <xsl:if test="n1:formData/n1:coverPage/n1:amendmentInfo/n1:confDeniedExpired=1 or n1:formData/n1:coverPage/n1:amendmentInfo/n1:confDeniedExpired='true' or n1:formData/n1:coverPage/n1:amendmentInfo/n1:confDeniedExpired='1' or n1:formData/n1:coverPage/n1:amendmentInfo/n1:confDeniedExpired='YES'">
         <tr>
            <td colspan="4" class="FormText" style="padding-top: 2em;">THIS FILING LISTS SECURITIES HOLDINGS REPORTED ON THE FORM 13F FILED ON 
               <xsl:value-of select="n1:formData/n1:coverPage/n1:amendmentInfo/n1:dateReported"/>
               PURSUANT TO A REQUEST FOR CONFIDENTIAL TREATMENT AND FOR WHICH 
               <xsl:value-of select="translate(n1:formData/n1:coverPage/n1:amendmentInfo/n1:reasonForNonConfidentiality,
                  'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
               ON 
               <xsl:value-of select="n1:formData/n1:coverPage/n1:amendmentInfo/n1:dateDeniedExpired"/>.
            </td>
         </tr>
      </xsl:if>
   </xsl:template>
   
</xsl:stylesheet>
