<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

   <xsl:import href="SEC-Common.xsl"/>

<!--
   XSL Stylesheet for SEC Form 25
   Version 1.1 - Dated June 27, 2008
   Created By: SAIC
   Created for: SEC
   -->

	<xsl:template match="/">
		<html>
			<head>
				<title>NOTIFICATION OF REMOVAL FROM LISTING AND/OR REGISTRATION UNDER SECTION 12(b) OF THE SECURITIES EXCHANGE ACT OF 1934.
			  	</title>
                                <xsl:call-template name="CSS"/>
			</head>
			<body>
				<table align="center" width="750" summary="Header">
					<tr>
						<td align="center" class="FormTitle">UNITED STATES</td>
						<td rowspan="4" width="30%" valign="top" align="center">
            				<xsl:call-template name="OMBBox">
               					<xsl:with-param name="OMBNumber" select="'3235-0080'" />
            					<xsl:with-param name="OMBExpireDate" select="'December 31, 2014'" />
               					<xsl:with-param name="OMBHours" select="'1.7'" />
            				</xsl:call-template>
         				</td>

					</tr>
					<tr>
						<td align="center" class="FormTitle">SECURITIES AND EXCHANGE COMMISSION</td>
					</tr>
					<tr>
						<td align="center" class="FormTextC">Washington, D.C. 20549</td>
					</tr>
					<tr>
						<td align="center" class="FormTitle">FORM 25</td>
					</tr>
					<tr>
						<td align="center" class="FormTitle" colspan="2">
							NOTIFICATION OF REMOVAL FROM LISTING AND/OR REGISTRATION<br />
							UNDER SECTION 12(b) OF THE SECURITIES EXCHANGE ACT OF 1934.
						</td>
					</tr>
					
					<xsl:apply-templates select="notificationOfRemoval/issuer" />
					
					<tr>
						<td class="FormText" colspan="2">
							Please place an X in the box to designate the rule provision relied upon to strike
							the class of securities from listing and registration:
						</td>
					</tr>
					<tr>
					  <td colspan="2">
						<xsl:call-template name="ruleProvision"/>
					  </td>
					</tr>
					<tr>
						<td class="FormText" colspan="2">
							Pursuant to the requirements fo the Securities Exchange Act of 1934, 
							<xsl:apply-templates select="notificationOfRemoval/exchange/entityName" mode="Normal" />
							certifies that it has reasonable grounds to believe that it
							meets all of the requirements for filing the Form 25 and has caused this notification to be
							signed on its behalf by the undersigned duly authorized person.
						</td>
					</tr>
					<tr>
					  <td colspan="2">
						<xsl:apply-templates select="notificationOfRemoval/signatureData"/>
					  </td>
					</tr>
					<tr>
					  <td colspan="2">
						<table align="center" width="650" summary="Footnote">
							<tr>
								<td align="left" valign="top" width="40">
									<a name="Footnote1">
										<sup>1</sup>
									</a>
								</td>
								<td align="left" class="FormText">
									Form 25 and attached Notice will be considered compliance with the provisions of
									17 CFR 240.19d-1 as applicable. <a href="#">See</a> General Instructions.
								</td>
							</tr>
						</table>
					  </td>
					</tr>
               <tr>
                  <td colspan="3" class="SmallFormText">
                     Persons who respond to the collection of information contained in this form are not required to respond unless the form displays a currently valid OMB Number.
                  </td>
               </tr>
				</table>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="notificationOfRemoval/issuer">
		<tr>
			<td align="right" class="FormTextR">Commission File Number </td>
			<td>
               <xsl:call-template name="createFileNoLink" >
                  <xsl:with-param name="aFileNumber" select="fileNumber"></xsl:with-param>
                  <xsl:with-param name="label" select="fileNumber"></xsl:with-param>
               </xsl:call-template>
			</td>
		</tr>
		<tr>
		  <td colspan="2">
		  <table align="center" width="650" summary="Basic Form Information">
			<tr>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 						border-right-width: 0; border-bottom-width: 2; border-left-width: 0;">
				<table summary="Issuer and Exchange Names">
				   <tr>
				      <td valign="top" class="FormText">Issuer:</td>
				      <td>
				         <xsl:if test="string-length(cik)>0">
                            <xsl:call-template name="createCIKLink" >
                               <xsl:with-param name="aCIK" select="cik"></xsl:with-param>
                               <xsl:with-param name="label" select="entityName"></xsl:with-param>
                            </xsl:call-template>
                         </xsl:if>
				         <xsl:if test="string-length(cik)=0">
				            <xsl:apply-templates select="entityName" mode="Normal" />
                         </xsl:if>
 				      </td>
				   </tr>
				   <tr>
				      <td valign="top" class="FormText">Exchange:</td>
				      <td>
				         <xsl:apply-templates select="//notificationOfRemoval/exchange/entityName" mode="Normal" />
				      </td>	
				   </tr>
				</table>
				</td>
			</tr>
			<tr>
				<td valign="top" align="center" class="SmallFormText">
					(Exact name of Issuer as specified in its charter, and name of Exchange where security is listed and/or registered)
				</td>
			</tr>
			<tr>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 							border-right-width: 0; border-bottom-width: 2; border-left-width: 0;">
				<table summary="Issuer Address Information">
					<tr> 
						<td align="right" valign="top" class="FormText">Address:</td>
						<td colspan="4"><xsl:apply-templates select="address/street1" mode="Normal" /></td>
					</tr>
					<xsl:if test="string-length(address/street2)>0">
						<tr>
						    <td></td>
							<td colspan="4"><xsl:apply-templates select="address/street2" mode="Normal" /></td>
						</tr>
                    </xsl:if>
					<tr>
						<td></td>
						<td align="left"><xsl:apply-templates select="address/city" mode="Normal" /></td>
						<td align="left"><xsl:apply-templates select="address/stateOrCountry" mode="Normal" /></td>
						<td align="left"><xsl:apply-templates select="address/zipCode" mode="NormalZip" /></td>
					</tr>
					<tr>
						<td align="right" valign="top" class="FormText">Telephone number:</td>
						<td align="left" colspan="4">
						   <xsl:apply-templates select="telephoneNumber" mode="NormalTDL" />
						</td>
					</tr>
				</table>
				</td>
			</tr>
			<tr>
				<td valign="top" align="center" class="SmallFormText">
					(Address, including zip code, and telephone number, including area code, of Issuer's
					principal executive offices)
				</td>
			</tr>
			<tr>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 				border-right-width: 0; border-bottom-width: 2; border-left-width: 0;">
					<xsl:apply-templates select="//notificationOfRemoval/descriptionClassSecurity" mode="Normal" />
				</td>
			</tr>
			<tr>
				<td valign="top" align="center" class="SmallFormText">
					(Description of class of securities)
				</td>
			</tr>
		</table>
		</td>
	</tr>
	</xsl:template>	
	
	<xsl:template name="ruleProvision">
		<table align="center" width="650" cellspacing="10" summary="Rule Provisions">
			<tr>
				<td class="FormText">
				<input type="checkbox" disabled="true">
					<xsl:for-each select="notificationOfRemoval/ruleProvision">
					  <xsl:if test=".='17 CFR 240.12d2-2(a)(1)'">
						<xsl:attribute name="checked"/>
					  </xsl:if>
					</xsl:for-each>
				</input>
				   <xsl:text>17 CFR 240.12d2-2(a)(1)</xsl:text>
				</td>
			</tr>
			<tr>
				<td class="FormText">
				<input type="checkbox" disabled="true">
					<xsl:for-each select="notificationOfRemoval/ruleProvision"><xsl:if test=".='17 CFR 240.12d2-2(a)(2)'">
						<xsl:attribute name="checked"/>
					</xsl:if></xsl:for-each>
				</input>
				<xsl:text>17 CFR 240.12d2-2(a)(2)</xsl:text>
				</td>
			</tr>
			<tr>
				<td class="FormText">
				<input type="checkbox" disabled="true">
					<xsl:for-each select="notificationOfRemoval/ruleProvision"><xsl:if test=".='17 CFR 240.12d2-2(a)(3)'">
						<xsl:attribute name="checked"/>
					</xsl:if></xsl:for-each>
				</input>
				<xsl:text>17 CFR 240.12d2-2(a)(3)</xsl:text>
				</td>
			</tr>
			<tr>
				<td class="FormText">	
				<input type="checkbox" disabled="true">
					<xsl:for-each select="notificationOfRemoval/ruleProvision"><xsl:if test=".='17 CFR 240.12d2-2(a)(4)'">
						<xsl:attribute name="checked"/>
					</xsl:if></xsl:for-each>
				</input>
				<xsl:text>17 CFR 240.12d2-2(a)(4)</xsl:text>
				</td>
			</tr>
			<tr>
				<td class="FormText">				
					<input type="checkbox"  disabled="true">
					<xsl:for-each select="notificationOfRemoval/ruleProvision"><xsl:if test=".='17 CFR 240.12d2-2(b)'">
						<xsl:attribute name="checked"/>
					</xsl:if></xsl:for-each>
					</input>
					Pursuant to 17 CFR 240.12d2-2(b), the Exchange has complied with its rules to	strike the class of securities from listing and/or withdraw registration on the Exchange.
					<a href="#Footnote1"><sup>1</sup></a>
				</td>
			</tr>
			<tr>
				<td class="FormText">
					<input type="checkbox"  disabled="true" />						
					Pursuant to 17 CFR 240.12d2-2(c), the Issuer has complied with its rules of the Exchange and the requirements of 17 CFR 240.12d-2(c) governing the voluntary withdrawal of the class of securities from listing and registration on the Exchange.
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="notificationOfRemoval/signatureData">
		<table align="center" width="650" summary="Signature Data">
			<tr>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 							border-right-width: 0; border-bottom-width: 1; border-left-width: 0;" width="120">
					<xsl:apply-templates select="signatureDate" mode="Normal" />
				</td>
				<td align="right" width="50" class="FormText">By</td>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 							border-right-width: 0; border-bottom-width: 1; border-left-width: 0;" width="200">
					<xsl:apply-templates select="signatureName" mode="Normal" />
				</td>
				<td width="10"/>
				<td valign="bottom" align="center" style="border: solid black; border-top-width: 0;
	 							border-right-width: 0; border-bottom-width: 1; border-left-width: 0;" width="120">
					<xsl:apply-templates select="signatureTitle" mode="Normal" />
				</td>
			</tr>
			<tr>
				<td align="center" class="FormText">Date</td>
				<td></td>
				<td align="center" colspan="2" class="FormText">Name</td>
				<td align="center" class="FormText">Title</td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:stylesheet>
