<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:import href="ReportingPerson.xsl" />

   <xsl:import href="SecuritiesNonDerivative.xsl" />

   <xsl:import href="SecuritiesDerivative.xsl" />

   <xsl:import href="SEC-Common.xsl" />

<!--
   XSL Stylesheet for SEC Forms 3, 4 and 5 
   Uses XSL Stylesheets: ReportingPerson.xsl, SecuritiesNonDerivative.xsl, SecuritiesDerivative.xsl 
   Based on XSD: ownership#Document.xsd.xml (Version 1.0), ownershipDocumentCommon.xsd.xml (Version 1.0) 
   Version 0.9 - Dated April 22, 2003
   Created By: SAIC 
   Created for: SEC
   -->
   <xsl:variable name="this" select="/" />

   <xsl:output method="html" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" media-type="application/xml" />

   <xsl:template match="/ownershipDocument">
      <html>
         <head>
            <title>SEC FORM 
            <xsl:value-of select="documentType" />
            </title>
            <xsl:call-template name="CSS"/>
         </head>

         <body bgcolor="white">
            <xsl:choose>
               <xsl:when test="(documentType=3) or (documentType='3/A')">
                  <xsl:call-template name="Form3Header" />

                  <xsl:apply-templates select="reportingOwner[1]" mode="form3" />
               </xsl:when>

               <xsl:when test="(documentType=4) or (documentType='4/A')">
                  <xsl:call-template name="Form4Header" />

                  <xsl:apply-templates select="reportingOwner[1]" mode="form4" />
               </xsl:when>

               <xsl:when test="(documentType=5) or (documentType='5/A')">
                  <xsl:call-template name="Form5Header" />

                  <xsl:apply-templates select="reportingOwner[1]" mode="form5" />
               </xsl:when>

               <xsl:otherwise>NO HEADER FOUND MATCHING TYPE 
               <xsl:apply-templates select="documentType" />
               </xsl:otherwise>
            </xsl:choose>

            <table width="100%" border="1" cellspacing="0" cellpadding="4">
               <xsl:choose>
                  <xsl:when test="(documentType=3) or (documentType='3/A')">
                     <xsl:call-template name="NonDerivativeHeader3" />

                     <tbody>
                        <xsl:apply-templates select="nonDerivativeSecurity" mode="form3" />
                     </tbody>
                  </xsl:when>

                  <xsl:when test="(documentType=4) or (documentType='4/A')">
                     <xsl:call-template name="NonDerivativeHeader4" />

                     <tbody>
                        <xsl:apply-templates select="nonDerivativeSecurity" mode="form4" />
                     </tbody>
                  </xsl:when>

                  <xsl:when test="(documentType=5) or (documentType='5/A')">
                     <xsl:call-template name="NonDerivativeHeader5" />

                     <tbody>
                        <xsl:apply-templates select="nonDerivativeSecurity" mode="form5" />
                     </tbody>
                  </xsl:when>

                  <xsl:otherwise>NO HEADER FOUND MATCHING TYPE 
                  <xsl:apply-templates select="documentType" />
                  </xsl:otherwise>
               </xsl:choose>
            </table>

            <table width="100%" border="1" cellspacing="0" cellpadding="4">
               <xsl:choose>
                  <xsl:when test="(documentType=3) or (documentType='3/A')">
                     <xsl:call-template name="DerivativeHeader3" />

                     <tbody>
                        <xsl:apply-templates select="derivativeSecurity" mode="form3" />
                     </tbody>
                  </xsl:when>

                  <xsl:when test="(documentType=4) or (documentType='4/A')">
                     <xsl:call-template name="DerivativeHeader4" />

                     <tbody>
                        <xsl:apply-templates select="derivativeSecurity" mode="form4" />
                     </tbody>
                  </xsl:when>

                  <xsl:when test="(documentType=5) or (documentType='5/A')">
                     <xsl:call-template name="DerivativeHeader5" />

                     <tbody>
                        <xsl:apply-templates select="derivativeSecurity" mode="form5" />
                     </tbody>
                  </xsl:when>

                  <xsl:otherwise>NO HEADER FOUND MATCHING TYPE 
                  <xsl:apply-templates select="documentType" />
                  </xsl:otherwise>
               </xsl:choose>
            </table>

            <xsl:if test="count(reportingOwner)&gt;1">
               <table width="40%" border="1" cellspacing="0" cellpadding="4">
                  <xsl:apply-templates select="reportingOwner" mode="extras" />
               </table>
            </xsl:if>

            <table border="0" width="100%">
               <tr>
                  <td class="MedSmallFormText">
                     <b>Explanation of Responses:</b>
                  </td>
               </tr>

               <xsl:apply-templates select="footnotes" />
            </table>

            <table width="100%" border="0">
               <xsl:apply-templates select="ownerSignature" />

               <tr>
                  <td>
                  </td>

                  <td class="MedSmallFormText">** Signature of Reporting Person</td>

                  <td class="MedSmallFormText">Date</td>
               </tr>

               <tr>
                  <td colspan="3" class="MedSmallFormText">Reminder: Report on a separate line for each class of securities beneficially owned directly or indirectly.</td>
               </tr>

               <tr>
                  <td colspan="3" class="MedSmallFormText">* If the form is filed by more than one reporting person, 
                  <i>see</i>

                  Instruction 
                  <xsl:choose>
                     <xsl:when test="(documentType=3) or (documentType='3/A')">5</xsl:when>

                     <xsl:when test="(documentType=4) or (documentType='4/A')">4</xsl:when>

                     <xsl:when test="(documentType=5) or (documentType='5/A')">4</xsl:when>
                  </xsl:choose>

                  (b)(v).</td>
               </tr>

               <tr>
                  <td colspan="3" class="MedSmallFormText">** Intentional misstatements or omissions of facts constitute Federal Criminal Violations 
                  <i>See</i>

                  18 U.S.C. 1001 and 15 U.S.C. 78ff(a).</td>
               </tr>

               <tr>
                  <td colspan="3" class="MedSmallFormText">Note: File three copies of this Form, one of which must be manually signed. If space is insufficient, 
                  <i>see</i>

                  Instruction 6 for procedure.</td>
               </tr>

               <tr>
                  <td colspan="3" class="MedSmallFormText">
                     <b>Persons who respond to the collection of information contained in this form are not required to respond unless the form displays a currently valid OMB Number.</b>
                  </td>
               </tr>
            </table>
         </body>
      </html>
   </xsl:template>

   <xsl:template name="Form3Header">SEC Form 3 
   <table width="100%" border="0" cellspacing="0" cellpadding="4">
      <tr>
         <td width="20%" colspan="2" valign="top" align="center" class="FormName">FORM 3</td>

         <td rowspan="1" width="60%" valign="middle" align="center">
            <xsl:call-template name="Form345TitleBox">
               <xsl:with-param name="FormTitle">INITIAL STATEMENT OF BENEFICIAL OWNERSHIP OF SECURITIES</xsl:with-param>
            </xsl:call-template>
         </td>

         <td rowspan="1" width="20%" valign="top" align="center">
            <xsl:call-template name="OMBBox">
               <xsl:with-param name="OMBNumber" select="'3235-0104'" />

               <xsl:with-param name="OMBExpireDate" select="'December 31, 2014'" />

               <xsl:with-param name="OMBHours" select="'0.5'" />
            </xsl:call-template>
         </td>
      </tr>
   </table>
   </xsl:template>

   <xsl:template name="Form4Header">SEC Form 4 
   <table width="100%" border="0" cellspacing="0" cellpadding="4">
      <tr>
         <td width="20%" colspan="2" valign="top" align="center" class="FormName">FORM 4</td>

         <td rowspan="2" width="60%" valign="middle" align="center">
            <xsl:call-template name="Form345TitleBox">
               <xsl:with-param name="FormTitle">STATEMENT OF CHANGES IN BENEFICIAL OWNERSHIP</xsl:with-param>
            </xsl:call-template>
         </td>

         <td rowspan="2" width="20%" valign="top" align="center">
            <xsl:call-template name="OMBBox">
               <xsl:with-param name="OMBNumber" select="'3235-0287'" />

               <xsl:with-param name="OMBExpireDate" select="'December 31, 2014'" />

               <xsl:with-param name="OMBHours" select="'0.5'" />
            </xsl:call-template>
         </td>
      </tr>

      <xsl:call-template name="HeaderInfo" />
   </table>
   </xsl:template>

   <xsl:template name="Form5Header">SEC Form 5 
   <table width="100%" border="0" cellspacing="0" cellpadding="4">
      <tr>
         <td width="20%" colspan="2" valign="top" align="center" class="FormName">FORM 5</td>

         <td rowspan="4" width="60%" valign="middle" align="center">
            <xsl:call-template name="Form345TitleBox">
               <xsl:with-param name="FormTitle">ANNUAL STATEMENT OF CHANGES IN BENEFICIAL OWNERSHIP</xsl:with-param>
            </xsl:call-template>
         </td>

         <td rowspan="4" width="20%" valign="top" align="center">
            <xsl:call-template name="OMBBox">
               <xsl:with-param name="OMBNumber" select="'3235-0362'" />

               <xsl:with-param name="OMBExpireDate" select="'January 31, 2014'" />

               <xsl:with-param name="OMBHours" select="'1.0'" />
            </xsl:call-template>
         </td>
      </tr>

      <xsl:call-template name="HeaderInfo" />
   </table>
   </xsl:template>

   <xsl:template name="HeaderInfo">
      <tr valign="middle">
         <td>
            <table width="100%" border="1" cellpadding="0" cellspacing="0">
               <tr>
                  <td>
                     <xsl:call-template name="TestCheck">
                        <xsl:with-param name="TestThis" select="notSubjectToSection16" />
                     </xsl:call-template>
                  </td>
               </tr>
            </table>
         </td>

         <td class="SmallFormText">Check this box if no longer subject to Section 16. Form 4 or Form 5 obligations may continue. 
         <i>See</i>

         Instruction 1(b).</td>
      </tr>

      <xsl:if test="(documentType=5) or (documentType='5/A')">
         <tr valign="middle">
            <td>
               <table width="100%" border="1" cellpadding="0" cellspacing="0">
                  <tr>
                     <td>
                        <xsl:call-template name="TestCheck">
                           <xsl:with-param name="TestThis" select="form3HoldingsReported" />
                        </xsl:call-template>
                     </td>
                  </tr>
               </table>
            </td>

            <td class="SmallFormText">Form 3 Holdings Reported.</td>
         </tr>

         <tr valign="middle">
            <td>
               <table width="100%" border="1" cellpadding="0" cellspacing="0">
                  <tr>
                     <td>
                        <xsl:call-template name="TestCheck">
                           <xsl:with-param name="TestThis" select="form4TransactionsReported" />
                        </xsl:call-template>
                     </td>
                  </tr>
               </table>
            </td>

            <td class="SmallFormText">Form 4 Transactions Reported.</td>
         </tr>
      </xsl:if>
   </xsl:template>

</xsl:stylesheet>

