<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
   XSL Stylesheet for Form D Sections
   Version 1.1 - Dated February 2010
   Created By: SAIC 
   Created for: SEC
   -->
   
   <xsl:template name="Section1and2">
     <xsl:apply-templates select="primaryIssuer"/>
     <xsl:apply-templates select="issuerList/issuer"/>
   </xsl:template>
   
   <xsl:template match="primaryIssuer|issuer">
     <p class="SectionTitle">1. Issuer's Identity</p>
     <table summary="Issuer Identity Information" width="100%">
       <tbody>
         <tr>
           <th width="33%" class="FormText">CIK (Filer ID Number)</th>
           <th width="10%" class="FormText">Previous Names</th>
           <td width="23%">
              <xsl:call-template name="BuildCheckBox">
                 <xsl:with-param name="TestThis" select="count(edgarPreviousNameList/previousName)+count(issuerPreviousNameList/previousName)=0" />
                 <xsl:with-param name="Label" select="'None'" />
              </xsl:call-template>
           </td>
           <th width="33%" class="FormText">Entity Type</th>
         </tr>
         <tr>
           <td>
             <xsl:call-template name="createCIKLink" >
               <xsl:with-param name="aCIK" select="cik"></xsl:with-param>
               <xsl:with-param name="label" select="cik"></xsl:with-param>
             </xsl:call-template>
           </td>
           <td rowspan="5" colspan="2" valign="top">
              <xsl:if test="count(edgarPreviousNameList/previousName)+count(issuerPreviousNameList/previousName)&gt;0">
                 <table border="0" summary="List of Previous Names">
                   <tbody>
                     <xsl:apply-templates select="edgarPreviousNameList/previousName" mode="multiple_rows" />
                     <xsl:apply-templates select="issuerPreviousNameList/previousName" mode="multiple_rows" />
                   </tbody>
                 </table>
              </xsl:if>
           </td>
           <td rowspan="7" valign="top">
             <xsl:call-template name="BuildXRadios">
               <xsl:with-param name="TestThis1" select="entityType='Corporation'"/>
               <xsl:with-param name="Label1" select="'Corporation'"/>
               <xsl:with-param name="TestThis2" select="entityType='Limited Partnership'"/>
               <xsl:with-param name="Label2" select="'Limited Partnership'"/>
               <xsl:with-param name="TestThis3" select="entityType='Limited Liability Company'"/>
               <xsl:with-param name="Label3" select="'Limited Liability Company'"/>
               <xsl:with-param name="TestThis4" select="entityType='General Partnership'"/>
               <xsl:with-param name="Label4" select="'General Partnership'"/>
               <xsl:with-param name="TestThis5" select="entityType='Business Trust'"/>
               <xsl:with-param name="Label5" select="'Business Trust'"/>
               <xsl:with-param name="TestThis6" select="entityType='Other'"/>
               <xsl:with-param name="Label6" select="'Other (Specify)'"/>
             </xsl:call-template>
             <br />
             <xsl:apply-templates select="entityTypeOtherDesc" mode="normal"/>
           </td>
         </tr>
         <tr>
           <th class="FormText">Name of Issuer</th>
         </tr>
         <tr>
           <xsl:apply-templates select="entityName" mode="NormalTDL" />
         </tr>
         <tr>
           <th class="FormText">Jurisdiction of Incorporation/Organization</th>
         </tr>
         <tr>
           <xsl:apply-templates select="jurisdictionOfInc" mode="NormalTDL"/>
         </tr>
         <tr>
           <th class="FormText" colspan="2">Year of Incorporation/Organization</th>
         </tr>
         <tr>
           <td colspan="3">
             <table border="0" summary="Year of Incorporation/Organization">
               <tbody>
                 <tr>
                   <xsl:call-template name="BuildSoloRadioTD">
                     <xsl:with-param name="TestThis" select="yearOfInc/overFiveYears" />
                     <xsl:with-param name="Label" select="'Over Five Years Ago'" />
                   </xsl:call-template>
                 </tr>
                 <tr>
                   <xsl:call-template name="BuildSoloRadioTD">
                     <xsl:with-param name="TestThis" select="boolean(yearOfInc/value)" />
                     <xsl:with-param name="Label" select="'Within Last Five Years (Specify Year)'" />
                   </xsl:call-template>
                   <td><xsl:apply-templates select="yearOfInc/value" mode="NormalText"/></td>
                 </tr>
                 <tr>
                   <xsl:call-template name="BuildSoloRadioTD">
                     <xsl:with-param name="TestThis" select="yearOfInc/yetToBeFormed" />
                     <xsl:with-param name="Label" select="'Yet to Be Formed'" />
                   </xsl:call-template>
                 </tr>
               </tbody>
             </table>
           </td>
         </tr>
       </tbody>
     </table>
     <p class="SectionTitle">2. Principal Place of Business and Contact Information</p>
     <table summary="Principal Place of Business and Contact Information" width="90%">
       <tbody>
         <tr>
           <th class="FormText" colspan="2">Name of Issuer</th>
         </tr>
         <tr>
           <xsl:apply-templates select="entityName" mode="NormalTDLCS2"/>
         </tr>
         <xsl:call-template name="SA1-SA2-Label">
            <xsl:with-param name="colspan" select="2" />
         </xsl:call-template>
         <tr>
           <xsl:apply-templates select="issuerAddress/street1" mode="NormalTDLCS2"/>
           <xsl:apply-templates select="issuerAddress/street2" mode="NormalTDLCS2"/>
         </tr>
         <tr>
           <th class="FormText" width="25%">City</th>
           <th class="FormText" width="25%">State/Province/Country</th>
           <th class="FormText" width="25%">ZIP/PostalCode</th>
           <th class="FormText" width="25%">Phone Number of Issuer</th>
         </tr>
         <tr>
           <xsl:call-template name="GetCityStateZip">
              <xsl:with-param name="Node" select="./issuerAddress" />
           </xsl:call-template>
           <xsl:apply-templates select="issuerPhoneNumber" mode="NormalTDLZ"/>         
         </tr>
       </tbody>
     </table>
   </xsl:template>
   
   <xsl:template match="*" mode="multiple_rows">
     <tr>
       <xsl:apply-templates select="." mode="NormalTDL"/>
     </tr>
   </xsl:template>
   
   <xsl:template name="Section3">
     <p class="SectionTitle">3. Related Persons</p>
     <xsl:apply-templates select="relatedPersonsList/relatedPersonInfo"/>
   </xsl:template>
   
   <xsl:template match="relatedPersonInfo">
     <table summary="Related Persons" width="90%">
       <tbody>
         <tr>
           <th class="FormText" width="30%">Last Name</th>
           <th class="FormText" width="30%">First Name</th>
           <th class="FormText" width="30%">Middle Name</th>
         </tr>
         <tr>
           <xsl:apply-templates select="relatedPersonName/lastName" mode="NormalTDL"/>
           <xsl:apply-templates select="relatedPersonName/firstName" mode="NormalTDL"/>
           <xsl:apply-templates select="relatedPersonName/middleName" mode="NormalTDL"/>
         </tr>
         <xsl:call-template name="SA1-SA2-Label" />
         <tr>
           <xsl:apply-templates select="relatedPersonAddress/street1" mode="NormalTDL"/>
           <xsl:apply-templates select="relatedPersonAddress/street2" mode="NormalTDL"/>
         </tr>
         <tr>
           <th class="FormText">City</th>
           <th class="FormText">State/Province/Country</th>
           <th class="FormText">ZIP/PostalCode</th>
         </tr>
         <tr>
           <xsl:call-template name="GetCityStateZip">
              <xsl:with-param name="Node" select="./relatedPersonAddress" />
           </xsl:call-template>
         </tr>
       </tbody>
     </table>
     <table summary="Relationship of Person">
       <tbody>
         <tr>
           <th class="FormText">Relationship:</th>
           <xsl:call-template name="BuildSoloRadioTD">
              <xsl:with-param name="TestThis" select="relatedPersonRelationshipList/relationship='Executive Officer'" />
              <xsl:with-param name="Label" select="'Executive Officer'" />
           </xsl:call-template>
           <xsl:call-template name="BuildSoloRadioTD">
              <xsl:with-param name="TestThis" select="relatedPersonRelationshipList/relationship='Director'" />
              <xsl:with-param name="Label" select="'Director'" />
           </xsl:call-template>
           <xsl:call-template name="BuildSoloRadioTD">
              <xsl:with-param name="TestThis" select="relatedPersonRelationshipList/relationship='Promoter'" />
              <xsl:with-param name="Label" select="'Promoter'" />
           </xsl:call-template>
         </tr>
       </tbody>
     </table>
     <p class="FormText">Clarification of Response (if Necessary):</p>
     <xsl:apply-templates select="relationshipClarification" mode="NormalText"/>
     <hr/>
   </xsl:template>

   <xsl:template name="Section4">
     <p class="SectionTitle">4. Industry Group</p>
     <xsl:for-each select="offeringData/industryGroup">
        <table border="0" summary="Industry Group">
           <tbody>
              <tr>
                 <td>
                    <table border="0" summary="Industry Group, Agriculture">
                      <tbody>
                       <xsl:call-template name="BuildSoloRadioTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Agriculture'" />
                          <xsl:with-param name="Label" select="'Agriculture'" />
                       </xsl:call-template>
                       <tr>
                          <td> </td>
                          <td class="FormText">Banking &amp; Financial Services</td>
                       </tr>
                       <tr>
                          <td> </td>
                          <td width="100%">
                             <table border="0" summary="Industry Group, Banking &amp; Financial Services">
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Commercial Banking'" />
                                   <xsl:with-param name="Label" select="'Commercial Banking'" />
                                </xsl:call-template>
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Insurance'" />
                                   <xsl:with-param name="Label" select="'Insurance'" />
                                </xsl:call-template>
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Investing'" />
                                   <xsl:with-param name="Label" select="'Investing'" />
                                </xsl:call-template>                                
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Investment Banking'" />
                                   <xsl:with-param name="Label" select="'Investment Banking'" />
                                </xsl:call-template>
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Pooled Investment Fund'" />
                                   <xsl:with-param name="Label" select="'Pooled Investment Fund'" />
                                </xsl:call-template>            
                                <tr>
                                   <td> </td>
                                   <td>
                                      <table border="0" summary="Pooled Investment Fund">
                                         <xsl:choose>
                                            <xsl:when test="industryGroupType = 'Pooled Investment Fund'">
                                               <xsl:call-template name="BuildSoloRadioTR">
                                                  <xsl:with-param name="TestThis" select="investmentFundInfo/investmentFundType = 'Hedge Fund'" />
                                                  <xsl:with-param name="Label" select="'Hedge Fund'" />
                                               </xsl:call-template>            
                                               <xsl:call-template name="BuildSoloRadioTR">
                                                  <xsl:with-param name="TestThis" select="investmentFundInfo/investmentFundType = 'Private Equity Fund'" />
                                                  <xsl:with-param name="Label" select="'Private Equity Fund'" />
                                               </xsl:call-template>            
                                               <xsl:call-template name="BuildSoloRadioTR">
                                                  <xsl:with-param name="TestThis" select="investmentFundInfo/investmentFundType = 'Venture Capital Fund'" />
                                                  <xsl:with-param name="Label" select="'Venture Capital Fund'" />
                                               </xsl:call-template>            
                                               <xsl:call-template name="BuildSoloRadioTR">
                                                  <xsl:with-param name="TestThis" select="investmentFundInfo/investmentFundType = 'Other Investment Fund'" />
                                                  <xsl:with-param name="Label" select="'Other Investment Fund'" />
                                               </xsl:call-template>            
                                            </xsl:when>
                                         </xsl:choose>
                                      </table>
                                   </td>
                                </tr>
                                <tr>
                                   <td> </td>
                                   <td class="FormText">Is the issuer registered as <br />an investment company under <br />the Investment Company <br />Act of 1940? </td>
                                </tr>
                                <tr>
                                   <td> </td>
                                   <td>
                                      <xsl:choose>
                                         <xsl:when test="industryGroupType = 'Pooled Investment Fund'">
                                            <xsl:call-template name="Build2Radios">
                                               <xsl:with-param name="TestThis1" select="investmentFundInfo/is40Act" />
                                               <xsl:with-param name="Label1" select="'Yes'" />
                                               <xsl:with-param name="TestNotThis2" select="investmentFundInfo/is40Act" />
                                               <xsl:with-param name="Label2" select="'No'" />
                                            </xsl:call-template>
                                         </xsl:when>
                                         <xsl:otherwise>
                                            <xsl:call-template name="Build2Radios">
                                               <xsl:with-param name="TestThis1" select="0" />
                                               <xsl:with-param name="Label1" select="'Yes'" />
                                               <xsl:with-param name="TestNotThis2" select="1" />
                                               <xsl:with-param name="Label2" select="'No'" />
                                            </xsl:call-template>
                                         </xsl:otherwise>
                                      </xsl:choose>
                                   </td>
                                </tr>
                                <xsl:call-template name="BuildSoloRadioTR">
                                   <xsl:with-param name="TestThis" select="industryGroupType = 'Other Banking and Financial Services'" />
                                   <xsl:with-param name="Label" select="'Other Banking &amp; Financial Services'" />
                                </xsl:call-template>           
                             </table>
                          </td>
                       </tr>
                       <xsl:call-template name="BuildSoloRadioTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Business Services'" />
                          <xsl:with-param name="Label" select="'Business Services'" />
                       </xsl:call-template>
                       <tr>
                          <td> </td>
                          <td class="FormText">Energy</td>
                       </tr>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Coal Mining'" />
                          <xsl:with-param name="Label" select="'Coal Mining'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Electric Utilities'" />
                          <xsl:with-param name="Label" select="'Electric Utilities'" />
                       </xsl:call-template>                       
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Energy Conservation'" />
                          <xsl:with-param name="Label" select="'Energy Conservation'" />
                       </xsl:call-template>                       
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Environmental Services'" />
                          <xsl:with-param name="Label" select="'Environmental Services'" />
                       </xsl:call-template>                          
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Oil and Gas'" />
                          <xsl:with-param name="Label" select="'Oil &amp; Gas'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Other Energy'" />
                          <xsl:with-param name="Label" select="'Other Energy'" />
                       </xsl:call-template>
                      </tbody>
                    </table>
                 </td>
                 <td vAlign="top">
                    <table border="0" summary="Industry Group, Health Care">
                      <tbody>
                       <tr>
                          <td> </td>
                          <td class="FormText">Health Care</td>
                       </tr>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Biotechnology'" />
                          <xsl:with-param name="Label" select="'Biotechnology'" />
                       </xsl:call-template>      
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Health Insurance'" />
                          <xsl:with-param name="Label" select="'Health Insurance'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Hospitals and Physicians'" />
                          <xsl:with-param name="Label" select="'Hospitals &amp; Physicians'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Pharmaceuticals'" />
                          <xsl:with-param name="Label" select="'Pharmaceuticals'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Other Health Care'" />
                          <xsl:with-param name="Label" select="'Other Health Care'" />
                       </xsl:call-template>
                       <tr>
                          <xsl:call-template name="BuildSoloRadioTD">
                             <xsl:with-param name="TestThis" select="industryGroupType = 'Manufacturing'" />
                             <xsl:with-param name="Label" select="'Manufacturing'" />
                          </xsl:call-template>                       
                       </tr>
                       <tr>
                          <td> </td>
                          <td class="FormText">Real Estate</td>
                       </tr>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Commercial'" />
                          <xsl:with-param name="Label" select="'Commercial'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Construction'" />
                          <xsl:with-param name="Label" select="'Construction'" />
                       </xsl:call-template>                       
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'REITS and Finance'" />
                          <xsl:with-param name="Label" select="'REITS &amp; Finance'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Residential'" />
                          <xsl:with-param name="Label" select="'Residential'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Other Real Estate'" />
                          <xsl:with-param name="Label" select="'Other Real Estate'" />
                       </xsl:call-template>
                      </tbody>
                    </table>
                 </td>
                 <td vAlign="top">
                    <table border="0" summary="Industry Group, Retailing">
                      <tbody>
                       <tr>
                          <xsl:call-template name="BuildCheckBoxTD">
                             <xsl:with-param name="TestThis" select="industryGroupType = 'Retailing'" />
                          </xsl:call-template>
                          <td class="FormText">Retailing</td>
                       </tr>
                       <tr>
                          <xsl:call-template name="BuildCheckBoxTD">
                             <xsl:with-param name="TestThis" select="industryGroupType = 'Restaurants'" />
                          </xsl:call-template>
                          <td class="FormText">Restaurants</td>
                       </tr>
                       <tr>
                          <td> </td>
                          <td class="FormText">Technology</td>
                       </tr>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Computers'" />
                          <xsl:with-param name="Label" select="'Computers'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Telecommunications'" />
                          <xsl:with-param name="Label" select="'Telecommunications'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Other Technology'" />
                          <xsl:with-param name="Label" select="'Other Technology'" />
                       </xsl:call-template>
                       <tr>
                          <td> </td>
                          <td class="FormText">Travel</td>
                       </tr>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Airlines and Airports'" />
                          <xsl:with-param name="Label" select="'Airlines &amp; Airports'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Lodging and Conventions'" />
                          <xsl:with-param name="Label" select="'Lodging &amp; Conventions'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Tourism and Travel Services'" />
                          <xsl:with-param name="Label" select="'Tourism &amp; Travel Services'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTR">
                          <xsl:with-param name="TestThis" select="industryGroupType = 'Other Travel'" />
                          <xsl:with-param name="Label" select="'Other Travel'" />
                       </xsl:call-template>
                       <tr>
                          <xsl:call-template name="BuildCheckBoxTD">
                             <xsl:with-param name="TestThis" select="industryGroupType = 'Other'" />
                          </xsl:call-template>
                          <td class="FormText">Other</td>
                       </tr>
                      </tbody>
                    </table>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section5">
     <p class="SectionTitle">5. Issuer Size</p>
     <xsl:for-each select="offeringData/issuerSize">
        <table border="0" summary="Issuer Size">
           <colgroup span="4">        
              <col width="2" />
              <col width="20%" />
              <col width="15%" />
              <col width="2" />
              <col width="65%" />
           </colgroup>
           <tbody>
              <tr>
                 <th colspan="2" class="FormText">Revenue Range</th>
                 <th rowspan="9" class="FormText" valign="top" align="center">OR</th>
                 <th colspan="2" class="FormText">Aggregate Net Asset Value Range</th>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = 'No Revenues'" />
                    <xsl:with-param name="Label" select="'No Revenues'" />
                 </xsl:call-template>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = 'No Aggregate Net Asset Value'" />
                    <xsl:with-param name="Label" select="'No Aggregate Net Asset Value'" />
                 </xsl:call-template>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = '$1 - $1,000,000'" />
                    <xsl:with-param name="Label" select="'$1 - $1,000,000'" />
                 </xsl:call-template>           
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = '$1 - $5,000,000'" />
                    <xsl:with-param name="Label" select="'$1 - $5,000,000'" />
                 </xsl:call-template>             
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = '$1,000,001 - $5,000,000'" />
                    <xsl:with-param name="Label" select="'$1,000,001 - $5,000,000'" />
                 </xsl:call-template>             
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = '$5,000,001 - $25,000,000'" />
                    <xsl:with-param name="Label" select="'$5,000,001 - $25,000,000'" />
                 </xsl:call-template>             
              </tr>
              <tr>  
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = '$5,000,001 - $25,000,000'" />
                    <xsl:with-param name="Label" select="'$5,000,001 - $25,000,000'" />
                 </xsl:call-template>          
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = '$25,000,001 - $50,000,000'" />
                    <xsl:with-param name="Label" select="'$25,000,001 - $50,000,000'" />
                 </xsl:call-template>             
              </tr>
              <tr>           
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = '$25,000,001 - $100,000,000'" />
                    <xsl:with-param name="Label" select="'$25,000,001 - $100,000,000'" />
                 </xsl:call-template>            
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = '$50,000,001 - $100,000,000'" />
                    <xsl:with-param name="Label" select="'$50,000,001 - $100,000,000'" />
                 </xsl:call-template>             
              </tr>
              <tr>       
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange = 'Over $100,000,000'" />
                    <xsl:with-param name="Label" select="'Over $100,000,000'" />
                 </xsl:call-template>             
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = 'Over $100,000,000'" />
                    <xsl:with-param name="Label" select="'Over $100,000,000'" />
                 </xsl:call-template>             
              </tr>
              <tr>       
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange  = 'Decline to Disclose'" />
                    <xsl:with-param name="Label" select="'Decline to Disclose'" />
                 </xsl:call-template>             
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = 'Decline to Disclose'" />
                    <xsl:with-param name="Label" select="'Decline to Disclose'" />
                 </xsl:call-template>             
              </tr>
              <tr>      
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="revenueRange  = 'Not Applicable'" />
                    <xsl:with-param name="Label" select="'Not Applicable'" />
                 </xsl:call-template>             
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="aggregateNetAssetValueRange = 'Not Applicable'" />
                    <xsl:with-param name="Label" select="'Not Applicable'" />
                 </xsl:call-template>              
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section6_after_X0707">
     <p class="SectionTitle">6. Federal Exemption(s) and Exclusion(s) Claimed (select all that apply)</p>
     <xsl:for-each select="offeringData/federalExemptionsExclusions">
        <table width="80%" border="0" summary="Federal Exemptions and Exclusions Claimed">
           <tbody>
              <tr>
                 <td> 
                    <table border="0" summary="Rule 504, 506 and Section 4(a)(5) Exemptions">
                       <tbody>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04'" />
                                   <xsl:with-param name="Label" select="'Rule 504(b)(1) (not (i), (ii) or (iii))'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.1'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(i)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.2'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(ii)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.3'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(iii)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='06b'" />
                                   <xsl:with-param name="Label" select="'Rule 506(b)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='06c'" />
                                   <xsl:with-param name="Label" select="'Rule 506(c)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='4a5'" />
                                   <xsl:with-param name="Label" select="'Securities Act Section 4(a)(5)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                       </tbody>
                    </table>
                 </td>
                 <td>
                    <xsl:call-template name="Section6_Subsection3">
                       <xsl:with-param name="Do3c" select="'Y'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section6_after_X0706">
     <p class="SectionTitle">6. Federal Exemption(s) and Exclusion(s) Claimed (select all that apply)</p>
     <xsl:for-each select="offeringData/federalExemptionsExclusions">
        <table width="80%" border="0" summary="Federal Exemptions and Exclusions Claimed">
           <tbody>
              <tr>
                 <td> 
                    <table border="0" summary="Rule 504, 505, 506 and Section 4(a)(5) Exemptions">
                       <tbody>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04'" />
                                   <xsl:with-param name="Label" select="'Rule 504(b)(1) (not (i), (ii) or (iii))'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.1'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(i)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.2'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(ii)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='04.3'" />
                                   <xsl:with-param name="Label" select="'Rule 504 (b)(1)(iii)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='05'" />
                                   <xsl:with-param name="Label" select="'Rule 505'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='06b'" />
                                   <xsl:with-param name="Label" select="'Rule 506(b)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='06c'" />
                                   <xsl:with-param name="Label" select="'Rule 506(c)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                          <tr>
                             <td>
                                <xsl:call-template name="BuildSoloRadioTD">
                                   <xsl:with-param name="TestThis" select="item='4a5'" />
                                   <xsl:with-param name="Label" select="'Securities Act Section 4(a)(5)'" />
                                </xsl:call-template>
                             </td>
                          </tr>
                       </tbody>
                    </table>
                 </td>
                 <td>
                    <xsl:call-template name="Section6_Subsection3">
                       <xsl:with-param name="Do3c" select="'Y'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section6">
     <xsl:param name="schemaVersion" />
     <p class="SectionTitle">6. Federal Exemption(s) and Exclusion(s) Claimed (select all that apply)</p>
     <xsl:for-each select="offeringData/federalExemptionsExclusions">
        <table width="80%" border="0" summary="Federal Exemptions and Exclusions Claimed">
           <tbody>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='04'" />
                    <xsl:with-param name="Label" select="'Rule 504(b)(1) (not (i), (ii) or (iii))'" />
                 </xsl:call-template>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='05'" />
                    <xsl:with-param name="Label" select="'Rule 505'" />
                 </xsl:call-template>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='04.1'" />
                    <xsl:with-param name="Label" select="'Rule 504 (b)(1)(i)'" />
                 </xsl:call-template>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='06'" />
                    <xsl:with-param name="Label" select="'Rule 506'" />
                  </xsl:call-template>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='04.2'" />
                    <xsl:with-param name="Label" select="'Rule 504 (b)(1)(ii)'" />
                 </xsl:call-template>
                 <xsl:choose>
                    <xsl:when test="(number(substring($schemaVersion,2))=705)">
                       <xsl:call-template name="BuildSoloRadioTD">
                          <xsl:with-param name="TestThis" select="item='46'" />
                          <xsl:with-param name="Label" select="'Securities Act Section 4(6)'" />
                       </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                       <xsl:call-template name="BuildSoloRadioTD">
                         <xsl:with-param name="TestThis" select="item='46'" />
                         <xsl:with-param name="Label" select="'Securities Act Section 4(5)'" />
                       </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="item='04.3'" />
                    <xsl:with-param name="Label" select="'Rule 504 (b)(1)(iii)'" />
                 </xsl:call-template>
                 <xsl:call-template name="Section6_Subsection3c"/>
              </tr>
              <tr>
                 <td colspan="2"></td>
                 <td colspan="2">
                    <xsl:call-template name="Section6_Subsection3">
                       <xsl:with-param name="Do3c" select="'N'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section6_Subsection3c">
      <xsl:call-template name="BuildSoloRadioTD">
         <xsl:with-param name="TestThis" select="item='3C'" />
         <xsl:with-param name="Label" select="'Investment Company Act Section 3(c)'" />
      </xsl:call-template>
   </xsl:template>

   <xsl:template name="Section6_Subsection3">
     <xsl:param name="Do3c" />
     <table border="0" width="100%" summary="Federal Exemptions and Exclusions Claimed, Section 3">
        <tbody>
           <xsl:if test="$Do3c='Y'">
              <tr>
                 <td colspan="2">
                    <table border="0" width="100%" summary="Federal Exemptions and Exclusions Claimed, Section 3">
                       <tbody>
                          <tr>
                             <xsl:call-template name="Section6_Subsection3c" />
                         </tr>
                      </tbody>
                    </table>
                 </td>
              </tr>
           </xsl:if>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.1'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(1)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.9'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(9)&#160;&#160;'" />
                 </xsl:call-template>
              </td>
           </tr>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.2'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(2)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.10'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(10)'" />
                 </xsl:call-template>
              </td>
           </tr>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.3'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(3)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.11'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(11)'" />
                 </xsl:call-template>
              </td>
           </tr>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.4'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(4)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.12'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(12)'" />
                 </xsl:call-template>
              </td>
           </tr>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.5'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(5)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.13'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(13)'" />
                 </xsl:call-template>
              </td>
           </tr>
           <tr>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="item='3C.6'" />
                    <xsl:with-param name="Label1" select="'Section 3(c)(6)'" />
                    <xsl:with-param name="TestThis2" select="item='3C.14'" />
                    <xsl:with-param name="Label2" select="'Section 3(c)(14)'" />
                 </xsl:call-template>
              </td>
           </tr>
           <xsl:call-template name="BuildCheckBoxTR">
              <xsl:with-param name="TestThis" select="item='3C.7'" />
              <xsl:with-param name="Label" select="'Section 3(c)(7)'" />
              <xsl:with-param name="AppendEmptyCell" select="false()" />
           </xsl:call-template>
         </tbody>
      </table>
   </xsl:template>

   <xsl:template name="Section7">
     <p class="SectionTitle">7. Type of Filing</p>
     <xsl:for-each select="offeringData/typeOfFiling">
        <table border="0" summary="Type of Filing">
           <tbody>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestNotThis" select="newOrAmendment/isAmendment" />
                    <xsl:with-param name="Label" select="'New Notice'" />
                 </xsl:call-template>
                 <td colspan="2"> </td>
                 <td class="FormText">Date of First Sale</td>
                 <xsl:apply-templates select="dateOfFirstSale/value" mode="NormalTDL"/>
                 <td colspan="2"> </td>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="dateOfFirstSale/yetToOccur" />
                    <xsl:with-param name="Label" select="'First Sale Yet to Occur'" />
                 </xsl:call-template>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="newOrAmendment/isAmendment" />
                    <xsl:with-param name="Label" select="'Amendment'" />
                 </xsl:call-template>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section8">
     <p class="SectionTitle">8. Duration of Offering</p>
     <table border="0" summary="Duration of Offering">
        <tbody>
           <tr>
              <td class="FormText">Does the Issuer intend this offering to last more than one year?</td>
              <td> </td>
              <td>
                 <xsl:call-template name="Build2Radios">
                    <xsl:with-param name="TestThis1" select="offeringData/durationOfOffering/moreThanOneYear" />
                    <xsl:with-param name="Label1" select="'Yes'" />
                    <xsl:with-param name="TestNotThis2" select="offeringData/durationOfOffering/moreThanOneYear" />
                    <xsl:with-param name="Label2" select="'No'" />
                 </xsl:call-template>
              </td>              
           </tr>
        </tbody>
     </table>
   </xsl:template>

   <xsl:template name="Section9">
     <p class="SectionTitle">9. Type(s) of Securities Offered (select all that apply)</p>
     <xsl:for-each select="offeringData/typesOfSecuritiesOffered">
        <table border="0" summary="Types of Securities Offered">
           <colgroup span="4">
              <col width="2" />
              <col width="50%" />
              <col width="2" />
              <col width="50%" />
           </colgroup>
           <tbody>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isEquityType" />
                    <xsl:with-param name="Label" select="'Equity'" />
                 </xsl:call-template>            
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isPooledInvestmentFundType" />
                    <xsl:with-param name="Label" select="'Pooled Investment Fund Interests'" />
                 </xsl:call-template>
              </tr>
              <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isDebtType" />
                    <xsl:with-param name="Label" select="'Debt'" />
                 </xsl:call-template>                           
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isTenantInCommonType" />
                    <xsl:with-param name="Label" select="'Tenant-in-Common Securities'" />
                 </xsl:call-template>         
              </tr>
              <tr>           
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isOptionToAcquireType" />
                    <xsl:with-param name="Label" select="'Option, Warrant or Other Right to Acquire Another Security'" />
                 </xsl:call-template>                    
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isMineralPropertyType" />
                    <xsl:with-param name="Label" select="'Mineral Property Securities'" />
                 </xsl:call-template>            
               </tr>
               <tr>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isSecurityToBeAcquiredType" />
                    <xsl:with-param name="Label" select="'Security to be Acquired Upon Exercise of Option, Warrant or Other Right to Acquire Security'" />
                 </xsl:call-template>
                 <xsl:call-template name="BuildSoloRadioTD">
                    <xsl:with-param name="TestThis" select="isOtherType" />
                    <xsl:with-param name="Label" select="'Other (describe)'" />
                 </xsl:call-template>
              </tr>
              <tr>
                 <td colspan="2"> </td>
                 <td colspan="2">
                    <xsl:apply-templates select="descriptionOfOtherType" mode="Normal"/>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section10">
     <p class="SectionTitle">10. Business Combination Transaction</p>
     <xsl:for-each select="offeringData/businessCombinationTransaction">
        <table border="0" summary="Business Combination Transaction" width="80%">
           <tbody>
              <tr>
                 <td class="FormText">Is this offering being made in connection with a business combination transaction, such as a merger, acquisition or exchange offer?</td>
                 <td> </td>
                 <td>
                    <xsl:call-template name="Build2Radios">
                       <xsl:with-param name="TestThis1" select="isBusinessCombinationTransaction" />
                       <xsl:with-param name="Label1" select="'Yes'" />
                       <xsl:with-param name="TestNotThis2" select="isBusinessCombinationTransaction" />
                       <xsl:with-param name="Label2" select="'No'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
        <p class="FormText">Clarification of Response (if Necessary):</p>
        <xsl:apply-templates select="clarificationOfResponse" mode="NormalText"/>
      </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section11">
     <p class="SectionTitle">11. Minimum Investment</p>
     <table border="0" summary="Minimum Investment">
         <tbody>
            <tr>
               <td class="FormText">Minimum investment accepted from any outside investor</td>
               <xsl:apply-templates select="offeringData/minimumInvestmentAccepted" mode="DollarTD"/>
               <td class="FormText">USD</td>
            </tr>
         </tbody>
      </table>
   </xsl:template>

   <xsl:template name="Section12">
     <p class="SectionTitle">12. Sales Compensation</p>
     <xsl:choose>
        <xsl:when test="count(  offeringData/salesCompensationList/recipient  ) &gt;0">
           <xsl:for-each select="offeringData/salesCompensationList/recipient">
              <div>
                 <table width="100%" summary="Sales Compensation">
                    <tr>
                       <td class="FormText">Recipient</td>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="string-length(recipientCRDNumber)=0 or recipientCRDNumber='None'" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'Recipient CRD Number'" />
                       </xsl:call-template>
                    </tr>
                    <tr>
                       <xsl:apply-templates select="recipientName" mode="NormalTDL" />
                       <xsl:apply-templates select="recipientCRDNumber" mode="NormalTDLZ" />
                    </tr>  
                    <tr>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="string-length(associatedBDCRDNumber)=0 or associatedBDCRDNumber='None'" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'(Associated) Broker or Dealer'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="string-length(associatedBDCRDNumber)=0 or associatedBDCRDNumber='None'" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'(Associated) Broker or Dealer CRD Number'" />
                       </xsl:call-template>
                    </tr>
                    <tr>
                       <xsl:apply-templates select="associatedBDName" mode="NormalTDL" />
                       <xsl:apply-templates select="associatedBDCRDNumber" mode="NormalTDLZ" />
                    </tr> 
                    <xsl:call-template name="SA1-SA2-Label" />
                    <tr>
                       <xsl:apply-templates select="recipientAddress/street1" mode="NormalTDL" />
                       <xsl:apply-templates select="recipientAddress/street2" mode="NormalTDL" />
                    </tr>
                    <tr>
                       <td class="FormText">City</td>
                       <td class="FormText">State/Province/Country</td>
                       <td class="FormText">ZIP/Postal Code</td>
                    </tr>
                    <tr>
                       <xsl:call-template name="GetCityStateZip">
                          <xsl:with-param name="Node" select="./recipientAddress" />
                       </xsl:call-template>
                    </tr>
                    <tr>
                    <xsl:call-template name="BuildCheckBoxTD">
                       <xsl:with-param name="TestThis" select="string-length(statesOfSolicitationList/value) &gt;0" />
                       <xsl:with-param name="Label" select="'All States'" />
                       <xsl:with-param name="AppendEmptyCell" select="false()" />
                       <xsl:with-param name="LeftLabel" select="'State(s) of Solicitation (select all that apply)'" />
                       <xsl:with-param name="LeftLabel2" select="'Check “All States” or check individual States'" />
                    </xsl:call-template>
                    <xsl:call-template name="BuildCheckBoxTD">
                       <xsl:with-param name="TestThis" select="foreignSolicitation" />
                       <xsl:with-param name="Label" select="'Foreign/non-US'" />
                       <xsl:with-param name="AppendEmptyCell" select="false()" />
                    </xsl:call-template>
                    </tr>
                    <tr>
                       <td>
                          <xsl:if test="string-length(statesOfSolicitationList/value)=0">
                             <xsl:choose>
                                <xsl:when test="count(statesOfSolicitationList/state) &gt;0">
                                   <table border="1" summary="State Of Solicitation List State">
                                      <tbody>
                                         <xsl:choose>
                                            <xsl:when test="count( statesOfSolicitationList/state ) = count( statesOfSolicitationList/description )">
                                               <xsl:apply-templates select="statesOfSolicitationList/description" mode="multiple_rows" />
                                            </xsl:when>
                                            <xsl:when test="count( statesOfSolicitationList/state ) &lt; count( statesOfSolicitationList/description )">
                                               <xsl:apply-templates select="statesOfSolicitationList/description" mode="multiple_rows" />
                                            </xsl:when>
                                            <xsl:otherwise>
                                               <xsl:apply-templates select="statesOfSolicitationList/state" mode="multiple_rows" />
                                            </xsl:otherwise>
                                         </xsl:choose>
                                      </tbody>
                                   </table>
                                </xsl:when>
                             </xsl:choose>
                          </xsl:if>
                       </td>
                    </tr>
                 </table>
              </div>
              <hr/>
           </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
           <div>
              <table width="100%" summary="Sales Compensation List">
                 <tbody>
                    <tr>
                       <td class="FormText">Recipient</td>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="count(offeringData/salesCompensationList/recipient)=0" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'Recipient CRD Number'" />
                       </xsl:call-template>
                    </tr>
                    <tr>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="count(offeringData/salesCompensationList/recipient)=0" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'(Associated) Broker or Dealer'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="count(offeringData/salesCompensationList/recipient)=0" />
                          <xsl:with-param name="Label" select="'None'" />
                          <xsl:with-param name="LeftLabel" select="'(Associated) Broker or Dealer CRD Number'" />
                       </xsl:call-template>
                    </tr>
                    <xsl:call-template name="SA1-SA2-Label" />
                    <tr>
                       <td class="FormText">City</td>
                       <td class="FormText">State/Province/Country</td>
                       <td class="FormText">ZIP/Postal Code</td>
                    </tr>
                    <tr>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestThis" select="count(offeringData/salesCompensationList/recipient) &gt;0" />
                          <xsl:with-param name="Label" select="'All States'" />
                          <xsl:with-param name="LeftLabel" select="'State(s) of Solicitation (select all that apply)'" />
                          <xsl:with-param name="LeftLabel2" select="'Check “All States” or check individual States'" />
                       </xsl:call-template>
                       <xsl:call-template name="BuildCheckBoxTD">
                          <xsl:with-param name="TestNotThis" select="string-length(foreignSolicitation)=0" />
                          <xsl:with-param name="Label" select="'Foreign/non-US'" />
                          <xsl:with-param name="AppendEmptyCell" select="false()" />
                       </xsl:call-template>
                    </tr>
                 </tbody>
              </table>
           </div> 
        </xsl:otherwise>
     </xsl:choose>
   </xsl:template>
   
   <xsl:template name="Section13">
     <p class="SectionTitle">13. Offering and Sales Amounts</p>
     <xsl:for-each select="offeringData/offeringSalesAmounts">
        <table border="0" summary="Offering and Sales Amounts">
           <tbody>
              <tr>
                 <td class="FormText">Total Offering Amount</td>
                 <xsl:if test="totalOfferingAmount='Indefinite'">
                    <td> </td>
                 </xsl:if>
                 <xsl:if test="not(totalOfferingAmount='Indefinite')">
                    <xsl:apply-templates select="totalOfferingAmount" mode="DollarTD"/>
                 </xsl:if>
                 <td class="FormText">USD</td>
                 <td>
                    <xsl:call-template name="BuildCheckBox">
                       <xsl:with-param name="TestThis" select="totalOfferingAmount = 'Indefinite'" />
                       <xsl:with-param name="Label" select="'Indefinite'" />
                       <xsl:with-param name="LeftLabel" select="'or'" />
                    </xsl:call-template>
                 </td>
              </tr>
              <tr>
                 <td class="FormText">Total Amount Sold</td>
                 <xsl:apply-templates select="totalAmountSold" mode="DollarTD"/>
                 <td class="FormText">USD</td>
              </tr>
              <tr>
                 <td class="FormText">Total Remaining to be Sold</td>
                 <xsl:if test="totalOfferingAmount='Indefinite'">
                    <td> </td>
                 </xsl:if>
                 <xsl:if test="not(totalRemaining='Indefinite')">
                   <xsl:apply-templates select="totalRemaining" mode="DollarTD"/>
                 </xsl:if>
                 <td class="FormText">USD</td>
                 <td>
                    <xsl:call-template name="BuildCheckBox">
                       <xsl:with-param name="TestThis" select="totalRemaining = 'Indefinite'" />
                       <xsl:with-param name="Label" select="'Indefinite'" />
                       <xsl:with-param name="LeftLabel" select="'or'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
        <p class="FormText">Clarification of Response (if Necessary):</p>
        <xsl:apply-templates select="clarificationOfResponse" mode="Normal"/>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section14">
     <p class="SectionTitle">14. Investors</p>
     <xsl:for-each select="offeringData/investors">
        <table border="0" summary="Investors">
           <tbody>
              <tr>
                 <td valign="middle">
                    <xsl:call-template name="BuildCheckBox">
                       <xsl:with-param name="TestThis" select="hasNonAccreditedInvestors" />
                    </xsl:call-template>
                 </td>
                 <td class="FormText">Select if securities in the offering have been or may be sold to persons who do not qualify as accredited investors, and enter the number of such non-accredited investors who already have invested in the offering.</td>
                 <td vAlign="top">
                    <table border="1" width="100" summary="Investors, Number Non Accredited Investors">
                       <tbody>
                          <tr>                        
                             <xsl:apply-templates select="numberNonAccreditedInvestors" mode="NormalTDL" />  
                          </tr>
                       </tbody>
                    </table>
                 </td>
              </tr>
              <tr>
                 <td> </td>
                 <td class="FormText">Regardless of whether securities in the offering have been or may be sold to persons who do not qualify as accredited investors, enter the total number of investors who already have invested in the offering:</td>
                 <td vAlign="top">
                    <table border="1" width="100" summary="Investors, Total NumberAlready Invested">
                       <tbody>
                          <tr>    
                             <xsl:apply-templates select="totalNumberAlreadyInvested" mode="NormalTDL"/>                       
                          </tr>
                       </tbody>
                    </table>
                 </td>
              </tr>
           </tbody>
        </table>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section15">
     <p class="SectionTitle">15. Sales Commissions &amp; Finder's Fees Expenses</p>
     <p class="FormText">Provide separately the amounts of sales commissions and finders fees expenses, if any. If the amount of an expenditure is not known, provide an estimate and check the box next to the amount.</p>
     <xsl:for-each select="offeringData/salesCommissionsFindersFees">
        <table border="0" summary="Sales Commissions &amp; Finder's Fees Expenses">
           <tbody>
              <tr>
                 <td class="FormTextR" width="200">Sales Commissions</td>
                 <xsl:apply-templates select="salesCommissions/dollarAmount" mode="DollarTD"/>											
                 <td class="FormText">USD</td>
                 <td align="right">
                    <xsl:call-template name="BuildCheckBox">
                       <xsl:with-param name="TestThis" select="salesCommissions/isEstimate" />
                       <xsl:with-param name="Label" select="'Estimate'" />
                    </xsl:call-template>
                 </td>
              </tr>
              <tr>
                 <td class="FormTextR" width="200">Finders&apos; Fees</td>	
                 <xsl:apply-templates select="findersFees/dollarAmount" mode="DollarTD"/>										
                 <td class="FormText">USD</td>
                 <td align="right">
                    <xsl:call-template name="BuildCheckBox">
                       <xsl:with-param name="TestThis" select="findersFees/isEstimate" />
                       <xsl:with-param name="Label" select="'Estimate'" />
                    </xsl:call-template>
                 </td>
              </tr>
           </tbody>
        </table>
        <p class="FormText">Clarification of Response (if Necessary):</p>
        <xsl:apply-templates select="clarificationOfResponse" mode="Normal"/>
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Section16">
      <p class="SectionTitle">16. Use of Proceeds</p>
      <p class="FormText">Provide the amount of the gross proceeds of the offering that has been or is proposed to be used for payments to any of the persons required to be named as executive officers, directors or promoters in response to Item 3 above. If the amount is unknown, provide an estimate and check the box next to the amount.</p>										
      <xsl:for-each select="offeringData/useOfProceeds">
         <table border="0" summary="Use of Proceeds">
            <tbody>
               <tr>
                  <td align="right" scope="col" vAlign="middle" width="200"> </td>											
                  <xsl:apply-templates select="grossProceedsUsed/dollarAmount" mode="DollarTD"/>
                  <td class="FormText">USD</td>
                  <td align="right">
                     <xsl:call-template name="BuildCheckBox">
                        <xsl:with-param name="TestThis" select="grossProceedsUsed/isEstimate" />
                        <xsl:with-param name="Label" select="'Estimate'" />
                     </xsl:call-template>
                  </td>
               </tr>
            </tbody>
         </table>
         <p class="FormText">Clarification of Response (if Necessary):</p>
         <xsl:apply-templates select="clarificationOfResponse" mode="Normal"/>
      </xsl:for-each>
   </xsl:template>

   <xsl:template name="Signature">
     <p class="SectionTitle">Signature and Submission</p>
     <p class="FormTitle2">Please verify the information you have entered and review the Terms of Submission below before signing and clicking SUBMIT below to file this notice.</p>
     <p class="FormTitle2">Terms of Submission</p>
     <table bgColor="#d5d5d5" border="0" summary="Signature and Submission" class="FormText">
        <tbody>
           <tr>
              <td>In submitting this notice, each issuer named above is:</td>
           </tr>
           <tr>
              <td>
                 <ul>
                    <li>Notifying the SEC and/or each State in which this notice is filed of the offering of 
                    securities described and undertaking to furnish them, upon written request, in the accordance with applicable
                    law, the information furnished to offerees.*</li>
                 </ul>
                 <ul>
                    <li>Irrevocably appointing each of the Secretary of the SEC and, the Securities Administrator 
                    or other legally designated officer of the State in which the issuer maintains its principal 
                    place of business and any State in which this notice is filed, as its agents for service of 
                    process, and agreeing that these persons may accept service on its behalf, of any notice, 
                    process or pleading, and further agreeing that such service may be made by registered or 
                    certified mail, in any Federal or state action, administrative proceeding, or arbitration 
                    brought against the issuer in any place subject to the jurisdiction of the United States, if the 
                    action, proceeding or arbitration (a) arises out of any activity in connection with the 
                    offering of securities that is the subject of this notice, and (b) is founded, directly or 
                    indirectly, upon the provisions of:  (i) the Securities Act of 1933, the Securities Exchange 
                    Act of 1934, the Trust Indenture Act of 1939, the Investment Company Act of 1940, or the 
                    Investment Advisers Act of 1940, or any rule or regulation under any of these statutes, or (ii) 
                    the laws of the State in which the issuer maintains its principal place of business or any State 
                    in which this notice is filed.</li>
                 </ul>
                 <ul>
            <xsl:choose>
               <xsl:when test="(number(substring(schemaVersion,2))>707)">
                  <li>Certifying that, if the issuer is claiming a Regulation D exemption for the offering, the issuer is not disqualified from relying on Rule 504 or Rule 506 for one of the reasons stated in Rule 504(b)(3) or Rule 506(d).</li>
               </xsl:when>
               <xsl:when test="(number(substring(schemaVersion,2))=707)">
                  <li>Certifying that, if the issuer is claiming a Regulation D exemption for the offering, the issuer is not disqualified from relying on Regulation D for one of the reasons stated in Rule 505(b)(2)(iii) or Rule 506(d).</li>
               </xsl:when>
               <xsl:otherwise>
                    <li>Certifying that, if the issuer is claiming a Rule 505 exemption, the issuer is not disqualified 
                    from relying on Rule 505 for one of the reasons stated in Rule 505(b)(2)(iii).</li>
               </xsl:otherwise>
            </xsl:choose>

                 </ul>
              </td>
           </tr>
        </tbody>
     </table>
     <p class="FormText">Each Issuer identified above has read this notice, knows the contents to be true, and has duly caused this notice to be signed on its behalf by the undersigned duly authorized person.</p>
     <p class="FormText">For signature, type in the signer's name or other letters or characters adopted or authorized as the signer's signature.</p>
     <xsl:if test="count(issuerList)&gt;0">
        <xsl:if test="offeringData/signatureBlock/authorizedRepresentative=1 or offeringData/signatureBlock/authorizedRepresentative='true' or offeringData/signatureBlock/authorizedRepresentative='1' or offeringData/signatureBlock/authorizedRepresentative='YES'" >
           <xsl:call-template name="BuildCheckBox">
              <xsl:with-param name="TestThis" select="offeringData/signatureBlock/authorizedRepresentative" />
              <xsl:with-param name="Label" select="'I also am a duly authorized representative of the other issuer(s) identified in Item 1 above and authorized to sign on their behalf.'" />
           </xsl:call-template>   
        </xsl:if>
     </xsl:if>
     <xsl:for-each select="offeringData">
        <xsl:for-each select="signatureBlock">
           <table border="1" width="100%" summary="Signature Block">
              <thead>
                 <tr>
                    <th class="FormTextC">Issuer</th>
                    <th class="FormTextC">Signature</th>
                    <th class="FormTextC">Name of Signer</th>
                    <th class="FormTextC">Title</th>
                    <th class="FormTextC">Date</th>
                 </tr>
               </thead>
               <tbody>
                  <xsl:if test="(count(issuerList)&gt;0) and (authorizedRepresentative=1 or authorizedRepresentative='true' or authorizedRepresentative='1' or authorizedRepresentative='YES')" >
                     <tr>
                        <td class="FormData">All Issuers</td>
                        <xsl:apply-templates select="signature/signatureName" mode="NormalTDL"/>
                        <xsl:apply-templates select="signature/nameOfSigner" mode="NormalTDL"/>
                        <xsl:apply-templates select="signature/signatureTitle" mode="NormalTDL"/>
                        <xsl:apply-templates select="signature/signatureDate" mode="NormalTDL"/>
                     </tr>
                  </xsl:if>
                  <xsl:if test="not((count(issuerList)&gt;0) and (authorizedRepresentative=1 or authorizedRepresentative='true' or authorizedRepresentative='1' or authorizedRepresentative='YES'))" >
                     <xsl:for-each select="signature">
                        <tr>
                           <xsl:apply-templates select="issuerName" mode="NormalTDL"/>
                           <xsl:apply-templates select="signatureName" mode="NormalTDL"/>
                           <xsl:apply-templates select="nameOfSigner" mode="NormalTDL"/>
                           <xsl:apply-templates select="signatureTitle" mode="NormalTDL"/>
                           <xsl:apply-templates select="signatureDate" mode="NormalTDL"/>
                        </tr>
                     </xsl:for-each>
                  </xsl:if>
               </tbody>
            </table>  
         </xsl:for-each>
      </xsl:for-each>
      <p class="FormEMText">Persons who respond to the collection of information contained in this form are not required to respond unless the form displays a currently valid OMB number.</p>
      <p class="SmallFormText">* This undertaking does not affect any limits Section 102(a) of the National Securities Markets
        Improvement Act of 1996 ("NSMIA") [Pub. L. No. 104-290, 110 Stat. 3416 (Oct. 11, 1996)] imposes on the ability of States to
        require information. As a result, if the securities that are the subject of this Form D are "covered securities" for purposes 
        of NSMIA, whether in all instances or due to the nature of the offering that is the subject of this Form D, States cannot
        routinely require offering materials under this undertaking or otherwise and can require offering materials only to the
        extent NSMIA permits them to do so under NSMIA's preservation of their anti-fraud authority.</p>
   </xsl:template>
   
   <xsl:template name="BuildCheckBoxTD">
      <xsl:param name="TestThis" />
      <xsl:param name="Label" />
      <xsl:param name="LeftLabel"/>
      <xsl:param name="LeftLabel2"/>
      <td>
         <xsl:call-template name="BuildCheckBox">
            <xsl:with-param name="TestThis" select="$TestThis" />
            <xsl:with-param name="Label" select="$Label" />
            <xsl:with-param name="LeftLabel" select="$LeftLabel" />
            <xsl:with-param name="LeftLabel2" select="$LeftLabel2" />
         </xsl:call-template>
      </td>
   </xsl:template>
   
   <xsl:template name="BuildCheckBoxTR">
      <xsl:param name="TestThis" />
      <xsl:param name="Label" />
      <xsl:param name="LeftLabel"/>
      <xsl:param name="AppendEmptyCell" select="true()"/>
      <tr>
         <xsl:if test="$AppendEmptyCell">
            <td> </td>
         </xsl:if>
         <xsl:call-template name="BuildCheckBoxTD">
            <xsl:with-param name="TestThis" select="$TestThis" />
            <xsl:with-param name="Label" select="$Label" />
            <xsl:with-param name="LeftLabel" select="$LeftLabel" />
         </xsl:call-template>
      </tr>
   </xsl:template>
   
   <xsl:template name="SA1-SA2-Label">
      <xsl:param name="colspan" />
      <xsl:if test="not($colspan='')">
         <tr>
            <xsl:element name="th">
               <xsl:attribute name="class">FormText</xsl:attribute>
               <xsl:attribute name="colspan"><xsl:value-of select="$colspan" /></xsl:attribute>Street Address 1</xsl:element>
            <xsl:element name="th">
               <xsl:attribute name="class">FormText</xsl:attribute>
               <xsl:attribute name="colspan"><xsl:value-of select="$colspan" /></xsl:attribute>Street Address 2</xsl:element>
         </tr>
      </xsl:if>
      <xsl:if test="$colspan=''">
         <tr>
            <th class="FormText">Street Address 1</th>
            <th class="FormText">Street Address 2</th>
         </tr>
      </xsl:if>
   </xsl:template>

   <xsl:template name="GetCityStateZip">
      <xsl:param name="Node" />
      <xsl:apply-templates select="$Node/city" mode="NormalTDL"/>
      <xsl:choose>
         <xsl:when test="count( $Node/stateOrCountryDescription ) &gt;0">
            <xsl:apply-templates select="$Node/stateOrCountryDescription" mode="NormalTDL"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:apply-templates select="$Node/stateOrCountry" mode="NormalTDL"/>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="$Node/zipCode" mode="NormalTDLZ"/>
   </xsl:template>
</xsl:stylesheet>
