<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:import href="TA-Common_X01.xsl" />
   <xsl:import href="TA-Sections.xsl" />
   <xsl:import href="SEC-Common.xsl" />

<!--
   XSL Stylesheet for SEC Forms [TA-1, TA-1/A, TA-2, TA-2/A, and TA-W] 
   Uses XSL Stylesheets:  TA-Common_X01.xsl, TA-Sections.xsl, SEC-Common.xsl

   Version 1.0 - Dated November 21, 2006
   Created By: SAIC 
   Created for: SEC
   -->
   <xsl:variable name="this" select="/" />

   <xsl:output method="html" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" media-type="application/xml" />

   <xsl:template match="/edgarSubmission">
      <html>
         <head>
            <title>SEC FORM 
            <xsl:value-of select="submissionType" />
            </title>
            <xsl:call-template name="CSS"/>
         </head>

         <body>
            <xsl:choose>
               <xsl:when test="starts-with(submissionType, 'TA-1')">
                  <xsl:call-template name="FormTA1Header" />
               </xsl:when>
               <xsl:when test="starts-with(submissionType, 'TA-2')">
                  <xsl:call-template name="FormTA2Header" />
               </xsl:when>
               <xsl:when test="(submissionType='TA-W')">
                  <xsl:call-template name="FormTAWHeader" />
               </xsl:when>
               <xsl:otherwise>NO HEADER FOUND MATCHING TYPE</xsl:otherwise>
            </xsl:choose>

            <xsl:call-template name="Section1" />
            <xsl:call-template name="Section2" />
            <xsl:call-template name="Section3" />
            <xsl:call-template name="Section4" />
            <xsl:call-template name="Section5" />
            <xsl:call-template name="Section6" />
            <xsl:call-template name="Section7" />
            <xsl:call-template name="Section8" />
            <xsl:call-template name="Section9" />
            <xsl:call-template name="Section10" />
            <xsl:call-template name="Section11" />
            <xsl:call-template name="Section12" />
            <xsl:call-template name="Section13" />
            <hr />
         </body>
      </html>
   </xsl:template>

   <xsl:template name="FormTA1Header">
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="TA-1 Form Header Information">
         <tr>
            <td width="10%" colspan="2" valign="top" align="left"></td>
            <td rowspan="1" width="70%" valign="middle" align="center">
               <xsl:call-template name="TitleBox">
                  <xsl:with-param name="FormTitle">FORM TA-1</xsl:with-param>
                  <xsl:with-param name="FormTitle1">UNIFORM FORM FOR REGISTRATION AS A TRANSFER AGENT AND FOR AMENDMENTTO REGISTRATION PURSUANT TO SECTION 17A OF THESECURITIES EXCHANGE ACT OF 1934</xsl:with-param>
               </xsl:call-template>
            </td>
            <td rowspan="1" width="20%" valign="top" align="center">
               <xsl:call-template name="OMBBox">
                  <xsl:with-param name="OMBNumber" select="'3235-0084'" />
                  <xsl:with-param name="OMBExpireDate" select="'July 31, 2018'" />
                  <xsl:with-param name="OMBHours" select="'1.50'" />
               </xsl:call-template>
            </td>
         </tr>
         <tr>
            <td class="FormText" valign="middle" align="right">GENERAL:</td>
            <td colspan="3" class="FormText" align="left">Form TA-1 is to be used to register or amend registration as a transfer agent with the Comptroller of the Currency, the Board of Governors of the Federal Reserve System, the Federal Deposit Insurance Corporation or the Securities and Exchange Commission pursuant to Section 17A of the Securities Exchange Act of 1934. Read all instructions before completing this form. Please print or type all responses.</td>
         </tr>
      </table>

      <span class="FormText">Form Version:</span>
      <xsl:apply-templates select="formVersion" mode="NormalText" />
      <hr />
   </xsl:template>

   <xsl:template name="FormTA2Header">
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="TA-2 Form Header Information">
         <tr>
            <td width="20%" colspan="2" valign="top" align="left">
               <span class="FormText">File Number:</span>
               <br />
               <xsl:call-template name="createFileNoLink">
                  <xsl:with-param name="aFileNumber" select="filer/fileNumber" />
                  <xsl:with-param name="label" select="filer/fileNumber" />
               </xsl:call-template>
               <br />
               <span class="FormText">For the reporting period ended</span>
               <xsl:apply-templates select="periodOfReport" mode="formatDate" />
            </td>
            <td rowspan="1" width="60%" valign="middle" align="center">
               <xsl:call-template name="TitleBox">
                  <xsl:with-param name="FormTitle">FORM TA-2</xsl:with-param>
                  <xsl:with-param name="FormTitle1">FORM FOR REPORTING ACTIVITIES OF TRANSFER AGENTS REGISTERED PURSUANT TO SECTION 17A OF THE SECURITIES EXCHANGE ACT OF 1934</xsl:with-param>
                  <xsl:with-param name="FormTitle2">ATTENTION: INTENTIONAL MISSTATEMENTS OR OMISSIONS OF FACT CONSTITUE FEDERAL CRIMINAL VIOLATIONS. See 18 U.S.C. 1001 and 15 U.S.C. 78ff(a)</xsl:with-param>
               </xsl:call-template>
            </td>
            <td rowspan="1" width="20%" valign="top" align="center">
               <xsl:call-template name="OMBBox">
                  <xsl:with-param name="OMBNumber" select="'3235-0337'" />
                  <xsl:with-param name="OMBExpireDate" select="'Oct 31, 2018'" />
                  <xsl:with-param name="OMBHours" select="'6.00'" />
                  <xsl:with-param name="OMBIntHours" select="'1.50'" />
                  <xsl:with-param name="OMBMinHours" select="'.50'" />
               </xsl:call-template>
            </td>
         </tr>
      </table>
      <span class="FormText">Form Version:</span>
      <xsl:apply-templates select="formVersion" mode="NormalText" />
      <hr />
   </xsl:template>

   <xsl:template name="FormTAWHeader">
      <table width="100%" border="0" cellspacing="0" cellpadding="4" summary="TA-W Form Header Information">
         <tr>
            <td width="20%" colspan="2" valign="top" align="left"></td>
            <td rowspan="1" width="60%" valign="middle" align="center">
               <xsl:call-template name="TitleBox">
                  <xsl:with-param name="FormTitle">FORM TA-W</xsl:with-param>
                  <xsl:with-param name="FormTitle1">NOTICE OF WITHDRAWAL FROM REGISTRATION AS TRANSFER AGENT PURSUANT TO SECTION 17A OF THE SECURITIES EXCHANGE ACT OF 1934</xsl:with-param>
               </xsl:call-template>
            </td>
            <td rowspan="1" width="20%" valign="top" align="center">
               <xsl:call-template name="OMBBox">
                  <xsl:with-param name="OMBNumber" select="'3235-0151'" />
                  <xsl:with-param name="OMBExpireDate" select="'Sept 30, 3017'" />
                  <xsl:with-param name="OMBHours" select="'0.5'" />
               </xsl:call-template>
            </td>
         </tr>
      </table>
      <span class="FormText">Form Version:</span>
      <xsl:apply-templates select="formVersion" mode="NormalText" />
      <hr />
   </xsl:template>
</xsl:stylesheet>

