<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:clitype="clitype" xmlns:com="http://www.sec.gov/edgar/common" xmlns:dei="http://www.sec.gov/edgar/dei" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:invest="http://www.sec.gov/edgar/invest" xmlns:iso4217="http://www.xbrl.org/2003/iso4217" xmlns:ix="http://www.xbrl.org/2008/inlineXBRL" xmlns:java="java" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:n1="http://www.sec.gov/edgar/nmfp" xmlns:part1="http://www.sec.gov/edgar/nmfpfund" xmlns:part2="http://www.sec.gov/edgar/nmfpsecurities" xmlns:ratings="http://www.sec.gov/edgar/ratings" xmlns:rr="http://www.sec.gov/edgar/rr" xmlns:sccom="http://www.sec.gov/edgar/sccommon" xmlns:state="http://www.sec.gov/edgar/statecodes" xmlns:us-gaap="http://www.sec.gov/edgar/us-gaap" xmlns:xbrldi="http://xbrl.org/2006/xbrldi" xmlns:xbrli="http://www.xbrl.org/2003/instance" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:altova="http://www.altova.com" exclude-result-prefixes="clitype com dei fn invest iso4217 ix java link n1 part1 part2 ratings rr sccom state us-gaap xbrldi xbrli xlink xs xsi altova">
<!--
   XSL Stylesheet for Form N-MFP Sections
   Version 1.1 - Dated February 2010
   Created By: SAIC 
   Created for: SEC
   -->
   
   <xsl:template name="Section1">
     <p class="SectionTitle">1. Identity Information</p>
     <table border="1" summary="Identity Information" width="100%">
       <tbody>
         <tr>
           <xsl:call-template name="tbleData1">
             <xsl:with-param name="applTmpltVal" select="n1:DocumentPeriodEndDate" />
             <xsl:with-param name="Label" >Report for</xsl:with-param>
           </xsl:call-template>
           <td class="AlignTop">
             <div class="FormText">CIK Number of Registrant</div>
             <div class="indent1">
               <xsl:call-template name="createCIKLink">
                  <xsl:with-param name="aCIK" select="n1:EntityCentralIndexKey" />
                  <xsl:with-param name="label" select="n1:EntityCentralIndexKey" />
               </xsl:call-template>
             </div>
           </td>
           <td class="AlignTop">
             <div class="FormText">EDGAR Series Identifier</div>
             <div class="indent1">
               <xsl:call-template name="createCIKLink">
                 <xsl:with-param name="aCIK" select="n1:seriesId" />
                 <xsl:with-param name="label" select="n1:seriesId" />
               </xsl:call-template>
             </div>
           </td>
         </tr>
         <tr>
           <td colspan="4" class="AlignTop">
             <div class="FormText">Total number of share classes in the series</div>
             <div class="indent1">
               <xsl:apply-templates select="n1:totalClassesInSeries" mode="NormalText" />
             </div>
           </td>
         </tr>
         <tr>
           <td colspan="4" class="AlignTop">
             <div class="FormText">Do you anticipate that this will be the fund's final filing on Form N-MFP?</div>
             <div class="indent1">
               <xsl:call-template name="createCheckBoxTable">
                 <xsl:with-param name="TestThis1" select="n1:isThisFinalFiling" />
                 <xsl:with-param name="Label1" select="'Yes'" />
                 <xsl:with-param name="TestNotThis2" select="n1:isThisFinalFiling" />
                 <xsl:with-param name="Label2" select="'No'" />
                 <xsl:with-param name="Summary" select="'Anticiplate Final checkbox'" />
               </xsl:call-template>
               <table summary="Anticiplate Final box">
                 <tr>
                   <td class="FormText">Is the fund liquidating?</td>
                 </tr>
                 <tr>
                   <td>
                     <xsl:call-template name="createCheckBoxTable">
                       <xsl:with-param name="TestThis1" select="n1:isFundLiquidating" />
                       <xsl:with-param name="Label1" select="'Yes'" />
                       <xsl:with-param name="TestNotThis2" select="n1:isFundLiquidating" />
                       <xsl:with-param name="Label2" select="'No'" />
                       <xsl:with-param name="Summary" select="'Liquidating checkbox'" />
                     </xsl:call-template>
                   </td>
                 </tr>
                 <tr>
                   <td class="FormText">Is the fund merging with, or being acquired by, another fund?</td>
                 </tr>
                 <tr>
                   <td>
                     <xsl:call-template name="createCheckBoxTable">
                       <xsl:with-param name="TestThis1" select="n1:isFundMergingWithOrBeingAcquiredByAnotherFund" />
                       <xsl:with-param name="Label1" select="'Yes'" />
                       <xsl:with-param name="TestNotThis2" select="n1:isFundMergingWithOrBeingAcquiredByAnotherFund" />
                       <xsl:with-param name="Label2" select="'No'" />
                       <xsl:with-param name="Summary" select="'Fund merging checkbox'" />
                     </xsl:call-template>
                   </td>
                 </tr>
                 <tr>
                   <td>
                     <table summary="Fund merging table" border="1" cellpadding="5">
                       <tr>
                         <td class="FormText">Successor fund CIK</td>
                         <td class="FormText">Successor fund Securities Act File Number</td>
                         <td class="FormText">Successor fund EDGAR Series Identifier</td>
                       </tr>
                       <xsl:for-each select="n1:successorFundList/fund">
                         <tr>
                           <td>
                             <xsl:call-template name="createCIKLink">
                               <xsl:with-param name="aCIK" select="EntityCentralIndexKey" />
                               <xsl:with-param name="label" select="EntityCentralIndexKey" />
                             </xsl:call-template>
                           </td>
                           <td>
                             <xsl:call-template name="createFileNoLink">
                               <xsl:with-param name="aFileNumber" select="ContainedFileInformationFileNumber" />
                               <xsl:with-param name="label" select="ContainedFileInformationFileNumber" />
                             </xsl:call-template>
                           </td>
                           <td>
                             <xsl:call-template name="createCIKLink">
                               <xsl:with-param name="aCIK" select="seriesIdentifier" />
                               <xsl:with-param name="label" select="seriesIdentifier" />
                             </xsl:call-template>
                           </td>
                         </tr>
                       </xsl:for-each>
                     </table>
                   </td>
                 </tr>
               </table>
             </div>
           </td>
         </tr>
         <tr>
           <td colspan="4" class="AlignTop">
             <div class="FormText">If this is not a final filing: has the fund acquired or merged with another fund since the last filing?</div>
             <div class="indent1">
               <xsl:call-template name="createCheckBoxTable">
                 <xsl:with-param name="TestThis1" select="n1:hasFundAcquiredOrMergedWithAnotherFundSinceLastFiling" />
                 <xsl:with-param name="Label1" select="'Yes'" />
                 <xsl:with-param name="TestNotThis2" select="n1:hasFundAcquiredOrMergedWithAnotherFundSinceLastFiling" />
                 <xsl:with-param name="Label2" select="'No'" />
                 <xsl:with-param name="Summary" select="'Not Final checkbox'" />
               </xsl:call-template>
               <table summary="Not Final table" border="1" cellpadding="5">
                 <tr>
                   <td class="FormText">Acquired or merged fund CIK</td>
                   <td class="FormText">Acquired or merged fund Securities Act File Number</td>
                   <td class="FormText">Acquired or merged fund EDGAR Series Identifier</td>
                 </tr>
                 <xsl:for-each select="n1:acquiredMergedFundList/fund">
                   <tr>
                     <td>
                       <xsl:call-template name="createCIKLink">
                         <xsl:with-param name="aCIK" select="EntityCentralIndexKey" />
                         <xsl:with-param name="label" select="EntityCentralIndexKey" />
                       </xsl:call-template>
                     </td>
                     <td>
                       <xsl:call-template name="createFileNoLink">
                         <xsl:with-param name="aFileNumber" select="ContainedFileInformationFileNumber" />
                         <xsl:with-param name="label" select="ContainedFileInformationFileNumber" />
                       </xsl:call-template>
                     </td>
                     <td>
                       <xsl:call-template name="createCIKLink">
                         <xsl:with-param name="aCIK" select="seriesIdentifier" />
                         <xsl:with-param name="label" select="seriesIdentifier" />
                       </xsl:call-template>
                     </td>
                   </tr>
                 </xsl:for-each>
               </table>
             </div>
           </td>
         </tr>
       </tbody>
     </table>
   </xsl:template>
   
   <xsl:template name="Section2">
     <p class="SectionTitle">Part I - Information about the Fund</p>
     <p class="FormTitle2">A. Series-Level Information</p>
     <table summary="Series-Level Information" border="1" width="100%">
       <tbody>
         <tr>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 1. Securities Act File Number</div>
             <div class="indent1">
               <xsl:call-template name="createFileNoLink">
                 <xsl:with-param name="aFileNumber" select="n1:seriesLevelInformation/part1:ContainedFileInformationFileNumber" />
                 <xsl:with-param name="label" select="n1:seriesLevelInformation/part1:ContainedFileInformationFileNumber" />
               </xsl:call-template>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 2. Investment Adviser</div>
             <div class="indent1">
               <table summary="Investment Adviser" width="90%">
                 <tbody>
                   <tr>
                     <th class="FormText">Adviser</th>
                     <th class="FormText">SEC File Number</th>
                   </tr>
                   <xsl:for-each select="n1:seriesLevelInformation/part1:investmentAdviserList/part1:adviser">
                     <tr>
                       <xsl:apply-templates select="part1:adviserName" mode="NormalTDL" />
                       <td>
                         <xsl:call-template name="createFileNoLink">
                           <xsl:with-param name="aFileNumber" select="part1:adviserFileNumber" />
                           <xsl:with-param name="label" select="part1:adviserFileNumber" />
                         </xsl:call-template>
                       </td>
                     </tr>
                   </xsl:for-each>
                 </tbody>
               </table>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 3. Sub-Adviser.  If a fund has one or more sub-advisers, disclose the name of each sub-adviser</div>
             <div class="indent1">
               <table summary="Sub Adviser" width="90%">
                 <tbody>
                   <tr>
                     <th class="FormText">Sub Advisor</th>
                     <th class="FormText">SEC File Number</th>
                   </tr>
                   <xsl:for-each select="n1:seriesLevelInformation/part1:subAdviserList/part1:subAdviser">
                     <tr>
                       <xsl:apply-templates select="part1:adviserName" mode="NormalTDL" />
                       <td>
                         <xsl:call-template name="createFileNoLink">
                           <xsl:with-param name="aFileNumber" select="part1:adviserFileNumber" />
                           <xsl:with-param name="label" select="part1:adviserFileNumber" />
                         </xsl:call-template>
                       </td>
                     </tr>
                   </xsl:for-each>
                 </tbody>
               </table>
             </div>
           </td>
         </tr>
         <tr>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 4. Independent Public Accountant</div>
             <div class="indent1">
               <table summary="Independent Public Accountant" width="90%">
                 <tbody>
                   <tr>
                     <th class="FormText">Name</th>
                     <th class="FormText">City</th>
                     <th class="FormText">State</th>
                   </tr>
                   <xsl:for-each select="n1:seriesLevelInformation/part1:independentPublicAccountant">
                     <tr>
                       <xsl:apply-templates select="part1:name" mode="NormalTDL" />
                       <xsl:apply-templates select="part1:city" mode="NormalTDL" />
                       <xsl:apply-templates select="part1:state" mode="NormalTDL" />
                     </tr>
                   </xsl:for-each>
                 </tbody>
               </table>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 5. Administrator.  If a fund has one or more administrators, disclose the name of each administrator</div>
             <div class="indent1">
               <table summary="Administrator" width="90%">
                 <tbody>
                   <tr>
                     <th class="FormText">Name</th>
                   </tr>
                   <xsl:for-each select="n1:seriesLevelInformation/part1:administratorList/part1:administrator">
                     <tr>
                       <xsl:apply-templates select="." mode="NormalTDL" />
                     </tr>
                   </xsl:for-each>
                 </tbody>
               </table>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 6. Transfer Agent</div>
             <div class="indent1">
               <table summary="Transfer Agent" width="90%">
                 <tbody>
                   <tr>
                     <th class="FormText">Name</th>
                     <th class="FormText">CIK Number</th>
                     <th class="FormText">SEC File Number</th>
                   </tr>
                   <xsl:for-each select="n1:seriesLevelInformation/part1:transferAgentList/part1:transferAgent">
                     <tr>
                       <xsl:apply-templates select="part1:name" mode="NormalTDL" />
                       <td>
                         <xsl:call-template name="createCIKLink">
                           <xsl:with-param name="aCIK" select="part1:EntityCentralIndexKey" />
                           <xsl:with-param name="label" select="part1:EntityCentralIndexKey" />
                         </xsl:call-template>
                       </td>
                       <td>
                         <xsl:call-template name="createFileNoLink">
                           <xsl:with-param name="aFileNumber" select="part1:fileNumber" />
                           <xsl:with-param name="label" select="part1:fileNumber" />
                         </xsl:call-template>
                       </td>
                     </tr>
                   </xsl:for-each>
                 </tbody>
               </table>
             </div>
           </td>
         </tr>
         <tr>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 7. Master-Feeder Funds.  Is this a feeder fund?</div>
             <div class="indent1">
               <xsl:call-template name="createCheckBoxTable">
                 <xsl:with-param name="TestThis1" select="n1:seriesLevelInformation/part1:isThisFeederFund" />
                 <xsl:with-param name="Label1" select="'Yes'" />
                 <xsl:with-param name="TestNotThis2" select="n1:seriesLevelInformation/part1:isThisFeederFund" />
                 <xsl:with-param name="Label2" select="'No'" />
                 <xsl:with-param name="Summary" select="'Item 7 Is this a Feeder Fund?'" />
               </xsl:call-template>
               <table summary="Item 7 box" width="90%">
                 <tr>
                   <td class="FormText">a. Identify the master fund by CIK</td>
                 </tr>
                 <tr>
                   <td>
                     <xsl:call-template name="createCIKLink">
                       <xsl:with-param name="aCIK" select="n1:seriesLevelInformation/part1:masterFund/part1:EntityCentralIndexKey" />
                       <xsl:with-param name="label" select="n1:seriesLevelInformation/part1:masterFund/part1:EntityCentralIndexKey" />
                    </xsl:call-template>
                   </td>
                 </tr>
                 <tr>
                   <td class="FormText">b. Securities Act file number of the master fund</td>
                 </tr>
                 <tr>
                   <td>
                     <xsl:call-template name="createFileNoLink">
                       <xsl:with-param name="aFileNumber" select="n1:seriesLevelInformation/part1:masterFund/part1:ContainedFileInformationFileNumber" />
                       <xsl:with-param name="label" select="n1:seriesLevelInformation/part1:masterFund/part1:ContainedFileInformationFileNumber" />
                     </xsl:call-template>
                   </td>
                 </tr>
                 <tr>
                   <td class="FormText">c. EDGAR series identifier of the master fund</td>
                 </tr>
                 <tr>
                   <td>
                     <xsl:call-template name="createCIKLink">
                       <xsl:with-param name="aCIK" select="n1:seriesLevelInformation/part1:masterFund/part1:seriesIdentifier" />
                       <xsl:with-param name="label" select="n1:seriesLevelInformation/part1:masterFund/part1:seriesIdentifier" />
                     </xsl:call-template>
                   </td>
                 </tr>
               </table>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 8. Master-Feeder Funds.  Is this a master fund?</div>
             <div class="indent1">
               <xsl:call-template name="createCheckBoxTable">
                 <xsl:with-param name="TestThis1" select="n1:seriesLevelInformation/part1:isThisMasterFund" />
                 <xsl:with-param name="Label1" select="'Yes'" />
                 <xsl:with-param name="TestNotThis2" select="n1:seriesLevelInformation/part1:isThisMasterFund" />
                 <xsl:with-param name="Label2" select="'No'" />
                 <xsl:with-param name="Summary" select="'Item 8 Is this a Master Fund?'" />
               </xsl:call-template>
               <!-- Display the sub elements for Item 8 even there are no values in the XML -->
               <xsl:choose>
                 <xsl:when test="not(n1:seriesLevelInformation/part1:isThisMasterFund='Y')">
                   <xsl:call-template name="printTableLabels">
                     <xsl:with-param name="Summary">Item 8 box</xsl:with-param>
                     <xsl:with-param name="Label1">a. If this is a master fund, identify all feeder funds by CIK or, if the fund does not have a CIK, by name</xsl:with-param>
                     <xsl:with-param name="Label2">b. Securities Act file number of each feeder fund</xsl:with-param>
                     <xsl:with-param name="Label3">c. EDGAR series identifier of each feeder fund</xsl:with-param>
                   </xsl:call-template>
                 </xsl:when> 
                 <xsl:otherwise> 
                   <xsl:for-each select="n1:seriesLevelInformation/part1:feederFundList/part1:feederFund">
                     <table summary="Item 8 box" width="90%">
                       <tr>
                         <td class="FormText">a. If this is a master fund, identify all feeder funds by CIK or</td>
                       </tr>
                       <tr>
                         <td>
                           <xsl:call-template name="createCIKLink">
                             <xsl:with-param name="aCIK" select="part1:EntityCentralIndexKey" />
                             <xsl:with-param name="label" select="part1:EntityCentralIndexKey" />
                           </xsl:call-template>
                         </td>
                       </tr>
                       <tr>
                         <td class="FormText">If the fund does not have a CIK, by name: </td>
                       </tr>
                       <tr>
                         <td><xsl:apply-templates select="part1:EntityRegistrantName" mode="NormalText" /></td>
                       </tr>
                       <tr>
                         <td class="FormText">b. Securities Act file number of each feeder fund</td>
                       </tr>
                       <tr>
                         <td>
                           <xsl:call-template name="createFileNoLink">
                             <xsl:with-param name="aFileNumber" select="part1:ContainedFileInformationFileNumber" />
                             <xsl:with-param name="label" select="part1:ContainedFileInformationFileNumber" />
                           </xsl:call-template>
                         </td>
                       </tr>
                       <tr>
                         <td class="FormText">c. EDGAR series identifier of each feeder fund</td>
                       </tr>
                       <tr>
                         <td>
                           <xsl:call-template name="createCIKLink">
                             <xsl:with-param name="aCIK" select="part1:seriesIdentifier" />
                             <xsl:with-param name="label" select="part1:seriesIdentifier" />
                           </xsl:call-template>
                         </td>
                       </tr>
                     </table>
                   </xsl:for-each>
                 </xsl:otherwise> 
               </xsl:choose>
             </div>
           </td>
           <td width="33%" class="AlignTop">
             <div class="FormText">Item 9. Is this series primarily used to fund insurance company separate accounts?</div>
             <div class="indent1">
               <xsl:call-template name="createCheckBoxTable">
                 <xsl:with-param name="TestThis1" select="n1:seriesLevelInformation/part1:isThisSeriesPrimarilyUsedToFundInsuranceCompanySeperateAccounts" />
                 <xsl:with-param name="Label1" select="'Yes'" />
                 <xsl:with-param name="TestNotThis2" select="n1:seriesLevelInformation/part1:isThisSeriesPrimarilyUsedToFundInsuranceCompanySeperateAccounts" />
                 <xsl:with-param name="Label2" select="'No'" />
                 <xsl:with-param name="Summary" select="'Item 9 Used to fund Insurance Company Separate Accounts?'" />
               </xsl:call-template>
             </div>
           </td>
         </tr>
         <tr>
           <xsl:call-template name="tbleData1">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:InvestmentTypeDomain" />
             <xsl:with-param name="Label" >Item 10. Category.  Indicate the category that most closely identifies the money market fund</xsl:with-param>
           </xsl:call-template>
           <xsl:call-template name="tbleData1">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:dollarWeightedAveragePortfolioMaturity" />
             <xsl:with-param name="Label" >Item 11. Dollar weighted average portfolio maturity</xsl:with-param>
             <xsl:with-param name="Unit"> days</xsl:with-param>
           </xsl:call-template>
           <xsl:call-template name="tbleData1">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:dollarWeightedAverageLifeMaturity" />
             <xsl:with-param name="Label" >Item 12. Dollar weighted average life maturity.  Calculate the dollar weighted average portfolio maturity without reference to the exceptions in rule 2a-7(d) regarding interest rate readjustments</xsl:with-param>
             <xsl:with-param name="Unit"> days</xsl:with-param>
           </xsl:call-template>
         </tr>
         <tr>
           <xsl:call-template name="tbleData2">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:AvailableForSaleSecuritiesAmortizedCost" />
             <xsl:with-param name="Label" >Item 13. Total value of portfolio securities at amortized cost, to the nearest cent</xsl:with-param>
           </xsl:call-template>
           <xsl:call-template name="tbleData2">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:OtherAssets" />
             <xsl:with-param name="Label" >Item 14. Total value of other assets, to the nearest cent</xsl:with-param>
           </xsl:call-template>
           <xsl:call-template name="tbleData2">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:Liabilities" />
             <xsl:with-param name="Label" >Item 15. Total value of liabilities, to the nearest cent</xsl:with-param>
           </xsl:call-template>
         </tr>
         <tr>
           <xsl:call-template name="tbleData2">
             <xsl:with-param name="applTmpltVal" select="n1:seriesLevelInformation/part1:AssetsNet" />
             <xsl:with-param name="Label" >Item 16. Net assets of the series, to the nearest cent</xsl:with-param>
           </xsl:call-template>
           <td colspan="2" class="AlignTop">
             <div class="FormText">Item 17. 7-day gross yield</div>
             <div class="indent1">
               <xsl:call-template name="printPercentValue">
                 <xsl:with-param name="value" select="n1:seriesLevelInformation/part1:MoneyMarketSevenDayYield" />
                 <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
               </xsl:call-template>
             </div>
           </td>
         </tr>
         <tr>
           <td width="33%" class="AlignTop" colspan="3">
             <div class="FormText">Item 18. Shadow Price of the Series</div>
             <div class="indent1">
               <table class="indent1" summary="Series Shadow Price 1" width="95%">
                 <tbody>
                   <tr>
                     <td class="FormText AlignTop">a.</td>
                     <td class="FormText">The net asset value per share most recently calculated using available market quotations (or an appropriate substitute that reflects current market conditions), including the value of any capital support agreement, to the nearest hundredth of a cent.</td>
                   </tr>
                   <tr>
                     <td class="FormText"> </td>
                     <td>
                       <xsl:call-template name="printDollarValue">
                         <xsl:with-param name="value" select="n1:seriesLevelInformation/part1:seriesShadowPrice/part1:netValuePerShareIncludingCapitalSupportAgreement" />
                         <xsl:with-param name="decimalMode">Decimal4</xsl:with-param>
                       </xsl:call-template>
                     </td>
                   </tr>
                   <tr>
                     <td class="FormText">b.</td>
                     <td class="FormText">Date as of which the market-based net asset value disclosed in item 18a was calculated.</td>
                   </tr>
                   <tr>
                     <td class="FormText"> </td>
                     <xsl:apply-templates select="n1:seriesLevelInformation/part1:seriesShadowPrice/part1:dateCalculatedFornetValuePerShareIncludingCapitalSupportAgreement" mode="NormalTDL" />
                   </tr>
                   <tr>
                     <td class="FormText AlignTop">c.</td>
                     <td class="FormText">The net asset value per share most recently calculated using available market quotations (or an appropriate substitute that reflects current market conditions), excluding the value of any capital support agreement, to the nearest hundredth of a cent.</td>
                   </tr>
                   <tr>
                     <td class="FormText"> </td>
                     <td>
                       <xsl:call-template name="printDollarValue">
                         <xsl:with-param name="value" select="n1:seriesLevelInformation/part1:seriesShadowPrice/part1:netValuePerShareExcludingCapitalSupportAgreement" />
                         <xsl:with-param name="decimalMode">Decimal4</xsl:with-param>
                       </xsl:call-template>
                     </td>
                   </tr>
                   <tr>
                     <td class="FormText">d.</td>
                     <td class="FormText">Date as of which the market-based net asset value disclosed in item 18c was calculated.</td>
                   </tr>
                   <tr>
                     <td class="FormText"> </td>
                     <xsl:apply-templates select="n1:seriesLevelInformation/part1:seriesShadowPrice/part1:dateCalculatedFornetValuePerShareExcludingCapitalSupportAgreement" mode="NormalTDL" />
                   </tr>
                 </tbody>
               </table>
             </div>
           </td>
         </tr>
       </tbody>
     </table>
     <p class="FormTitle2">B. Class-Level Information. <br />For each Class of the Series, disclose the following:</p>
     <table summary="Class-Level Information" border="1" width="100%">
       <tbody>
         <xsl:for-each select="n1:classLevelInformationList/part1:classLevelInformation">
           <tr>
             <td width="33%" class="AlignTop">
               <div class="FormText">Item 19. EDGAR Class Identifier</div>
               <div class="indent1">
                 <xsl:call-template name="createCIKLink">
                    <xsl:with-param name="aCIK" select="part1:classId" />
                    <xsl:with-param name="label" select="part1:classId" />
                 </xsl:call-template>
               </div>
             </td>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part1:minInitialInvestment" />
               <xsl:with-param name="Label" >Item 20. Minimum Initial Investment</xsl:with-param>
             </xsl:call-template>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part1:netAssetsOfClass" />
               <xsl:with-param name="Label" >Item 21. Net assets of the Class, to the nearest cent</xsl:with-param>
             </xsl:call-template>
           </tr>
           <tr>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part1:netAssetValuePerShare" />
               <xsl:with-param name="Label" >Item 22. Net asset value per share for purposes of distributions, redemptions, and repurchase, to the nearest cent</xsl:with-param>
             </xsl:call-template>
             <td width="33%" class="AlignTop">
               <div class="FormText">
                  <span>Item 23. Net shareholder flow activity for the month ended (subscriptions less redemptions), to the nearest cent</span>
               </div>
               <div class="indent1">
                 <xsl:call-template name="printDollarValue">
                   <xsl:with-param name="value" select="part1:netShareholderFlowActivityForMonthEnded" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
               <div class="FormText">
                  <span>a. Gross subscriptions for the month ended (Including dividend reinvestments), to the nearest cent</span>
               </div>
               <div class="indent1">
                 <xsl:call-template name="printDollarValue">
                   <xsl:with-param name="value" select="part1:grossSubscriptionsForMonthEnded" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
               <div class="FormText">
                  <span>b. Gross redemptions for the month ended, to the nearest cent</span>
               </div>
               <div class="indent1">
                 <xsl:call-template name="printDollarValue">
                   <xsl:with-param name="value" select="part1:grossRedemptionsForMonthEnded" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
             </td>
             <td width="33%" class="AlignTop">
               <span>Item 24. 7-day net yield, as calculated under Item 26(a)(1) of Form N-1A</span>
               <div class="indent1">
                 <xsl:call-template name="printPercentValue">
                   <xsl:with-param name="value" select="part1:sevenDayNetYield" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
             </td>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 25. Shadow Price of Each Class</div>
               <div class="indent1">
                 <table summary="Shadow Price of each Class" width="95%">
                   <tbody>
                     <tr>
                       <td class="FormText AlignTop">a.</td>
                       <td class="FormText">The net asset value per share most recently calculated using available market quotations (or an appropriate substitute that reflects current market conditions), including the value of any capital support agreement, to the nearest hundredth of a cent.</td>
                     </tr>
                     <tr>
                       <td class="FormText"> </td>
                       <td>
                         <xsl:call-template name="printDollarValue">
                           <xsl:with-param name="value" select="part1:classShadowPrice/part1:netAssetValuePerShareIncludingCapitalSupportAgreement/part1:value" />
                           <xsl:with-param name="decimalMode">Decimal4</xsl:with-param>
                         </xsl:call-template>
                       </td>
                     </tr>
                     <tr>
                       <td class="FormText">b.</td>
                       <td class="FormText">Date as of which the market-based net asset value disclosed in item 25a was calculated.</td>
                     </tr>
                     <tr>
                       <td class="FormText"> </td>
                       <xsl:apply-templates select="part1:classShadowPrice/part1:netAssetValuePerShareIncludingCapitalSupportAgreement/part1:dateAsOfWhichValueWasCalculated" mode="NormalTDL" />
                     </tr>
                     <tr>
                       <td class="FormText AlignTop">c.</td>
                       <td class="FormText">The net asset value per share most recently calculated using available market quotations (or an appropriate substitute that reflects current market conditions), excluding the value of any capital support agreement, to the nearest hundredth of a cent.</td>
                     </tr>
                     <tr>
                       <td class="FormText"> </td>
                       <td>
                         <xsl:call-template name="printDollarValue">
                           <xsl:with-param name="value" select="part1:classShadowPrice/part1:netAssetValuePerShareExcludingCapitalSupportAgreement/part1:value" />
                           <xsl:with-param name="decimalMode">Decimal4</xsl:with-param>
                         </xsl:call-template>
                       </td>
                     </tr>
                     <tr>
                       <td class="FormText">d.</td>
                       <td class="FormText">Date as of which the market-based net asset value disclosed in item 25c was calculated.</td>
                     </tr>
                     <tr>
                       <td class="FormText"> </td>
                       <xsl:apply-templates select="part1:classShadowPrice/part1:netAssetValuePerShareExcludingCapitalSupportAgreement/part1:dateAsOfWhichValueWasCalculated" mode="NormalTDL" />
                     </tr>
                   </tbody>
                 </table>
               </div>
             </td>
           </tr>
         </xsl:for-each>
       </tbody>
     </table>
   </xsl:template>

   <xsl:template name="Section3">
     <p class="SectionTitle">Part II - Schedule of Portfolio Securities</p>
     <p class="FormTitle2">For each security held by the money market fund, disclose the following:</p>
     <xsl:for-each select="n1:scheduleOfPortfolioSecuritiesList/part2:scheduleOfPortfolioSecurities">
       <table summary="Schedule of Portfolio Securities" border="1" width="100%">
         <tbody>
           <tr>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentIssuer" />
               <xsl:with-param name="Label" >Item 26. Name of the Issuer</xsl:with-param>
             </xsl:call-template>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentTitle" />
               <xsl:with-param name="Label" >Item 27. The title of the issue (including coupon or yield)</xsl:with-param>
             </xsl:call-template>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:CUSIPMember" />
               <xsl:with-param name="Label" >Item 28. The CUSIP.  If the security has a CUSIP, filers must provide the security's CUSIP pursuant to this Item and may skip Items 29 and 30</xsl:with-param>
             </xsl:call-template>
           </tr>
           <tr>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentIdentifier" />
               <xsl:with-param name="Label" >Item 29. Other unique identifier, if the security has a unique identifier.  If a CUSIP is provided pursuant to Item 28, skip this Item</xsl:with-param>
             </xsl:call-template>
             <td width="33%" class="AlignTop">
               <div class="FormText">Item 30. CIK of the issuer, if the issuer has a CIK.  If a CUSIP is provided pursuant to Item 28, skip this Item</div>
               <div class="indent1">
                 <xsl:call-template name="createCIKLink">
                   <xsl:with-param name="aCIK" select="part2:EntityCentralIndexKey" />
                   <xsl:with-param name="label" select="part2:EntityCentralIndexKey" />
                 </xsl:call-template>
               </div>
             </td>
             <td width="33%" class="AlignTop">
               <div class="FormText">Item 31. The category of investment.  Indicate the category that most closely identitfies the instrument</div>
               <div class="indent1">
                 <xsl:apply-templates select="part2:InvestmentTypeDomain" mode="NormalText" />
               </div>
               <xsl:if test="count(part2:categoryOfInvestmentDesc)&gt;0">
                 <div class="FormText">If Other Instrument, include a brief description</div>
                 <div class="indent1">
                   <xsl:apply-templates select="part2:categoryOfInvestmentDesc" mode="NormalText" />
                 </div>
               </xsl:if>
             </td>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 32. If the security is a repurchase agreement: is the fund treating the acquisition of the repurchase agreement as the acquisition of the underlying securities (i.e., collateral) for purposes of portfolio diversification under rule 2a-7?</div>
               <div class="indent1">
                 <xsl:call-template name="createCheckBoxTable">
                   <xsl:with-param name="TestThis1" select="part2:isFundTreatingAsAcquisitionUnderlyingSecurities" />
                   <xsl:with-param name="Label1" select="'Yes'" />
                   <xsl:with-param name="TestNotThis2" select="part2:isFundTreatingAsAcquisitionUnderlyingSecurities" />
                   <xsl:with-param name="Label2" select="'No'" />
                 </xsl:call-template>
                 <xsl:choose>
                   <xsl:when test="count(part2:repurchaseAgreementList/part2:RepurchaseAgreement)&gt;0">
                     <table summary="Item 32 security is repurchase agreement" width="90%">
                       <xsl:for-each select="part2:repurchaseAgreementList/part2:RepurchaseAgreement">
                         <xsl:call-template name="Item32_Details">
                           <xsl:with-param name="item32a" select="part2:InvestmentIssuer" />
                           <xsl:with-param name="item32b" select="part2:InvestmentMaturityDate/invest:date" />
                           <xsl:with-param name="item32bDateFrom" select="part2:InvestmentMaturityDate/invest:DateRange/invest:from" />
                           <xsl:with-param name="item32bDateTo" select="part2:InvestmentMaturityDate/invest:DateRange/invest:to" />
                           <xsl:with-param name="item32c" select="part2:CR" />
                           <xsl:with-param name="item32d" select="part2:InvestmentTypeDomain" />
                           <xsl:with-param name="item32dOther" select="part2:categoryOfInvestmentDesc" />
                           <xsl:with-param name="item32e" select="part2:AssetsSoldUnderAgreementsToRepurchaseCarryingAmounts" />
                           <xsl:with-param name="item32f" select="part2:CashCollateralForBorrowedSecurities" />
                         </xsl:call-template>
                       </xsl:for-each>
                     </table>
                   </xsl:when>
                   <xsl:otherwise>
                     <table summary="Item 32 With No Repurchase Agreements" width="90%">
                       <xsl:call-template name="Item32_Details">
                       </xsl:call-template>
                     </table>
                   </xsl:otherwise>
                 </xsl:choose>
               </div>
             </td>
           </tr>
           <tr>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:rating" />
               <xsl:with-param name="Label" >Item 33. Rating.  Indicate whether the security is a rated First Tier Security, rated Second Tier Security, an Unrated Security, or no longer an Eligible Security</xsl:with-param>
             </xsl:call-template>
             <td colspan="2" class="AlignTop">
               <xsl:for-each select="part2:designatedNRSROList/part2:designatedNRSRO">
                 <div class="FormText">Item 34. Name of Designated NRSRO</div>
                 <div class="indent1">
                   <xsl:apply-templates select="part2:RAN" mode="NormalText" />
                   <table summary="Item 34 Designated NRSRO" width="90%">
                     <tr>
                       <td class="FormText">a. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO.  If the instrument and its issuer are not rated by the Designated NRSRO. indicate "NR".</td>
                     </tr>
                     <tr>
                       <xsl:apply-templates select="part2:R" mode="NormalTDL" />
                     </tr>
                   </table>
                 </div>
               </xsl:for-each>
             </td>
           </tr>
           <tr>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentMaturityDate" />
               <xsl:with-param name="Label" >Item 35. The maturity date as determined under rule 2a-7. Determine the maturity date, taking into account the maturity shortening provisions of rule 2a-7(d)</xsl:with-param>
             </xsl:call-template>
             <td colspan="2" class="AlignTop">
               <div class="FormText">Item 36. The final legal maturity date, taking into account any maturity date extensions that may be effected at the option of the issuer</div>
               <div class="indent1">
                 <xsl:apply-templates select="part2:finalLegalInvestmentMaturityDate" mode="NormalText" />
               </div>
             </td>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 37. Does the security have a Demand Feature?</div>
               <div class="indent1">
                 <xsl:call-template name="createCheckBoxTable">
                   <xsl:with-param name="TestThis1" select="part2:doesSecurityHaveDemandFeature" />
                   <xsl:with-param name="Label1" select="'Yes'" />
                   <xsl:with-param name="TestNotThis2" select="part2:doesSecurityHaveDemandFeature" />
                   <xsl:with-param name="Label2" select="'No'" />
                   <xsl:with-param name="Summary" select="'Item 37 Security Demand Feature Table'" />
                 </xsl:call-template>
                 <!-- Display the sub elements for Item 37 even there are no values in the XML -->
                 <xsl:choose>
                   <xsl:when test="not(part2:demandFeatureIssuerList/part2:demandFeatureIssuer)">
                     <xsl:call-template name="printTableLabels">
                       <xsl:with-param name="Summary">Item 37 Demand Features</xsl:with-param>
                       <xsl:with-param name="Label1">a. The identity of the Demand Feature issuer.</xsl:with-param>
                       <xsl:with-param name="Label2">b. Designated NRSRO(s) for the Demand Feature or provider of the Demand Feature</xsl:with-param>
                       <xsl:with-param name="Label3">c. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”</xsl:with-param>
                     </xsl:call-template>
                   </xsl:when> 
                   <xsl:otherwise> 
                     <xsl:for-each select="part2:demandFeatureIssuerList/part2:demandFeatureIssuer">
                       <table summary="Item 37 Demand Feature Issuers" width="90%">
                         <tr>
                           <td class="FormText">a. The identity of the Demand Feature issuer.</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:InvestmentIssuer" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">b. Designated NRSRO(s) for the Demand Feature or provider of the Demand Feature.</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:NRSRORatingList/part2:NRSROSRating/part2:RAN" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">c. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”.</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:NRSRORatingList/part2:NRSROSRating/part2:R" mode="NormalTDL" />
                         </tr>
                       </table>
                     </xsl:for-each>
                   </xsl:otherwise> 
                 </xsl:choose>
               </div>
             </td>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 38. Does the security have a Guarantee?</div>
               <div class="indent1">
                 <xsl:call-template name="createCheckBoxTable">
                   <xsl:with-param name="TestThis1" select="part2:doesSecurityHaveGuarantee" />
                   <xsl:with-param name="Label1" select="'Yes'" />
                   <xsl:with-param name="TestNotThis2" select="part2:doesSecurityHaveGuarantee" />
                   <xsl:with-param name="Label2" select="'No'" />
                   <xsl:with-param name="Summary" select="'Item 38 Security has a Guarantee?'" />
                 </xsl:call-template>
                 <!-- Display the sub elements for Item 38 even there are no values in the XML -->
                 <xsl:choose>
                   <xsl:when test="not(part2:guarantorList/part2:guarantor)">
                     <xsl:call-template name="printTableLabels">
                       <xsl:with-param name="Summary">Item 38 Gaurantors</xsl:with-param>
                       <xsl:with-param name="Label1">a. The identity of the Guarantor</xsl:with-param>
                       <xsl:with-param name="Label2">b. Designated NRSRO(s) for the Guarantee or Guarantor</xsl:with-param>
                       <xsl:with-param name="Label3">c. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”</xsl:with-param>
                     </xsl:call-template>
                   </xsl:when> 
                   <xsl:otherwise> 
                     <xsl:for-each select="part2:guarantorList/part2:guarantor">
                       <table summary="Item 38 Gaurantors" width="90%">
                         <tr>
                           <td class="FormText">a. The identity of the Guarantor</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:O" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">b. Designated NRSRO(s) for the Guarantee or Guarantor</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:NRSRORatingList/part2:NRSRORating/part2:RAN" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">c. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:NRSRORatingList/part2:NRSRORating/part2:R" mode="NormalTDL" />
                         </tr>
                       </table>
                     </xsl:for-each>
                   </xsl:otherwise> 
                 </xsl:choose>
               </div>
             </td>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 39. Does the security have any enhancements, other than those identified in Items 37 and 38 above, on which the fund is relying to determine the quality, maturity or liquidity of the security?</div>
               <div class="indent1">
                 <xsl:call-template name="createCheckBoxTable">
                   <xsl:with-param name="TestThis1" select="part2:doesSecurityHaveEnhancementsOnWhichFundRelying" />
                   <xsl:with-param name="Label1" select="'Yes'" />
                   <xsl:with-param name="TestNotThis2" select="part2:doesSecurityHaveEnhancementsOnWhichFundRelying" />
                   <xsl:with-param name="Label2" select="'No'" />
                   <xsl:with-param name="Summary" select="'Item 39 checkbox'" />
                 </xsl:call-template>
                 <!-- Display the sub elements for Item 39 even there are no values in the XML -->
                 <xsl:choose>
                   <xsl:when test="not(part2:enhancementsList/part2:enhancement)">
                     <xsl:call-template name="printTableLabels">
                       <xsl:with-param name="Summary">Item 39 Enhancements</xsl:with-param>
                       <xsl:with-param name="Label1">a. The type of enhancement</xsl:with-param>
                       <xsl:with-param name="Label2">b. The identity of the enhancement provider</xsl:with-param>
                       <xsl:with-param name="Label3">c. Designated NRSRO(s) for the enhancement or enhancement provider</xsl:with-param>
                       <xsl:with-param name="Label4">d. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”</xsl:with-param>
                     </xsl:call-template>
                   </xsl:when> 
                   <xsl:otherwise> 
                     <xsl:for-each select="part2:enhancementsList/part2:enhancement">
                       <table summary="Item 39 Enhancements" width="90%">
                         <tr>
                           <td class="FormText">a. The type of enhancement</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:typeOfEnhancement" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">b. The identity of the enhancement provider</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:enhancementProviderList/part2:Provider/part2:enhancementProvider" mode="NormalTDL" />
                         </tr>
                         <tr>
                           <td class="FormText">c. Designated NRSRO(s) for the enhancement or enhancement provider</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:enhancementProviderList/part2:Provider/part2:NRSRORatingList/part2:NRSRORating/part2:RAN" mode="NormalTDL" />
                         </tr>
                         <tr>
                       <td class="FormText">d. For each Designated NRSRO, disclose the credit rating given by the Designated NRSRO. If there is no rating given by the Designated NRSRO, indicate “NR.”</td>
                         </tr>
                         <tr>
                           <xsl:apply-templates select="part2:enhancementProviderList/part2:Provider/part2:NRSRORatingList/part2:NRSRORating/part2:R" mode="NormalTDL" />
                         </tr>
                       </table>
                     </xsl:for-each>
                   </xsl:otherwise> 
                 </xsl:choose>
               </div>
             </td>
           </tr>
           <tr>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentOwnedBalancePrincipalAmount" />
               <xsl:with-param name="Label" >Item 40. The total principal amount of the security held by the series, to the nearest cent</xsl:with-param>
             </xsl:call-template>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part2:AvailableForSaleSecuritiesAmortizedCost" />
               <xsl:with-param name="Label" >Item 41. The total current amortized cost, to the nearest cent</xsl:with-param>
             </xsl:call-template>
             <td width="33%" class="AlignTop">
               <div class="FormText">Item 42. The percentage of the money market fund's net assets invested in the security, to the nearest hundredth of a percent</div>
               <div class="indent1">
                 <xsl:call-template name="printPercentValue">
                   <xsl:with-param name="value" select="part2:InvestmentOwnedPercentOfNetAssets" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
             </td>
           </tr>
           <tr>
             <xsl:call-template name="tbleData1">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentOwnedInvestmentAditionalInformation" />
               <xsl:with-param name="Label" >Item 43. Explanatory notes. Disclose any other information that may be material to other disclosures related to the portfolio security</xsl:with-param>
             </xsl:call-template>
             <td width="33%" class="AlignTop">
               <div class="FormText">Item 44. Is this an Illiquid Security as of the date of this report?</div>
               <div class="indent1">
                 <xsl:call-template name="createCheckBoxTable">
                   <xsl:with-param name="TestThis1" select="part2:isThisIlliquidSecurity" />
                   <xsl:with-param name="Label1" select="'Yes'" />
                   <xsl:with-param name="TestNotThis2" select="part2:isThisIlliquidSecurity" />
                   <xsl:with-param name="Label2" select="'No'" />
                   <xsl:with-param name="Summary" select="'Item 44 checkbox'" />
                 </xsl:call-template>
               </div>
             </td>
             <xsl:call-template name="tbleData2">
               <xsl:with-param name="applTmpltVal" select="part2:InvestmentOwnedAtFairValue" />
               <xsl:with-param name="Label" >Item 45. The value of the security, calculated using available market quotations (or an appropriate substitute that reflects current market conditions), including the value of any capital support agreement, to the nearest cent</xsl:with-param>
             </xsl:call-template>
           </tr>
           <tr>
             <td colspan="3" class="AlignTop">
               <div class="FormText">Item 46. The value of the security, calculated using available market quotations (or an appropriate substitute that reflects current market conditions), excluding the value of any capital support agreement, to the nearest cent</div>
               <div class="indent1">
                 <xsl:call-template name="printDollarValue">
                   <xsl:with-param name="value" select="part2:valueOfSecurityExcludingValueOfCapitalSupportAgreement" />
                   <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
                 </xsl:call-template>
               </div>
             </td>
           </tr>
         </tbody>
       </table>
       <hr />
     </xsl:for-each>
   </xsl:template>

   <xsl:template name="Item32_Details">
     <xsl:param name="item32a" />
     <xsl:param name="item32b" />
     <xsl:param name="item32bDateFrom" />
     <xsl:param name="item32bDateTo" />
     <xsl:param name="item32c" />
     <xsl:param name="item32d" />
     <xsl:param name="item32dOther" />
     <xsl:param name="item32e" />
     <xsl:param name="item32f" />
     <tr>
       <td class="FormText"><br/>For repurchase agreements, describe the securities subject to the repurchase agreement, including:</td>
     </tr>
     <tr>
       <td class="FormText">a. The name of the issuer:
         <xsl:if test="string-length($item32a) &gt;0">
           <xsl:apply-templates select="$item32a" mode="Normal" />
         </xsl:if>
       </td>
     </tr>
     <tr>
       <td class="FormText">b. Maturity date:
         <xsl:if test="string-length($item32b) &gt;0">
           <xsl:apply-templates select="$item32b" mode="Normal" />
         </xsl:if>
       </td>
     </tr>
     <tr>
       <td>
         <table summary="Item 32b Maturity Date Range" class="indent1">
           <tr>
             <td class="FormText">from:
               <xsl:if test="string-length($item32bDateFrom) &gt;0">
                 <xsl:apply-templates select="$item32bDateFrom" mode="Normal" />
               </xsl:if>
             </td>
           </tr>
           <tr>
             <td class="FormText">to:
               <xsl:if test="string-length($item32bDateTo) &gt;0">
                 <xsl:apply-templates select="$item32bDateTo" mode="Normal" />
               </xsl:if>
             </td>
           </tr>
         </table>
       </td>
     </tr>
     <tr>
       <td class="FormText">c. Coupon or yield:
         <xsl:if test="string-length($item32c) &gt;0">
           <xsl:apply-templates select="$item32c" mode="Normal" />
         </xsl:if>
       </td>
     </tr>
     <tr>
       <td class="FormText">d. The category of investments:
         <xsl:if test="string-length($item32d) &gt;0">
           <xsl:apply-templates select="$item32d" mode="Normal" />
         </xsl:if>
       </td>
     </tr>
     <tr>
       <td>
         <table summary="Item 32d Category of Investments" class="indent1">
           <tr>
             <td class="FormText">If Other Instrument, include a brief description:
               <xsl:if test="substring($item32d, 1,5)='Other'">
                 <xsl:if test="string-length($item32dOther) &gt;0">
                   <xsl:apply-templates select="$item32dOther" mode="Normal" />
                 </xsl:if>
               </xsl:if>
             </td>
           </tr>
         </table>
       </td>
     </tr>
     <tr>
       <td class="FormText">e. The principal amount, to the nearest cent:
         <xsl:call-template name="printDollarValue">
           <xsl:with-param name="value" select="$item32e" />
           <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
         </xsl:call-template>
       </td>
     </tr>
     <tr>
       <td class="FormText">f. Value of collateral, to the nearest cent:
         <xsl:call-template name="printDollarValue">
           <xsl:with-param name="value" select="$item32f" />
           <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
         </xsl:call-template>
       </td>
     </tr>
     <tr>
       <td class="FormText">If multiple securities of an issuer are subject to the repurchase agreement, the securities may be aggregated, in which case disclose:</td>
     </tr>
     <tr>
       <td class="FormText">(a) the total principal amount and value and (b) the range of maturity dates and interest rates.</td>
     </tr>
   </xsl:template>

   <xsl:template name="createCheckBoxTable">
      <xsl:param name="TestThis1" />
      <xsl:param name="Label1" />
      <xsl:param name="TestNotThis2" />
      <xsl:param name="Label2" />
      <xsl:param name="Summary" />

     <table summary="{$Summary}">
       <tr>
         <td>
           <xsl:call-template name="Build2Radios">
             <xsl:with-param name="TestThis1" select="$TestThis1" />
             <xsl:with-param name="Label1" select="$Label1" />
             <xsl:with-param name="TestNotThis2" select="$TestNotThis2" />
             <xsl:with-param name="Label2" select="$Label2" />
           </xsl:call-template>
         </td>
       </tr>
     </table>
   </xsl:template>

   <xsl:template name="tbleData1">
      <xsl:param name="applTmpltVal" />
      <xsl:param name="Label" />
      <xsl:param name="Unit" />
      <td width="33%" class="AlignTop">
         <div class="FormText">
            <xsl:value-of select="$Label" />
         </div>
         <div class="indent1">
            <xsl:apply-templates select="$applTmpltVal" mode="NormalText" />
            <span class="FormData"><xsl:value-of select="$Unit" /></span>
         </div>
      </td>
   </xsl:template>

   <xsl:template name="tbleData2">
      <xsl:param name="applTmpltVal" />
      <xsl:param name="Label" />
      <td width="33%" class="AlignTop">
         <div class="FormText">
            <xsl:value-of select="$Label" />
         </div>
         <div class="indent1">
            <xsl:call-template name="printDollarValue">
              <xsl:with-param name="value" select="$applTmpltVal" />
              <xsl:with-param name="decimalMode">Decimal2</xsl:with-param>
            </xsl:call-template>
         </div>
      </td>
   </xsl:template>

   <xsl:template name="printTableLabels">
      <xsl:param name="Summary" />
      <xsl:param name="Label1" />
      <xsl:param name="Label2" />
      <xsl:param name="Label3" />
      <xsl:param name="Label4" />
      <table summary="{$Summary}" width="90%">
        <tr>
          <td class="FormText"><xsl:value-of select="$Label1" /></td>
        </tr>
        <xsl:if test="$Label2">
          <tr>
            <td class="FormText"><xsl:value-of select="$Label2" /></td>
          </tr>
        </xsl:if>
        <xsl:if test="$Label3">
          <tr>
            <td class="FormText"><xsl:value-of select="$Label3" /></td>
          </tr>
        </xsl:if>
        <xsl:if test="$Label4">
          <tr>
            <td class="FormText"><xsl:value-of select="$Label4" /></td>
          </tr>
        </xsl:if>
      </table>
   </xsl:template>

   <xsl:template name="printDecimalValue">
      <xsl:param name="value" />
      <xsl:param name="decimalMode" />

      <xsl:choose>
         <xsl:when test="number($value)">
            <xsl:choose>
               <xsl:when test="($decimalMode='Decimal2')">
                  <xsl:call-template name="printDecimal2">
                     <xsl:with-param name="value" select="$value" />
                  </xsl:call-template>
               </xsl:when>
               <xsl:when test="($decimalMode='Decimal4')">
                  <xsl:call-template name="printDecimal4">
                     <xsl:with-param name="value" select="$value" />
                  </xsl:call-template>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="$value" />
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="$value" disable-output-escaping="yes" />
         </xsl:otherwise>
      </xsl:choose>

   </xsl:template>

   <xsl:template name="printDollarValue">
      <xsl:param name="value" />
      <xsl:param name="decimalMode" />
      <xsl:if test="not($value='')">
        <xsl:if test="count($value)&gt;0">
          <span class="FormText">$</span>
          <span class="FormData">
             <xsl:call-template name="printDecimalValue">
                <xsl:with-param name="value" select="$value" />
                <xsl:with-param name="decimalMode" select="$decimalMode" />
             </xsl:call-template>
          </span>
        </xsl:if>
      </xsl:if>
   </xsl:template>

   <xsl:template name="printPercentValue">
      <xsl:param name="value" />
      <xsl:param name="decimalMode" />
      <xsl:if test="not($value='')">
        <xsl:if test="count($value)&gt;0">
          <xsl:variable name="percent_value">
            <xsl:value-of select="$value * 100" />
          </xsl:variable>
          <span class="FormData">
             <xsl:call-template name="printDecimalValue">
                <xsl:with-param name="value" select="$percent_value" />
                <xsl:with-param name="decimalMode" select="$decimalMode" />
             </xsl:call-template>
          </span>
          <span class="FormText">%</span>
        </xsl:if>
      </xsl:if>
   </xsl:template>

   <xsl:template name="printDecimal2">
      <xsl:param name="value" />
      <xsl:value-of select="format-number($value,'###,##0.00')" />
   </xsl:template>

   <xsl:template name="printDecimal4">
      <xsl:param name="value" />
      <xsl:value-of select="format-number($value,'###,##0.0000')" />
   </xsl:template>

   <xsl:template match="*" mode="Decimal2">
     <xsl:value-of select="format-number(.,'###,##0.00')" />
   </xsl:template>

   <xsl:template match="*" mode="Decimal4">
     <xsl:value-of select="format-number(.,'###,##0.0000')" />
   </xsl:template>

</xsl:stylesheet>
