<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

   <xsl:import href="SEC-Common.xsl"/>

<xsl:key name="existing-by-seriesId" match="existing" use="seriesId" /> 

<xsl:key name="merger-by-cik-seriesId" match="merger" use="concat(acquiringCik, '+', acquiringSeriesId)"/>
<xsl:key name="merger-by-cik-seriesId-classContractId" match="merger" use="concat(acquiringCik, '+', acquiringSeriesId, '+', acquiringClassContractId)"/>

<xsl:template match="merger">
	<xsl:value-of select="acquiringCik"/>
	<xsl:for-each select="merger">
		<xsl:sort select="./acquiringCIK" />
		<xsl:for-each select="current-group()">
			<xsl:sort select="acquiringSeriesId" />
			<xsl:value-of select="acquiringCik"/>
			<xsl:value-of select="acquiringSeriesId"/>
			<xsl:value-of select="acquiringClassContractId"/>
		</xsl:for-each> 
	</xsl:for-each>
</xsl:template>

<xsl:template match="seriesClassContractData"> 
	<xsl:if test="count(existing) > 0">
	<tr>
		<th colspan="2"><u>REFERENCED SERIES/CLASSES (CONTRACTS)</u></th>
	</tr>

	<xsl:for-each select="existing[count(. | key('existing-by-seriesId', seriesId)[1]) = 1]">
	<xsl:sort select="seriesId" /> 
	<tr>
		<td colspan="2" style="border-top:thin dotted black">
		
			<table summary="Series and Class/Contract Information" width="100%">
				<tr align="left">
					<td align="left" colspan="2"><b>Series ID</b></td>
				</tr>
				<tr align="left">
					<td align="left" width="2%"></td>
					<td align="left" width="18%"><b>Class/Contract</b></td>
					<td align="left"><b>Name</b></td>
				</tr>
				<tr>
					<td width="20%" colspan="2">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="seriesId" />
							<xsl:with-param name="aclass" select="'hot'" />
						</xsl:call-template>
					</td>
					<td><xsl:value-of select="seriesName" /> </td>
				</tr>
				<xsl:for-each select="key('existing-by-seriesId', seriesId)"> 
				<tr>
					<td align="left"></td>
					<td>
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="classContractId" />
							<xsl:with-param name="aclass" select="'subCat'" />
						</xsl:call-template>
					</td>
					<td><xsl:value-of select="classContractName" /></td>
				</tr>
				</xsl:for-each> 
			</table>
		</td>
	</tr>
	</xsl:for-each> 
	</xsl:if>

	<xsl:if test="count(merger) > 0">
	<tr>
		<th colspan="2"><u>SERIES/CLASSES (CONTRACTS) MERGERS</u></th>
	</tr>
	</xsl:if>

	<xsl:for-each select="merger[count(. | key('merger-by-cik-seriesId-classContractId', concat(acquiringCik,'+',acquiringSeriesId,'+',acquiringClassContractId))[1])=1]">
	<tr>
		<td colspan="2" style="border-top:thin dotted black">
			<table summary="Series and Class/Contract Information" width="100%">
				<tr align="left">
					<td align="left" colspan="3" width="8%"><b>CIK</b></td>
					<td align="left" colspan="4" width="90%"></td>
				</tr>
				<tr align="left">
					<td align="left" width="2%"></td>
					<td align="left" colspan="2"><b>Series ID</b></td>
					<td align="left" colspan="3"></td>
				</tr>
				<tr align="left">
					<td align="left" width="2%"></td>
					<td align="left" width="2%"></td>
					<td align="left"><b>Class/Contract</b></td>
					<td align="left"><b>Name</b></td>
				</tr>
				<tr>
					<td align="left" colspan="4"><b class="blue">Acquiring:</b></td>
				</tr>
				<xsl:if test="acquiringCik != ''">
				<tr>
					<td width="15%" colspan="3">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="acquiringCik" />
							<xsl:with-param name="aclass" select="'search'" />
						</xsl:call-template>
					<!-- <xsl:value-of select="acquiringCik"/> -->
					</td>
					<td width="85%"><xsl:value-of select="acquiringEntityName"/></td>
				</tr>
				<xsl:if test="acquiringSeriesId != ''">
				<tr>
					<td></td>
					<td width="15%" colspan="2">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="acquiringSeriesId" />
							<xsl:with-param name="aclass" select="'hot'" />
						</xsl:call-template>
					</td>
					<td width="85%"><xsl:value-of select="acquiringSeriesName"/></td>
				</tr>
				<xsl:if test="acquiringClassContractId != ''">

				<tr>
					<td colspan="2"></td>
					<td width="13%">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="acquiringClassContractId" />
							<xsl:with-param name="aclass" select="'subCat'" />
						</xsl:call-template>
					</td>
					<td width="80%"><xsl:value-of select="acquiringClassContractName"/></td>
				</tr>
				</xsl:if>
				</xsl:if>
				</xsl:if>
				<xsl:for-each select="key('merger-by-cik-seriesId-classContractId', concat(acquiringCik,'+',acquiringSeriesId,'+',acquiringClassContractId))"> 
				<tr>
					<td align="left" colspan="4"><b class="blue">Target:</b></td>
				</tr>			
				<xsl:if test="targetCik != ''">
				<tr>
					<td width="15%" colspan="3">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="targetCik" />
							<xsl:with-param name="aclass" select="'search'" />
						</xsl:call-template>
					</td>
					<td width="85%"><xsl:value-of select="targetEntityName"/></td>
				</tr>
				<xsl:if test="targetSeriesId != ''">
				<tr>
					<td></td>
					<td width="15%" colspan="2">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="targetSeriesId" />
							<xsl:with-param name="aclass" select="'hot'" />
						</xsl:call-template>
					</td>
					<td width="85%"><xsl:value-of select="targetSeriesName"/></td>
				</tr>
				<xsl:if test="targetClassContractId != ''">
				<tr>
					<td></td>
					<td></td>
					<td width="15%">
						<xsl:call-template name="linkCIK">
							<xsl:with-param name="aCIK" select="targetClassContractId" />
							<xsl:with-param name="aclass" select="'subCat'" />
						</xsl:call-template>
					</td>
					<td width="85%"><xsl:value-of select="targetClassContractName"/></td>
				</tr>
				</xsl:if>
				</xsl:if>
				</xsl:if>				
				</xsl:for-each>
			</table>
		</td>
	</tr>

	</xsl:for-each>

</xsl:template>

<xsl:template match="merger">
</xsl:template>

   <xsl:template name="linkCIK">
      <xsl:param name="aCIK" />
      <xsl:param name="aclass" />
      <xsl:call-template name="createCIKLink" >
         <xsl:with-param name="aCIK" select="$aCIK"></xsl:with-param>
         <xsl:with-param name="label" select="$aCIK"></xsl:with-param>
         <xsl:with-param name="aclass" select="$aclass"></xsl:with-param>
     </xsl:call-template>
   </xsl:template>

   <xsl:template name="linkFileNumber">
      <xsl:param name="aFileNumber" />
      <xsl:param name="aclass" />
      <xsl:call-template name="createFileNumberLink" >
         <xsl:with-param name="aFileNumber" select="$aFileNumber"></xsl:with-param>
         <xsl:with-param name="label" select="$aFileNumber"></xsl:with-param>
         <xsl:with-param name="aclass" select="$aclass"></xsl:with-param>
     </xsl:call-template>
   </xsl:template>

   <xsl:template name="createFileNumberLink">
      <xsl:param name="aFileNumber" />
      <xsl:param name="label" />
      <xsl:param name="aclass" />
      <xsl:element name="a">
         <xsl:attribute name="class"><xsl:value-of select="$aclass" /></xsl:attribute>
         <xsl:attribute name="href">http://www.sec.gov/cgi-bin/browse-edgar?action=getcompany&amp;filenum=<xsl:value-of select="$aFileNumber" /></xsl:attribute>
         <xsl:apply-templates select="$label" mode="mode0" />
      </xsl:element>
   </xsl:template>

<xsl:template match="edgarSubmission/effectiveData/filer">
	<tr>
	   <td colspan="2" style="border-top:thin solid black">&#160;</td>
	</tr>
	<tr>
		<td align="left" width="20%"><b>CIK:</b></td>
		<td width="80%">
			<xsl:call-template name="linkCIK">
				<xsl:with-param name="aCIK" select="cik" />
				<xsl:with-param name="aclass" select="'search'" />
			</xsl:call-template>
		</td>
	</tr>
	<tr>
		<td align="left" width="20%" valign="top"><b>Company Name:</b></td>
		<td width="80%"><xsl:value-of select="entityName"/></td>
	</tr>
	<tr>
		<td align="left" width="20%"><b>File Number:</b></td>
		<td width="80%">
			<xsl:call-template name="linkFileNumber">
				<xsl:with-param name="aFileNumber" select="fileNumber"></xsl:with-param>
			</xsl:call-template>

		</td>
	</tr>
        <xsl:apply-templates select="seriesClassContractData"/>
</xsl:template>

<xsl:template match="/">
	<html>
		<head>
			<title>Notice of Qualification</title>
			<script language="JavaScript" src="/include/sec.js" type="text/javascript"></script>
			<style type="text/css">
              .FormData {color: blue; background-color: white; font-size: small; font-family: Times, serif}
              .SmallFormData {color: blue; background-color: white; font-size: x-small; font-family: Times, serif}
              .FootnoteData {color: green; background-color: white; font-size: x-small; font-family: Times, serif}
              .FormText {font-size: x-small; font-family: arial, helvetica, sans-serif}
              .SmallFormText {font-size: xx-small; font-family: arial, helvetica, sans-serif}
              .FormTitle {font-size: medium; font-family: arial, helvetica, sans-serif; font-weight: bold}
              .FormName {font-size: large; font-family: arial, helvetica, sans-serif; font-weight: bold}
              body {background: white}             
			</style>
		</head>
		<body>
			<table align="center" width="700" summary="Form Header">
                           <thead>
				<tr>
					<td align="center" colspan="2" class="FormTitle">UNITED STATES</td>
				</tr>
				<tr>
					<td align="center" colspan="2" class="FormTitle">SECURITIES AND EXCHANGE COMMISSION</td>
				</tr>
				<tr>
					<td align="center" colspan="2" class="FormText">Washington, D.C. 20549</td>
				</tr>
				<tr>
					<td align="center" colspan="2" class="FormName">Notice of Qualification</td>
				</tr>
                             </thead>
                             <tbody>
				<tr>
				  <xsl:variable name='year' select='substring(edgarSubmission/effectiveData/finalEffectivenessDispDate,1,4)'/>
				  <xsl:variable name='month' select='substring(edgarSubmission/effectiveData/finalEffectivenessDispDate,6,2)'/>
				  <xsl:variable name='day' select='number(substring(edgarSubmission/effectiveData/finalEffectivenessDispDate,9,2))'/>
					<td align="left" width="20%"><b>Date Qualified:</b></td>
					<td width="80%">
					  <xsl:choose>
					    <xsl:when test="$month = 1">January </xsl:when>
						<xsl:when test="$month = 2">February </xsl:when>
						<xsl:when test="$month = 3">March </xsl:when>
						<xsl:when test="$month = 4">April </xsl:when>
						<xsl:when test="$month = 5">May </xsl:when>
						<xsl:when test="$month = 6">June </xsl:when>
						<xsl:when test="$month = 7">July </xsl:when>
						<xsl:when test="$month = 8">August </xsl:when>
						<xsl:when test="$month = 9">September </xsl:when>
						<xsl:when test="$month = 10">October </xsl:when>
						<xsl:when test="$month = 11">November </xsl:when>
						<xsl:when test="$month = 12">December </xsl:when>
						<xsl:otherwise><xsl:value-of select="edgarSubmission/effectiveData/finalEffectivenessDispDate"/></xsl:otherwise>
					  </xsl:choose>
					  <xsl:value-of select="$day"/>,
					  <xsl:value-of select="concat($year,'  ')"/>
                      <xsl:if test="edgarSubmission/effectiveData/finalEffectivenessDispTime != ''">
						<xsl:variable name='hour' select='number(substring(edgarSubmission/effectiveData/finalEffectivenessDispTime,1,2))'/>
						<xsl:variable name='minute' select='substring(edgarSubmission/effectiveData/finalEffectivenessDispTime,4,2)'/>
						<xsl:choose>
						  <xsl:when test="$hour &gt; 11">
						    <xsl:choose>
						      <xsl:when test="$hour &lt; 13">
						        <xsl:value-of select="$hour"/>:<xsl:value-of select="$minute"/> P.M.
						      </xsl:when>
						      <xsl:otherwise>
						        <xsl:variable name='disphour' select='$hour - 12' />
						        <xsl:value-of select="$disphour"/>:<xsl:value-of select="$minute"/> P.M.
                                                      <!-- The time between midingt and midnight+59min is not addressed here
                                                           since no filing expected during that time
                                                      -->
						      </xsl:otherwise>
						    </xsl:choose>
						  </xsl:when>
						  <xsl:otherwise>
						    <xsl:value-of select="$hour"/>:<xsl:value-of select="$minute"/> A.M.
						  </xsl:otherwise>
						</xsl:choose>
					  </xsl:if> 
                    </td>
				</tr>
<!--
			</table>
			<table align="center" width="700" summary="Form Data">
-->
				<xsl:if test="edgarSubmission/effectiveData/accessionNumber !=''"> 
					<tr>
						<td align="left" width="20%"><b>Accession Number:</b></td>
						<td width="80%"><xsl:value-of select="edgarSubmission/effectiveData/accessionNumber"/></td>
					</tr>
				</xsl:if>
				<xsl:if test="edgarSubmission/effectiveData/submissionType !=''"> 
					<tr>
						<td align="left" width="20%"><b>Submission Type:</b></td>
						<td width="80%"><xsl:value-of select="edgarSubmission/effectiveData/submissionType"/></td>
					</tr>
				</xsl:if>
				<xsl:if test="edgarSubmission/effectiveData/form !=''"> 
					<tr>
						<td align="left" width="20%"><b>Form:</b></td>
						<td width="80%"><xsl:value-of select="edgarSubmission/effectiveData/form"/></td>
					</tr>
				</xsl:if>

				<xsl:apply-templates select="edgarSubmission/effectiveData/filer"/>
                           </tbody>
			</table>
		</body>
	</html>
</xsl:template>

</xsl:stylesheet>
