<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

   <!--
   XSL Stylesheet for Securities Derivative Table in SEC Forms 3, 4 and 5
   Based on DTDs: SecurityData.dtd (Version 1.0)
   Version 0.9 - Dated April 22, 2003
   Created By: SAIC
   Created for: SEC
   -->

   <xsl:template name="DerivativeTableHeader">
      <xsl:param name="Title" />

      <b>Table II - <xsl:value-of select="$Title" /></b>

      <br />

      <b>(e.g., puts, calls, warrants, options, convertible securities)</b>
   </xsl:template>

   <xsl:template name="DerivativeHeader3">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="8" align="center" class="FormTextC">
            <xsl:call-template name="DerivativeTableHeader">
               <xsl:with-param name="Title" select="'Derivative Securities Beneficially Owned'" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="35%" valign="top" rowspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="DerivativeSecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="9%" valign="top" colspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="DateExerTitleBox">
               <xsl:with-param name="BoxNumber" select="2" />
            </xsl:call-template>
         </th>

         <th width="26%" valign="top" colspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="TitleAmountBox">
               <xsl:with-param name="BoxNumber" select="3" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" rowspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="ConversionTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="8%" valign="top" rowspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="5" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>

         <th width="15%" valign="top" rowspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="6" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="4%" valign="bottom" align="center" class="MedSmallFormText">Date Exercisable</th>

         <th width="5%" valign="bottom" align="center" class="MedSmallFormText">Expiration Date</th>

         <th width="20%" valign="bottom" align="center" class="MedSmallFormText">Title</th>

         <th width="6%" valign="bottom" align="center" class="MedSmallFormText">Amount or Number of Shares</th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template name="DerivativeHeader4">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="16" align="center" class="FormTextC">
            <xsl:call-template name="DerivativeTableHeader">
               <xsl:with-param name="Title" select="'Derivative Securities Acquired, Disposed of, or Beneficially Owned'" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="13%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DerivativeSecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />

               <xsl:with-param name="InstructionNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="5%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ConversionTitleBox">
               <xsl:with-param name="BoxNumber" select="2" />
            </xsl:call-template>
         </th>

         <th width="5%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionDateTitleBox">
               <xsl:with-param name="BoxNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="5%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ExecutionDateTitleBox">
               <xsl:with-param name="BoxNumber" select="'3A'" />
            </xsl:call-template>
         </th>

         <th width="9%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionCodeTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />

               <xsl:with-param name="InstructionNumber" select="8" />
            </xsl:call-template>
         </th>

         <th width="10%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="NumDerivativesTitleBox">
               <xsl:with-param name="BoxNumber" select="5" />

               <xsl:with-param name="InstructionNumber" select="'3, 4 and 5'" />
            </xsl:call-template>
         </th>

         <th width="9%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DateExerTitleBox">
               <xsl:with-param name="BoxNumber" select="6" />
            </xsl:call-template>
         </th>

         <th width="17%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TitleAmountBox">
               <xsl:with-param name="BoxNumber" select="7" />

               <xsl:with-param name="InstructionNumber" select="'3 and 4'" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DervPriceTitleBox">
               <xsl:with-param name="BoxNumber" select="8" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="NumDerivTitleBox">
               <xsl:with-param name="BoxNumber" select="9" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="10" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="11" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="4%" valign="bottom" align="center" class="SmallFormText">Code</th>

         <th width="4%" valign="bottom" align="center" class="SmallFormText">V</th>

         <th width="5%" valign="bottom" align="center" class="SmallFormText">(A)</th>

         <th width="5%" valign="bottom" align="center" class="SmallFormText">(D)</th>

         <th width="5%" valign="bottom" align="center" class="SmallFormText">Date Exercisable</th>

         <th width="4%" valign="bottom" align="center" class="SmallFormText">Expiration Date</th>

         <th width="10%" valign="bottom" align="center" class="SmallFormText">Title</th>

         <th width="7%" valign="bottom" align="center" class="SmallFormText">Amount or Number of Shares</th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template name="DerivativeHeader5">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="15" align="center" class="FormTextC">
            <xsl:call-template name="DerivativeTableHeader">
               <xsl:with-param name="Title" select="'Derivative Securities Acquired, Disposed of, or Beneficially Owned'" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="13%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DerivativeSecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />

               <xsl:with-param name="InstructionNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ConversionTitleBox">
               <xsl:with-param name="BoxNumber" select="2" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionDateTitleBox">
               <xsl:with-param name="BoxNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ExecutionDateTitleBox">
               <xsl:with-param name="BoxNumber" select="'3A'" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionCodeTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />

               <xsl:with-param name="InstructionNumber" select="8" />
            </xsl:call-template>
         </th>

         <th width="12%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="NumDerivativesTitleBox">
               <xsl:with-param name="BoxNumber" select="5" />

               <xsl:with-param name="InstructionNumber" select="'3, 4 and 5'" />
            </xsl:call-template>
         </th>

         <th width="10%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DateExerTitleBox">
               <xsl:with-param name="BoxNumber" select="6" />
            </xsl:call-template>
         </th>

         <th width="18%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TitleAmountBox">
               <xsl:with-param name="BoxNumber" select="7" />

               <xsl:with-param name="InstructionNumber" select="'3 and 4'" />
            </xsl:call-template>
         </th>

         <th width="5%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="DervPriceTitleBox">
               <xsl:with-param name="BoxNumber" select="8" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="NumDerivTitleBox">
               <xsl:with-param name="BoxNumber" select="9" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="10" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="11" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="6%" valign="bottom" align="center" class="SmallFormText">(A)</th>

         <th width="6%" valign="bottom" align="center" class="SmallFormText">(D)</th>

         <th width="5%" valign="bottom" align="center" class="SmallFormText">Date Exercisable</th>

         <th width="5%" valign="bottom" align="center" class="SmallFormText">Expiration Date</th>

         <th width="12%" valign="bottom" align="center" class="SmallFormText">Title</th>

         <th width="6%" valign="bottom" align="center" class="SmallFormText">Amount or Number of Shares</th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template match="derivativeSecurity" mode="form3">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="exerciseDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="expirationDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity/underlyingSecurityTitle" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity" />
         </td>

         <td align="center">
            <xsl:apply-templates select="conversionOrExercisePrice" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="footnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="footnoted"/>
         </td>
      </tr>
   </xsl:template>
   
   <xsl:template match="derivativeSecurity" mode="form4">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="conversionOrExercisePrice" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="deemedExecutionDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='3'">
               <xsl:apply-templates select="transactionCoding/transactionFormType" mode="Small" />
            </xsl:if>
            <xsl:apply-templates select="transactionCoding/transactionCode" mode="Small" />
            <xsl:call-template name="TestCheckMark-Span">
               <xsl:with-param name="TestThis" select="transactionCoding/equitySwapInvolved" />
               <xsl:with-param name="MarkValue" select="/K" />
               <xsl:with-param name="TestThis" select="SmallFormData" />
            </xsl:call-template>
            <xsl:apply-templates select="transactionCoding/footnoteId" />
         </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='5'">
               <span class="SmallFormData">V</span>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:if test="transactionAmounts/transactionAcquiredDisposedCode/value='A'">
               <xsl:apply-templates select="transactionAmounts/transactionShares" mode="smallFootnoted"/>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:if test="transactionAmounts/transactionAcquiredDisposedCode/value='D'">
               <xsl:apply-templates select="transactionAmounts/transactionShares" mode="smallFootnoted"/>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:apply-templates select="exerciseDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="expirationDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity/underlyingSecurityTitle" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity" />
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts" />
         </td>

         <td align="center">
            <xsl:apply-templates select="postTransactionAmounts" mode="small" />
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="smallFootnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="smallFootnoted"/>
         </td>
      </tr>
   </xsl:template>

   <xsl:template match="derivativeSecurity" mode="form5">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="conversionOrExercisePrice" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="deemedExecutionDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='3' or transactionCoding/transactionFormType='4'">
               <xsl:apply-templates select="transactionCoding/transactionFormType" mode="Small" />
            </xsl:if>
            <xsl:apply-templates select="transactionCoding/transactionCode" mode="Small" />
            <xsl:apply-templates select="transactionCoding/footnoteId" />
         </td>

         <td align="center">
            <xsl:if test="transactionAmounts/transactionAcquiredDisposedCode/value='A'">
               <xsl:apply-templates select="transactionAmounts/transactionShares" mode="smallFootnoted"/>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:if test="transactionAmounts/transactionAcquiredDisposedCode/value='D'">
               <xsl:apply-templates select="transactionAmounts/transactionShares" mode="smallFootnoted"/>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:apply-templates select="exerciseDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="expirationDate" mode="smallFormatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity/underlyingSecurityTitle" mode="smallFootnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="underlyingSecurity" mode="small" />
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts" />
         </td>

         <td align="center">
            <xsl:apply-templates select="postTransactionAmounts" mode="small" />
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="smallFootnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="smallFootnoted"/>
         </td>
      </tr>
   </xsl:template>
   
   <xsl:template match="transactionAmounts">
      <xsl:choose>
         <xsl:when test="transactionValue!=''">
            $<xsl:apply-templates select="transactionValue" mode="smallFootnoted"/>
         </xsl:when>
         
         <xsl:otherwise>
            <xsl:apply-templates select="transactionShares" mode="smallFootnoted"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   
   <xsl:template match="underlyingSecurity">
      <xsl:choose>
         <xsl:when test="underlyingSecurityValue!=''">
            $<xsl:apply-templates select="underlyingSecurityValue" mode="footnoted"/>
         </xsl:when>
         
         <xsl:otherwise>
            <xsl:apply-templates select="underlyingSecurityShares" mode="footnoted"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <xsl:template match="underlyingSecurity" mode="small" >
      <xsl:choose>
         <xsl:when test="underlyingSecurityValue!=''">
            $<xsl:apply-templates select="underlyingSecurityValue" mode="smallFootnoted"/>
         </xsl:when>
         
         <xsl:otherwise>
            <xsl:apply-templates select="underlyingSecurityShares" mode="smallFootnoted"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <xsl:template match="postTransactionAmounts">
      <xsl:choose>
         <xsl:when test="valueOwnedFollowingTransaction!=''">
            $<xsl:apply-templates select="valueOwnedFollowingTransaction" mode="footnoted"/>
         </xsl:when>
         
         <xsl:otherwise>
            <xsl:apply-templates select="sharesOwnedFollowingTransaction" mode="footnoted"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <xsl:template match="postTransactionAmounts" mode="small">
      <xsl:choose>
         <xsl:when test="valueOwnedFollowingTransaction!=''">
            $<xsl:apply-templates select="valueOwnedFollowingTransaction" mode="smallFootnoted"/>
         </xsl:when>
         
         <xsl:otherwise>
            <xsl:apply-templates select="sharesOwnedFollowingTransaction" mode="smallFootnoted"/>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>
   
   <xsl:template name="DerivativeSecurityTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Title of Derivative Security (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="DateExerTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Date Exercisable and Expiration Date 
      <xsl:call-template name="DateLabel" />
   </xsl:template>

   <xsl:template name="TitleAmountBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Title and Amount of Securities Underlying Derivative Security (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="ConversionTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Conversion or Exercise Price of Derivative Security
   </xsl:template>

   <xsl:template name="TransactionDateTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Transaction Date
      <xsl:call-template name="DateLabel" />
   </xsl:template>

   <xsl:template name="ExecutionDateTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Deemed Execution Date, if any
      <xsl:call-template name="DateLabel" />
   </xsl:template>

   <xsl:template name="TransactionCodeTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Transaction Code (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="NumDerivativesTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. 
      Number of Derivative Securities Acquired (A) or Disposed of (D) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="DervPriceTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Price of Derivative Security (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="NumDerivTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. 
      Number of derivative Securities Beneficially Owned Following Reported Transaction(s) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="OwnershipTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Ownership Form: Direct (D) or Indirect (I) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="IndirectTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Nature of Indirect Beneficial Ownership (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

</xsl:stylesheet>

