<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

   <!--
   XSL Stylesheet for Securities NON-Derivative Table in SEC Forms 3, 4 and 5
   Based on DTDs: SecurityData.dtd (Version 1.0)
   Version 1.0 - Dated February 11, 2003
   Created By: SAIC
   Created for: SEC
   -->

   <xsl:template name="NonDerivativeHeader3">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="4" align="center" class="FormTextC">
            <b>Table I - Non-Derivative Securities Beneficially Owned</b>
         </th>
      </tr>

      <tr>
         <th width="44%" valign="top" align="left" class="MedSmallFormText">
            <xsl:call-template name="SecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="19%" valign="top" align="left" class="MedSmallFormText">
            <xsl:call-template name="Amount3TitleBox">
               <xsl:with-param name="BoxNumber" select="2" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="11%" valign="top" align="left" class="MedSmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="3" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>

         <th width="26%" valign="top" align="left" class="MedSmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />

               <xsl:with-param name="InstructionNumber" select="5" />
            </xsl:call-template>
         </th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template name="NonDerivativeHeader4">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="11" align="center" class="FormTextC">
            <b>Table I - Non-Derivative Securities Acquired, Disposed of, or Beneficially Owned</b>
         </th>
      </tr>

      <tr>
         <th width="36%" valign="top" rowspan="2" align="left" class="MedSmallFormText">
            <xsl:call-template name="SecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />

               <xsl:with-param name="InstructionNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransDateTitleBox">
               <xsl:with-param name="BoxNumber" select="2" />
            </xsl:call-template>
         </th>

         <th width="5%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ExecDateTitleBox">
               <xsl:with-param name="BoxNumber" select="'2A'" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" colspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionTitleBox">
               <xsl:with-param name="BoxNumber" select="3" />

               <xsl:with-param name="InstructionNumber" select="8" />
            </xsl:call-template>
         </th>

         <th width="19%" valign="top" colspan="3" align="left" class="SmallFormText">
            <xsl:call-template name="AcqDispTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />

               <xsl:with-param name="InstructionNumber" select="'3, 4 and 5'" />
            </xsl:call-template>
         </th>

         <th width="11%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="Amount4TitleBox">
               <xsl:with-param name="BoxNumber" select="5" />

               <xsl:with-param name="InstructionNumber" select="'3 and 4'" />
            </xsl:call-template>
         </th>

         <th width="9%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="6" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="8%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="7" />

               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="4%" align="center" class="SmallFormText">Code</th>

         <th width="3%" align="center" class="SmallFormText">V</th>

         <th width="8%" align="center" class="SmallFormText">Amount</th>

         <th width="5%" align="center" class="SmallFormText">(A) or (D)</th>

         <th width="6%" align="center" class="SmallFormText">Price</th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template name="NonDerivativeHeader5">
      <thead>
      <tr>
         <th width="100%" valign="top" colspan="16" align="center" class="FormTextC">
            <b>Table I - Non-Derivative Securities Acquired, Disposed of, or Beneficially Owned</b>
         </th>
      </tr>

      <tr>
         <th width="28%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="SecurityTitleBox">
               <xsl:with-param name="BoxNumber" select="1" />
               <xsl:with-param name="InstructionNumber" select="3" />
            </xsl:call-template>
         </th>

         <th width="7%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransDateTitleBox">
               <xsl:with-param name="BoxNumber" select="2" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="ExecDateTitleBox">
               <xsl:with-param name="BoxNumber" select="'2A'" />
            </xsl:call-template>
         </th>

         <th width="6%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="TransactionTitleBox">
               <xsl:with-param name="BoxNumber" select="3" />
               <xsl:with-param name="InstructionNumber" select="8" />
            </xsl:call-template>
         </th>

         <th width="24%" valign="top" colspan="3" align="left" class="SmallFormText">
            <xsl:call-template name="AcqDispTitleBox">
               <xsl:with-param name="BoxNumber" select="4" />
               <xsl:with-param name="InstructionNumber" select="'3, 4 and 5'" />
            </xsl:call-template>
         </th>

         <th width="11%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="Amount5TitleBox">
               <xsl:with-param name="BoxNumber" select="5" />
               <xsl:with-param name="InstructionNumber" select="'3 and 4'" />
            </xsl:call-template>
         </th>

         <th width="8%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="OwnershipTitleBox">
               <xsl:with-param name="BoxNumber" select="6" />
               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>

         <th width="9%" valign="top" rowspan="2" align="left" class="SmallFormText">
            <xsl:call-template name="IndirectTitleBox">
               <xsl:with-param name="BoxNumber" select="7" />
               <xsl:with-param name="InstructionNumber" select="4" />
            </xsl:call-template>
         </th>
      </tr>

      <tr>
         <th width="10%" align="center" class="SmallFormText">Amount</th>

         <th width="5%" align="center" class="SmallFormText">(A) or (D)</th>

         <th width="9%" align="center" class="SmallFormText">Price</th>
      </tr>
      </thead>
   </xsl:template>

   <xsl:template match="nonDerivativeSecurity" mode="form3">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionShares" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="footnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="footnoted"/>
         </td>
      </tr>
   </xsl:template>

   <xsl:template match="nonDerivativeSecurity" mode="form4">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionDate" mode="formatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="deemedExecutionDate" mode="formatDate"/>
          </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='3'">
               <xsl:apply-templates select="transactionCoding/transactionFormType" mode="Small" />
            </xsl:if>
            <xsl:apply-templates select="transactionCoding/transactionCode" mode="Small" />
            <xsl:call-template name="TestCheckMark-Span">
               <xsl:with-param name="TestThis" select="transactionCoding/equitySwapInvolved" />
               <xsl:with-param name="MarkValue" select="'/K'" />
               <xsl:with-param name="SpanClass" select="'SmallFormData'" />
            </xsl:call-template>
            <xsl:apply-templates select="transactionCoding/footnoteId" />
         </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='5'">
               <span class="SmallFormData">V</span>
            </xsl:if>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionShares" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionAcquiredDisposedCode" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionValue" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="postTransactionAmounts" />
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="footnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="footnoted"/>
         </td>
      </tr>
   </xsl:template>
   
   <xsl:template match="nonDerivativeSecurity" mode="form5">
      <tr>
         <td align="left">
            <xsl:apply-templates select="securityTitle" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionDate" mode="formatDate"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="deemedExecutionDate" mode="formatDate"/>
         </td>

         <td align="center">
            <xsl:if test="transactionCoding/transactionFormType='3' or transactionCoding/transactionFormType='4'">
               <xsl:apply-templates select="transactionCoding/transactionFormType" mode="Normal" />
            </xsl:if>
            <xsl:apply-templates select="transactionCoding/transactionCode" mode="Normal"/>
            <xsl:call-template name="TestCheckMark-Span">
               <xsl:with-param name="TestThis" select="transactionCoding/equitySwapInvolved" />
               <xsl:with-param name="MarkValue" select="'/K'" />
               <xsl:with-param name="SpanClass" select="'formData'" />
            </xsl:call-template>
            <xsl:apply-templates select="transactionCoding/footnoteId" />
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionShares" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionAcquiredDisposedCode" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="transactionAmounts/transactionValue" mode="footnoted"/>
         </td>

         <td align="center">
            <xsl:apply-templates select="postTransactionAmounts" />
         </td>

         <td align="center">
            <xsl:apply-templates select="ownershipNature/directOrIndirectOwnership" mode="footnoted"/>
         </td>

         <td align="left">
            <xsl:apply-templates select="ownershipNature/natureOfOwnership" mode="footnoted"/>
         </td>
      </tr>
   </xsl:template>

   <xsl:template name="SecurityTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Title of Security (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="TransDateTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Transaction Date
      <xsl:call-template name="DateLabel" />
   </xsl:template>

   <xsl:template name="ExecDateTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:value-of select="$BoxNumber" />. Deemed Execution Date, if any
      <xsl:call-template name="DateLabel" />
   </xsl:template>

   <xsl:template name="TransactionTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Transaction Code (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="AcqDispTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Securities Acquired (A) or Disposed Of (D) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="Amount3TitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. 
      Amount of Securities Beneficially Owned (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="Amount4TitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. 
      Amount of Securities Beneficially Owned Following Reported Transaction(s) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="Amount5TitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. 
      Amount of Securities Beneficially Owned at end of Issuer's Fiscal Year (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="OwnershipTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

      <xsl:value-of select="$BoxNumber" />. Ownership Form: Direct (D) or Indirect (I) (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>

   <xsl:template name="IndirectTitleBox">
      <xsl:param name="BoxNumber" />

      <xsl:param name="InstructionNumber" />

       <xsl:value-of select="$BoxNumber" />. Nature of Indirect Beneficial Ownership (Instr. 
      <xsl:value-of select="$InstructionNumber" />)
   </xsl:template>
</xsl:stylesheet>

