<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
   XSL Stylesheet for TA-1, TA-2, TA-W Forms, Common Sections
   Version 1.1 - Dated January 29, 2007 
   Created By: SAIC 
   Created for: SEC
   -->

   <xsl:template name="Section1">
      <xsl:call-template name="QuestionAnswerCIK">
         <xsl:with-param name="Number" select="'1(a)'" />
         <xsl:with-param name="Question" select="'Filer CIK: '" />
         <xsl:with-param name="aCIK" select="filer/cik" />
      </xsl:call-template>

      <xsl:call-template name="QuestionAnswer2RBT">
         <xsl:with-param name="Number" select="'1(c)'" />
         <xsl:with-param name="Question" select="'Live/Test Filing? '" />
         <xsl:with-param name="Test1" select="testOrLive='LIVE'" />
         <xsl:with-param name="Label1" select="'Live'" />
         <xsl:with-param name="Test2" select="testOrLive='TEST'" />
         <xsl:with-param name="Label2" select="'Test'" />
      </xsl:call-template>

      <xsl:if test="not(submissionType='TA-W')">
         <xsl:call-template name="QuestionAnswer1CB">
            <xsl:with-param name="Number" select="'1(e)'" />
            <xsl:with-param name="Question" select="'Is this filing an amendment to a previous filing? '" />
            <xsl:with-param name="Test" select="submissionType='TA-2/A' or submissionType='TA-1/A'" />
            <xsl:with-param name="Label" select="'Yes'" />
         </xsl:call-template>
      </xsl:if>

      <xsl:if test="starts-with(submissionType,'TA-1')">
         <xsl:call-template name="QuestionAnswerFiler">
            <xsl:with-param name="Number" select="'1(e)(i)'" />
            <xsl:with-param name="Question" select="'File Number: '" />
            <xsl:with-param name="aFileNumber" select="filer/fileNumber" />
         </xsl:call-template>
         <br />
      </xsl:if>

      <xsl:if test="starts-with(submissionType,'TA-2')">
         <xsl:call-template name="QuestionAnswer">
            <xsl:with-param name="Number" select="'1(h)'" />
            <xsl:with-param name="Question" select="'Full Name of Registrant as stated in Question 3 of Form TA-1: '" />
            <xsl:with-param name="Answer" select="registrant/entityName" />
            <xsl:with-param name="Breaks" select="1" />
         </xsl:call-template>
         <br />
      </xsl:if>
      <br />
   </xsl:template>

   <xsl:template name="Section2">
      <xsl:if test="starts-with(submissionType,'TA-1')">
         <xsl:call-template name="QuestionAnswerXRBs">
            <xsl:with-param name="Number" select="'2'" />
            <xsl:with-param name="Question" select="'Appropriate regulatory agency (check one):'" />
            <xsl:with-param name="Test1" select="1" />
            <xsl:with-param name="Label1" select="'Securities and Exchange Commission'" />
            <xsl:with-param name="Test2" select="0" />
            <xsl:with-param name="Label2" select="'Board of Governors of the Federal Reserve System'" />
            <xsl:with-param name="Test3" select="0" />
            <xsl:with-param name="Label3" select="'Federal Deposit Insurance Corporation'" />
            <xsl:with-param name="Test4" select="0" />
            <xsl:with-param name="Label4" select="'Comptroller of the Currency'" />
            <xsl:with-param name="Test5" select="0" />
            <xsl:with-param name="Label5" select="'Office of Thrift Supervision'" />
         </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="starts-with(submissionType,'TA-2')">
         <xsl:call-template name="QuestionAnswer3RBs">
            <xsl:with-param name="Number" select="'2(a)'" />
            <xsl:with-param name="Question" select="'During the reporting period, has the Registrant engaged a service company to perform any of its transfer agent functions?'" />
            <xsl:with-param name="Test1" select="engagedServiceCompany/function='ALL'" />
            <xsl:with-param name="Label1" select="'All'" />
            <xsl:with-param name="Test2" select="engagedServiceCompany/function='SOME'" />
            <xsl:with-param name="Label2" select="'Some'" />
            <xsl:with-param name="Test3" select="engagedServiceCompany/function='NONE'" />
            <xsl:with-param name="Label3" select="'None'" />
         </xsl:call-template>
         <xsl:if test="engagedServiceCompany/function='ALL'"> 
            <xsl:call-template name="Note">
               <xsl:with-param name="Part1" select="'A transfer agent that engaged a service company to perform '" />
               <xsl:with-param name="Style1" select="'normal'" />
               <xsl:with-param name="Part2" select="'all'" />
               <xsl:with-param name="Style2" select="'bold'" />
               <xsl:with-param name="Part3" select="' of its transfer agent functions during the reporting period is required to complete only Questions 1 through 3 and signature section of Form TA-2.'" />
               <xsl:with-param name="Style3" select="'normal'" />
            </xsl:call-template>
            <br />
         </xsl:if>

         <xsl:call-template name="Question">
            <xsl:with-param name="Number" select="'2(b)'" />
            <xsl:with-param name="Question" select="'If the answer to subsection (a) is all or some, provide the name(s) and transfer agent file number(s) of all service company(ies) engaged:'" />
         </xsl:call-template>

         <table border="1" width="80%" cellspacing="0" cellpadding="0" summary="">
            <tr>
               <th align="left" width="70%">Name of Transfer Agent(s):</th>
               <th align="left" width="30%">File Number:</th>
            </tr>
            <xsl:for-each select="engagedServiceCompany/serviceCompanyTransferAgent">
               <xsl:call-template name="AnswerFilerTable">
                  <xsl:with-param name="Answer" select="entityName" />
                  <xsl:with-param name="aFileNumber" select="fileNumber" />
               </xsl:call-template>
            </xsl:for-each>
         </table>
         
         <xsl:call-template name="QuestionAnswer2RBs">
            <xsl:with-param name="Number" select="'2(c)'" />
            <xsl:with-param name="Question" select="'During the reporting period, has the Registrant been engaged as a service company by a named transfer agent to perform transfer agent functions?'" />
            <xsl:with-param name="Test1" select="engagedAsServiceCompany/function" />
            <xsl:with-param name="Label1" select="'Yes'" />
            <xsl:with-param name="NotTest2" select="engagedAsServiceCompany/function" />
            <xsl:with-param name="Label2" select="'No'" />
         </xsl:call-template>
         
         <xsl:call-template name="Question">
            <xsl:with-param name="Number" select="'2(d)'" />
            <xsl:with-param name="Question" select="'If the answer to subsection (c) is yes, provide the name(s) and file number(s) of the named transfer agent(s) for which the Registrant has been engaged as a service company to perform transfer agent functions:'" />
         </xsl:call-template>
         <table border="1" width="80%" cellspacing="0" cellpadding="0" summary="">
            <tr>
               <th align="left" width="70%">Name of Transfer Agent(s):</th>
               <th align="left" width="30%">File Number:</th>
            </tr>
            <xsl:for-each select="engagedAsServiceCompany/asServiceCompanyTransferAgent">
               <xsl:call-template name="AnswerFilerTable">
                  <xsl:with-param name="Answer" select="entityName" />
                  <xsl:with-param name="aFileNumber" select="fileNumber" />
               </xsl:call-template>
            </xsl:for-each>
         </table>
      </xsl:if>
      
      <xsl:if test="starts-with(submissionType,'TA-W')">
         <xsl:call-template name="QuestionAnswerFiler">
            <xsl:with-param name="Number" select="'2'" />
            <xsl:with-param name="Question" select="'Transfer Agent File Number: '" />
            <xsl:with-param name="aFileNumber" select="filer/fileNumber" />
            <xsl:with-param name="Breaks" select="0" />
         </xsl:call-template>
         <br />
      </xsl:if>
      <br />
   </xsl:template>
   
   <xsl:template name="Section3">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(a)'" />
               <xsl:with-param name="Question" select="'Full Name of Registrant:'" />
               <xsl:with-param name="Answer" select="registrant/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(a)(i)'" />
               <xsl:with-param name="Question" select="'Previous name, if being amended:'" />
               <xsl:with-param name="Answer" select="registrant/previousEntityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(b)'" />
               <xsl:with-param name="Question" select="'Financial Industry Number Standard (FINS) number:'" />
               <xsl:with-param name="Answer" select="registrant/finsNumber" />
               <xsl:with-param name="Breaks" select="0" />
               <xsl:with-param name="JustText" select="1" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'3(c)'" />
               <xsl:with-param name="Question" select="'Address of principal office where transfer agent activities are, or will be, performed:'" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'3(c)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="AddressInfo" select="registrant/principalOfficeAddress" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'3(d)'" />
               <xsl:with-param name="Question" select="'Address of principal office where transfer agent activities are, or will be, performed: '" />
               <xsl:with-param name="Test1" select="registrant/differentMailingAddress" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/differentMailingAddress" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'3(d)'" />
               <xsl:with-param name="Question" select="'If `yes,` provide address(es):'" />
               <xsl:with-param name="AddressInfo" select="registrant/mailingAddress" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(e)'" />
               <xsl:with-param name="Question" select="'Telephone Number (Include Area Code)'" />
               <xsl:with-param name="Answer" select="registrant/telephoneNumber" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(a)'" />
               <xsl:with-param name="Question" select="'Registrant`s appropriate regulatory agency (ARA):'" />
               <xsl:with-param name="Answer" select="regulatoryAgency" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer3RBs">
               <xsl:with-param name="Number" select="'3(b)'" />
               <xsl:with-param name="Question" select="'During the reporting period, has the Registrant amended Form TA-1 within 60 calendar days following the date on which information reported therein became inaccurate, incomplete, or misleading?'" />
               <xsl:with-param name="Test1" select="inaccurateIncompleteMisleading/amendmentFiled='YES'" />
               <xsl:with-param name="Label1" select="'Yes, filed amendment(s)'" />
               <xsl:with-param name="Test2" select="inaccurateIncompleteMisleading/amendmentFiled='NO'" />
               <xsl:with-param name="Label2" select="'No, failed to file amendment(s)'" />
               <xsl:with-param name="Test3" select="inaccurateIncompleteMisleading/amendmentFiled='NA'" />
               <xsl:with-param name="Label3" select="'Not applicable'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3(c)'" />
               <xsl:with-param name="Question" select="'If the answer to subsection (b) is no, provide an explanation:'" />
               <xsl:with-param name="Answer" select="inaccurateIncompleteMisleading/additionalInformation" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'3'" />
               <xsl:with-param name="Question" select="'Full name of registrant:'" />
               <xsl:with-param name="Answer" select="registrant/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>
 
   <xsl:template name="Section4">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="QuestionAnswer2RBT">
               <xsl:with-param name="Number" select="'4'" />
               <xsl:with-param name="Question" select="'Does registrant conduct, or will it conduct, transfer agent activities at any location other than that given in Question 3(c) above?'" />
               <xsl:with-param name="Test1" select="registrant/conductBusinessInOtherLocations='true'" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="Test2" select="registrant/conductBusinessInOtherLocations='false'" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'4(a)'" />
               <xsl:with-param name="Question" select="'If `yes,` provide address(es):'" />
               <xsl:with-param name="AddressInfo" select="registrant/otherBusinessLocation" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'4(a)'" />
               <xsl:with-param name="Question" select="'Number of items received for transfer during the reporting period:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberItemsReceivedForTransfer" />
               <xsl:with-param name="QWidth" select="'90%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'4(b)'" />
               <xsl:with-param name="Question" select="'Number of individual securityholder accounts for which the 
TA maintained master securityholder filings:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberMasterSecurityHolderFilings" />
               <xsl:with-param name="QWidth" select="'90%'" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'4'" />
               <xsl:with-param name="Question" select="'Name under which transfer agent activities are conducted, if different from above:'" />
               <xsl:with-param name="Answer" select="registrant/activitiesConductedEntityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>
   
   <xsl:template name="Section5">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="QuestionAnswer2RBT">
               <xsl:with-param name="Number" select="'5'" />
               <xsl:with-param name="Question" select="'Does registrant act, or will it act, as a transfer agent solely for its own securities and/or securities of an affiliate(s)?'" />
               <xsl:with-param name="Test1" select="registrant/selfTransferAgent" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/selfTransferAgent" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'5(a)'" />
               <xsl:with-param name="Question" select="'Total number of individual securityholder accounts, 
including accounts in the Direct Registration System (DRS), dividend reinvestment plans and/or direct purchase plans as of December 31:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberIndividualAccounts" />
               <xsl:with-param name="QWidth" select="'90%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'5(b)'" />
               <xsl:with-param name="Question" select="'Number of individual securityholder dividend reinvestment plan and/or direct purchase plan accounts as of December 31:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberDivReinvDirPurPlanAccounts" />
               <xsl:with-param name="QWidth" select="'90%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'5(c)'" />
               <xsl:with-param name="Question" select="'Number of individual securityholder DRS accounts as of December 31:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberDirectRegistSystemAccounts" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'5(d)'" />
               <xsl:with-param name="Question" select="'Approximate percentage of individual securityholder accounts from subsection (a) in the following categories as of December 31:'" />
            </xsl:call-template>
            <table border="1" width="100%" cellspacing="0" cellpadding="0" summary="">
               <tr>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(i)'" />
                        <xsl:with-param name="Question" select="'Corporate Equity Securities'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(ii)'" />
                        <xsl:with-param name="Question" select="'Corporate Debt Securities'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(iii)'" />
                        <xsl:with-param name="Question" select="'Open-End Investment Company Securities'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(iv)'" />
                        <xsl:with-param name="Question" select="'Limited Partnership Securities'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(v)'" />
                        <xsl:with-param name="Question" select="'Municipal Debt Securities'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="'5(d)(vi)'" />
                        <xsl:with-param name="Question" select="'Other Securities'" />
                     </xsl:call-template>
                  </th>
                </tr>
                <xsl:for-each select="serviceCompanyData/securityHolderAccounts">
                  <xsl:call-template name="Answer6ColTable">
                     <xsl:with-param name="AnswerCol1" select="equitySecurity" />
                     <xsl:with-param name="AnswerCol2" select="debtSecurity" />
                     <xsl:with-param name="AnswerCol3" select="openEndInvestmentCompany" />
                     <xsl:with-param name="AnswerCol4" select="limitedPartnership" />
                     <xsl:with-param name="AnswerCol5" select="municipalDebt" />
                     <xsl:with-param name="AnswerCol6" select="other" />
                  </xsl:call-template>
               </xsl:for-each>
            </table>
            <xsl:if test="(serviceCompanyData/numberMasterSecurityHolderFilings &lt; 1000) and (serviceCompanyData/numberItemsReceivedForTransfer &lt; 1000)"> 
               <xsl:call-template name="Note">
                  <xsl:with-param name="Part1" select="'A registered transfer agent that received fewer than 1,000 items for transfer during the reporting period '" />
                  <xsl:with-param name="Style1" select="'normal'" />
                  <xsl:with-param name="Part2" select="'and'" />
                  <xsl:with-param name="Style2" select="'bold'" />
                  <xsl:with-param name="Part3" select="' that did not maintain master securityholder files for more than 1,000 individual securityholder accounts as of December 31 of the reporting period is required to complete only Questions 1 through 5, 11, and the signature section of Form TA-2.'" />
                  <xsl:with-param name="Style3" select="'normal'" />
               </xsl:call-template>
            </xsl:if>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="AddressBlockA">
               <xsl:with-param name="Number" select="'5'" />
               <xsl:with-param name="Question" select="'Address of registrants principle place of business:'" />
               <xsl:with-param name="AddressInfo" select="registrant/businessAddress" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>

   <xsl:template name="Section6">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="QuestionAnswer2RBT">
               <xsl:with-param name="Number" select="'6'" />
               <xsl:with-param name="Question" select="'Has registrant, as a named transfer agent, engaged, or will it engage, a service company to perform any transfer agent functions?'" />
               <xsl:with-param name="Test1" select="registrant/engagedServiceCompany" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/engagedServiceCompany" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="''" />
               <xsl:with-param name="Question" select="'If `yes,` provide the name(s) and address(es) of all service companies engaged, or that will be engaged, by the registrant to perform its transfer agent functions:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:for-each select="registrant/serviceCompany">
               <xsl:call-template name="QuestionAnswer">
                  <xsl:with-param name="Number" select="'6(a)'" />
                  <xsl:with-param name="Question" select="'Name:'" />
                  <xsl:with-param name="Answer" select="entityName" />
                  <xsl:with-param name="Breaks" select="1" />
               </xsl:call-template>
               <xsl:call-template name="QuestionAnswerFiler">
                  <xsl:with-param name="Number" select="'6(b)'" />
                  <xsl:with-param name="Question" select="'File Number: '" />
                  <xsl:with-param name="aFileNumber" select="fileNumber" />
               </xsl:call-template>
               <xsl:call-template name="AddressBlockI">
                  <xsl:with-param name="Number" select="'6(c)'" />
                  <xsl:with-param name="Question" select="''" />
                  <xsl:with-param name="AddressInfo" select="serviceCompanyAddress" />
               </xsl:call-template>
            </xsl:for-each>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'6'" />
               <xsl:with-param name="Question" select="'Number of securities issues for which Registrant acted in the following capacities, as of December 31:'" />
            </xsl:call-template>
            <table border="1" width="100%" cellspacing="0" cellpadding="0" summary="">
               <tr>
                  <th rowspan="2"></th>
                  <th colspan="2">
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Corporate Securities'" />
                     </xsl:call-template>
                  </th>
                  <th rowspan="2">
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Open-End Investment Company Securities'" />
                     </xsl:call-template>
                  </th>
                  <th rowspan="2">
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Limited Partnership Securities'" />
                     </xsl:call-template>
                  </th>
                  <th rowspan="2">
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Municipal Debt Securities'" />
                     </xsl:call-template>
                  </th>
                  <th rowspan="2">
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Other Securities'" />
                     </xsl:call-template>
                  </th>
               </tr>
               <tr>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Equity'" />
                     </xsl:call-template>
                  </th>
                  <th>
                     <xsl:call-template name="QuestionAnswer">
                        <xsl:with-param name="Number" select="''" />
                        <xsl:with-param name="Question" select="'Debt'" />
                     </xsl:call-template>
                  </th>
               </tr>
               <xsl:for-each select="serviceCompanyData/securityHolderData/transMaintainMasterSecHolder">
                  <xsl:call-template name="Answer7ColTable">
                     <xsl:with-param name="Number" select="'6(a)'" />
                     <xsl:with-param name="Question" select="'Receives items for transfer and maintains the master securityholder files:'" />
                     <xsl:with-param name="AnswerCol1" select="equitySecurity" />
                     <xsl:with-param name="AnswerCol2" select="debtSecurity" />
                     <xsl:with-param name="AnswerCol3" select="openEndInvestmentCompany" />
                     <xsl:with-param name="AnswerCol4" select="limitedPartnership" />
                     <xsl:with-param name="AnswerCol5" select="municipalDebt" />
                     <xsl:with-param name="AnswerCol6" select="other" />
                  </xsl:call-template>
               </xsl:for-each>
               <xsl:for-each select="serviceCompanyData/securityHolderData/transNotMaintMasterSecHolder">
                  <xsl:call-template name="Answer7ColTable">
                     <xsl:with-param name="Number" select="'6(b)'" />
                     <xsl:with-param name="Question" select="'Receives items for transfer but does not maintain the master securityholder files::'" />
                     <xsl:with-param name="AnswerCol1" select="equitySecurity" />
                     <xsl:with-param name="AnswerCol2" select="debtSecurity" />
                     <xsl:with-param name="AnswerCol3" select="openEndInvestmentCompany" />
                     <xsl:with-param name="AnswerCol4" select="limitedPartnership" />
                     <xsl:with-param name="AnswerCol5" select="municipalDebt" />
                     <xsl:with-param name="AnswerCol6" select="other" />
                  </xsl:call-template>
               </xsl:for-each>
               <xsl:for-each select="serviceCompanyData/securityHolderData/notTransMaintMasterSecHolder">
                  <xsl:call-template name="Answer7ColTable">
                     <xsl:with-param name="Number" select="'6(c)'" />
                     <xsl:with-param name="Question" select="'Does not receive items for transfer but maintains the master securityholder files:'" />
                     <xsl:with-param name="AnswerCol1" select="equitySecurity" />
                     <xsl:with-param name="AnswerCol2" select="debtSecurity" />
                     <xsl:with-param name="AnswerCol3" select="openEndInvestmentCompany" />
                     <xsl:with-param name="AnswerCol4" select="limitedPartnership" />
                     <xsl:with-param name="AnswerCol5" select="municipalDebt" />
                     <xsl:with-param name="AnswerCol6" select="other" />
                  </xsl:call-template>
               </xsl:for-each>
            </table>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'6'" />
               <xsl:with-param name="Question" select="'Furnish registrant`s reasons for ceasing the performance of transfer agent functions or for otherwise requesting withdrawal of its registration:'" />
               <xsl:with-param name="Answer" select="registrant/withdrawalDescription" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>

   <xsl:template name="Section7">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="QuestionAnswer2RBT">
               <xsl:with-param name="Number" select="'7'" />
               <xsl:with-param name="Question" select="'Has registrant been engaged, or will it be engaged, as a service company by a named transfer agent to perform transfer agent functions? '" />
               <xsl:with-param name="Test1" select="registrant/engagedAsServiceCompany" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/engagedAsServiceCompany" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="''" />
               <xsl:with-param name="Question" select="'If `yes,` provide the name(s) and File Number(s) of the named transfer agent(s) for which the registrant has been engaged, or will be engaged, as a service company to perform transfer agent functions:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:for-each select="registrant/asServiceCompany">
               <xsl:call-template name="QuestionAnswer">
                  <xsl:with-param name="Number" select="'7(a)'" />
                  <xsl:with-param name="Question" select="'Name:'" />
                  <xsl:with-param name="Answer" select="entityName" />
                  <xsl:with-param name="Breaks" select="1" />
               </xsl:call-template>
               <xsl:call-template name="QuestionAnswerFiler">
                  <xsl:with-param name="Number" select="'7(b)'" />
                  <xsl:with-param name="Question" select="'File Number: '" />
                  <xsl:with-param name="aFileNumber" select="fileNumber" />
               </xsl:call-template>
               <xsl:call-template name="AddressBlockI">
                  <xsl:with-param name="Number" select="'7(c)'" />
                  <xsl:with-param name="Question" select="''" />
                  <xsl:with-param name="AddressInfo" select="asServiceCompanyAddress" />
               </xsl:call-template>
            </xsl:for-each>
            <hr />
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'7'" />
               <xsl:with-param name="Question" select="'Scope of certain additional types of activities performed:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'7(a)'" />
               <xsl:with-param name="Question" select="'Number of issues for which dividend reinvestment plan and/or direct purchase plan services were provided, as of December 31:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/dividendReinvDirectPurchasePlan/numberIssues" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'7(b)'" />
               <xsl:with-param name="Question" select="'Number of issues for which DRS services were provided, as of December 31:'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/directRegistrationSystem/numberIssues" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'7(c)'" />
               <xsl:with-param name="Question" select="'Dividend disbursement and interest paying agent activities conducted during the reporting period:'" />
               <xsl:with-param name="Answer" select="''" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'7(c)(i)'" />
               <xsl:with-param name="Question" select="'number of issues'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/dividendAndInterest/numberIssues" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'7(c)(ii)'" />
               <xsl:with-param name="Question" select="'amount (in dollars)'" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/dividendAndInterest/amountIssues" />
               <xsl:with-param name="QWidth" select="'80%'" />
               <xsl:with-param name="Dollar" select="1" />
            </xsl:call-template>
            <br />
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'7'" />
               <xsl:with-param name="Question" select="'Furnish the last date registrant performed transfer agent functions as defined by Section 3(a)(25) of the Act for any security, including debt and equity, registered under Section 12 of the Act or which would be required to be registered except for the exemption from registration provided by paragraph (g)(2)(B) or (g)(2)(G) of that section.'" />
               <xsl:with-param name="Answer" select="registrant/lastActionDate"/>
               <xsl:with-param name="Breaks" select="1" />
               <xsl:with-param name="ADate" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'7(a)'" />
               <xsl:with-param name="Question" select="'Does registrant have any intention of performing in the near future a transfer agent function for any such security?'" />
               <xsl:with-param name="Test1" select="registrant/futureTransferAgentFunctions='true'" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="Test2" select="registrant/futureTransferAgentFunctions='false'" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <br />
         </xsl:when>
      </xsl:choose>
   </xsl:template>

   <xsl:template name="Section8">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <p align="center" class="FormText"><b>Completion of Question 8 on this form is required by all independent, non-issuer registrants 
            whose appropriate regulatory authority is the Securities and Exchange Commission.  Those registrants who are not required to 
            complete Question 8 should select `Not Applicable.`</b></p>
            <xsl:call-template name="QuestionAnswerXRBT">
               <xsl:with-param name="Number" select="'8'" />
               <xsl:with-param name="Question" select="'Is registrant a:'" />
               <xsl:with-param name="Test1" select="registrant/registrantType='Corporation'" />
               <xsl:with-param name="Label1" select="'Corporation'" />
               <xsl:with-param name="Test2" select="registrant/registrantType='Partnership'" />
               <xsl:with-param name="Label2" select="'Partnership'" />
               <xsl:with-param name="Test3" select="registrant/registrantType='Sole Proprietorship'" />
               <xsl:with-param name="Label3" select="'Sole Proprietorship'" />
               <xsl:with-param name="Test4" select="registrant/registrantType='Other'" />
               <xsl:with-param name="Label4" select="'Other'" />
               <xsl:with-param name="Test5" select="registrant/registrantType='Not Applicable' or registrant/registrantType='NA'" />
               <xsl:with-param name="Label5" select="'Not Applicable'" />
            </xsl:call-template>
            <xsl:if test="registrant/registrantType='Corporation' or registrant/registrantType='Partnership'">
               <p class="FormText"><b>Section for Initial Registration and for Amendments Reporting Additional Persons. (Corporation or Partnership)</b></p>
               <xsl:apply-templates select="registrant/corporationPartnershipData"/>
            </xsl:if>
            <xsl:if test="registrant/registrantType='Sole Proprietorship' or registrant/registrantType='Other'">
               <p class="FormText"><b>Section for Initial Registration and for Amendments Reporting Additional Persons. (Sole Proprietorship or Other)</b></p>
               <xsl:apply-templates select="registrant/solePropriertorshipOtherData"/>
            </xsl:if>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'8(a)'" />
               <xsl:with-param name="Question" select="'Number and aggregate market value of securities aged record differences, existing for more than 30 days, as of December 31: '" />
            </xsl:call-template>
            <table border="1" cellspacing="0" cellpadding="10" summary="Aggregate market value of securities">
              <tr><th></th><th class="FormText">Prior Transfer Agent(s)<br />(If applicable)</th><th class="FormText">Current Transfer Agent</th></tr>
              <xsl:call-template name="Answer3ColTable">
                 <xsl:with-param name="Number" select="'8(a)(i)'" />
                 <xsl:with-param name="RowHeader" select="'Number of issues: '" />
                 <xsl:with-param name="AnswerCol1" select="serviceCompanyData/securityHolderData/priorAgent/numberIssues" />
                 <xsl:with-param name="AnswerCol2" select="serviceCompanyData/securityHolderData/currentAgent/numberIssues" />
              </xsl:call-template>
              <xsl:call-template name="Answer3ColTable">
                 <xsl:with-param name="Number" select="'8(a)(ii)'" />
                 <xsl:with-param name="RowHeader" select="'Market value (in dollars): '" />
                 <xsl:with-param name="AnswerCol1" select="serviceCompanyData/securityHolderData/priorAgent/amountIssues" />
                 <xsl:with-param name="AnswerCol2" select="serviceCompanyData/securityHolderData/currentAgent/amountIssues" />
                 <xsl:with-param name="Dollar" select="1" />
              </xsl:call-template>
            </table>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'8(b)'" />
               <xsl:with-param name="Question" select="'Number of quarterly reports regarding buy-ins filed by the registrant with its ARA (including the SEC) during the reporting period pursuant to Rule 17Ad-11(c)(2) of the Act: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/numberFiled" />
               <xsl:with-param name="Breaks" select="0" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer3RBHs">
               <xsl:with-param name="Number" select="'8(c)'" />
               <xsl:with-param name="Question" select="'During the reporting period, did the Registrant file all quarterly reports regarding buy-ins with its ARA (including the SEC) required by Rule 17Ad-11(c)(2) of the Act?'" />
               <xsl:with-param name="Test1" select="serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/fileAll" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/fileAll" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="Test3">
                  <xsl:choose>
                     <xsl:when test="not(serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/fileAll)">1</xsl:when>
                     <xsl:otherwise><xsl:value-of select="serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/fileAll='NA' or serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/fileAll=''"/></xsl:otherwise>
                  </xsl:choose>
               </xsl:with-param>
               <xsl:with-param name="Label3" select="'NA'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'8(d)'" />
               <xsl:with-param name="Question" select="'If the answers to subsection (c) is no, provide an explanation for each failure to file: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/quarterlyReportsRegardingBuyIns/additionalInformation" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'8'" />
               <xsl:with-param name="Question" select="'Is registrant directly or indirectly involved in any legal actions or proceedings or aware of any potential claims against it in connection with its performance of transfer agent functions for any security?'" />
               <xsl:with-param name="Test1" select="registrant/subjectOfProceedings/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/subjectOfProceedings/involved" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'8(a)'" />
               <xsl:with-param name="Question" select="'If so, furnish complete information with respect to each:'" />
               <xsl:with-param name="Details" select="registrant/subjectOfProceedings/subjectOfProceedingsDetails" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>
   
   <xsl:template match="registrant/corporationPartnershipData">
   <!-- Section 8(a) [CORPORATION] -->
      <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(i)'" />
         <xsl:with-param name="Question" select="'Full Name:  '" />
         <xsl:with-param name="Answer" select="entityName" />
         <xsl:with-param name="Breaks" select="0" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(ii)'" />
         <xsl:with-param name="Question" select="'Relationship Start Date:  '" />
         <xsl:with-param name="Answer" select="relationshipStartDate" />
         <xsl:with-param name="Breaks" select="0" />
         <xsl:with-param name="ADate" select="1" />
      </xsl:call-template>
         <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(iii)'" />
         <xsl:with-param name="Question" select="'Title or Status:  '" />
         <xsl:with-param name="Answer" select="titleOrStatus" />
         <xsl:with-param name="Breaks" select="0" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswerXRBT">
         <xsl:with-param name="Number" select="'8(a)(iv)'" />
         <xsl:with-param name="Question" select="'Ownership Code:'" />
         <xsl:with-param name="Test1" select="ownershipCode='NA'" />
         <xsl:with-param name="Label1" select="'NA - 0 to 5%'" />
         <xsl:with-param name="Test2" select="ownershipCode='A'" />
         <xsl:with-param name="Label2" select="'A - 5% up to 10% '" />
         <xsl:with-param name="Test3" select="ownershipCode='B'" />
         <xsl:with-param name="Label3" select="'B - 10% up to 25%'" />
         <xsl:with-param name="Test4" select="ownershipCode='C'" />
         <xsl:with-param name="Label4" select="'C - 25% up to 50%'" />
         <xsl:with-param name="Test5" select="ownershipCode='D'" />
         <xsl:with-param name="Label5" select="'D - 50% up to 75% '" />
         <xsl:with-param name="Test6" select="ownershipCode='E'" />
         <xsl:with-param name="Label6" select="'E - 75% up to 100%'" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswerXRBT">
         <xsl:with-param name="Number" select="'8(a)(v)'" />
         <xsl:with-param name="Question" select="'Control Person:'" />
         <xsl:with-param name="Test1" select="controlPerson='true'" />
         <xsl:with-param name="Label1" select="' '" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(vi)'" />
         <xsl:with-param name="Question" select="'Relationship End Date:  '" />
         <xsl:with-param name="Answer" select="relationshipEndDate" />
         <xsl:with-param name="Breaks" select="0" />
         <xsl:with-param name="ADate" select="1" />
      </xsl:call-template>
      <br />
   </xsl:template>
   
   <xsl:template match="registrant/solePropriertorshipOtherData">
    <!-- Section 8(a) [Sole Propriertor] -->
     <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(i)'" />
         <xsl:with-param name="Question" select="'Full Name:  '" />
         <xsl:with-param name="Answer" select="entityName" />
         <xsl:with-param name="Breaks" select="0" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(ii)'" />
         <xsl:with-param name="Question" select="'Relationship Start Date:  '" />
         <xsl:with-param name="Answer" select="relationshipStartDate" />
         <xsl:with-param name="Breaks" select="0" />
      <xsl:with-param name="ADate" select="1" />
      </xsl:call-template>
         <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(iii)'" />
         <xsl:with-param name="Question" select="'Title or Status:  '" />
         <xsl:with-param name="Answer" select="titleOrStatus" />
         <xsl:with-param name="Breaks" select="0" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswerXRBT">
         <xsl:with-param name="Number" select="'8(a)(iv)'" />
         <xsl:with-param name="Question" select="'Ownership Code:'" />
         <xsl:with-param name="Test1" select="ownershipCode='NA'" />
         <xsl:with-param name="Label1" select="'NA - 0 to 5%'" />
         <xsl:with-param name="Test2" select="ownershipCode='A'" />
         <xsl:with-param name="Label2" select="'A - 5% up to 10% '" />
         <xsl:with-param name="Test3" select="ownershipCode='B'" />
         <xsl:with-param name="Label3" select="'B - 10% up to 25%'" />
         <xsl:with-param name="Test4" select="ownershipCode='C'" />
         <xsl:with-param name="Label4" select="'C - 25% up to 50%'" />
         <xsl:with-param name="Test5" select="ownershipCode='D'" />
         <xsl:with-param name="Label5" select="'D - 50% up to 75% '" />
         <xsl:with-param name="Test6" select="ownershipCode='E'" />
         <xsl:with-param name="Label6" select="'E - 75% up to 100%'" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswerXRBT">
         <xsl:with-param name="Number" select="'8(a)(v)'" />
         <xsl:with-param name="Question" select="'Control Person:'" />
         <xsl:with-param name="Test1" select="controlPerson='true'" />
         <xsl:with-param name="Label1" select="' '" />
      </xsl:call-template>
      <xsl:call-template name="QuestionAnswer">
         <xsl:with-param name="Number" select="'8(a)(vi)'" />
         <xsl:with-param name="Question" select="'Relationship End Date:  '" />
         <xsl:with-param name="Answer" select="relationshipEndDate" />
         <xsl:with-param name="Breaks" select="0" />
         <xsl:with-param name="ADate" select="1" />
      </xsl:call-template>
   </xsl:template>

   <xsl:template name="Section9">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'9'" />
               <xsl:with-param name="Question" select="'Does any person or entity not named in the answer to Question 8: '" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer3RBHs">
               <xsl:with-param name="Number" select="'9(a)'" />
               <xsl:with-param name="Question" select="'directly or indirectly, through agreement or otherwise exercise or have the power to exercise control over the management or policies of applicant; or . . . .'" />
               <xsl:with-param name="Test1" select="otherControlManagement/otherEntity" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="otherControlManagement/otherEntity" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="Test3" select="otherControlManagement/otherEntity='NA' or otherControlManagement/otherEntity=''" />
               <xsl:with-param name="Label3" select="'NA'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'9(a)(i)'" />
               <xsl:with-param name="Question" select="'Exact name of each person or entity: '" />
               <xsl:with-param name="Answer" select="otherControlManagement/otherControlManagementDetails/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'9(a)(ii)'" />
               <xsl:with-param name="Question" select="'Description of the Agreement or other basis: '" />
               <xsl:with-param name="Answer" select="otherControlManagement/otherControlManagementDetails/agreementDescription" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBT">
               <xsl:with-param name="Number" select="'9(b)'" />
               <xsl:with-param name="Question" select="'wholly or partially finance the business of applicant, directly or indirectly, in any manner other than by a public offering of securities made pursuant to the Securities Act of 1933 or by credit extended in the ordinary course of business by suppliers, banks and others ? . . . . . . . . . . . . . . . . . . . . . . . . . .'" />
               <xsl:with-param name="Test1" select="otherControlFinance/otherEntity" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="otherControlFinance/otherEntity" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'9(b)(i)'" />
               <xsl:with-param name="Question" select="'Exact name of each person or entity: '" />
               <xsl:with-param name="Answer" select="otherControlFinance/otherControlFinanceDetails/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'9(b)(ii)'" />
               <xsl:with-param name="Question" select="'Description of the Agreement or other basis: '" />
               <xsl:with-param name="Answer" select="otherControlFinance/otherControlFinanceDetails/agreementDescription" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="QuestionAnswer3RBHs">
               <xsl:with-param name="Number" select="'9(a)'" />
               <xsl:with-param name="Question" select="'During the reporting period, has the Registrant always been in compliance with the turnaround time for routine items as set forth in Rule 17Ad-2 of the Act?'" />
               <xsl:with-param name="Test1" select="serviceCompanyData/securityHolderData/turnaroundCompliant/alwaysCompliant" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="serviceCompanyData/securityHolderData/turnaroundCompliant/alwaysCompliant" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="Test3">
                  <xsl:choose>
                     <xsl:when test="not(serviceCompanyData/securityHolderData/turnaroundCompliant/alwaysCompliant)">1</xsl:when>
                  <xsl:otherwise><xsl:value-of select="serviceCompanyData/securityHolderData/turnaroundCompliant/alwaysCompliant='NA' or serviceCompanyData/securityHolderData/turnaroundCompliant/alwaysCompliant=''"/></xsl:otherwise>
                  </xsl:choose>
               </xsl:with-param>
               <xsl:with-param name="Label3" select="'NA'" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="''" />
               <xsl:with-param name="Question" select="'If the answer to subsection (a) is no, complete subsections (i) through (ii).'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'9(a)(i)'" />
               <xsl:with-param name="Question" select="'Provide the number of months during the reporting period in which the Registrant was not in compliance with the turnaround time for routine items according to Rule 17Ad-2 of the Act: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/turnaroundCompliant/nonCompliantData/numberMonthsNotCompliant" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'9(a)(ii)'" />
               <xsl:with-param name="Question" select="'Provide the number of written notices Registrant filed during the reporting period with the SEC and with its ARA that reported its noncompliance with turnaround time for routine items according to Rule 17Ad-2 of the Act: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/turnaroundCompliant/nonCompliantData/numberNoticeNonComplianceFiled" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'9'" />
               <xsl:with-param name="Question" select="'Are there any unsatisfied judgments or liens against registrant arising out of its performance of transfer agent functions for any security?'" />
               <xsl:with-param name="Test1" select="registrant/unsatisfiedJudgementsOrLiens/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrant/unsatisfiedJudgementsOrLiens/involved" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerClaimInfo">
               <xsl:with-param name="Number" select="'9(a)'" />
               <xsl:with-param name="Question" select="'If so, furnish complete information regarding each judgment or lien.'" />
               <xsl:with-param name="Details" select="registrant/unsatisfiedJudgementsOrLiens/unsatisfiedJudgementOrLiensDetails" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>

   <xsl:template name="Section10">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10'" />
               <xsl:with-param name="Question" select="'Applicant and Control Affiliate Disciplinary History:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="''" />
               <xsl:with-param name="Question" select="'The following definitions apply for purposes of answering this Question 10 '" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <table border="0" summary="Question 10 Definitions">
              <tr>
                <td class="FormText" valign="middle">Control affiliate</td>
                <td class="FormText">- An individual or firm that directly or indirectly controls, is under common control with, or is 
controlled by applicant. Included are any employees identified in 8(a), 8(b), 8(c) of this form as exercising control. Excluded are any employees who perform solely clerical, administrative support of 
similar functions, or who, regardless of title, perform no executive duties or have no senior policy making 
authority.</td>
              </tr>
              <tr>
                <td class="FormText">Investment or investment related</td>
                <td class="FormText">- Pertaining to securities, commodities, banking, insurance, or real estate (including, 
but not limited to, acting as or being associated with a broker-dealer, investment company, investment adviser, futures sponsor, bank, or savings and 
loan association).</td>
              </tr>
              <tr>
                <td class="FormText">Involved</td>
                <td class="FormText">- Doing an act of aiding, abetting, counseling, commanding, 
inducing, conspiring with or failing reasonably to supervise another in doing an act.</td>              
              </tr>
            </table>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10(a)'" />
               <xsl:with-param name="Question" select="'In the past ten years has the applicant or a control affiliate been convicted of or plead guilty or nolo contender (`no contest`) to:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(a)(1)'" />
               <xsl:with-param name="Question" select="'a felony or misdemeanor involving: investments or an investment-related business, fraud, false statements or omissions, wrongful taking of property, or bribery, forgery, counterfeiting or extortion?'" />
               <xsl:with-param name="Test1" select="felonyOrMisdemeanor/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="felonyOrMisdemeanor/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(a)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="felonyOrMisdemeanor/felonyOrMisdemeanorDetails" />
               <xsl:with-param name="Test" select="felonyOrMisdemeanor/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(a)(2)'" />
               <xsl:with-param name="Question" select="'any other felony?'" />
               <xsl:with-param name="Test1" select="otherFelony/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="otherFelony/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(a)(2)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="otherFelony/otherFelonyDetails" />
               <xsl:with-param name="Test" select="otherFelony/involved" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10(b)'" />
               <xsl:with-param name="Question" select="'Has any court in the past ten years:'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(b)(1)'" />
               <xsl:with-param name="Question" select="'enjoined the applicant or a control affiliate in connection with any investment-related activity?'" />
               <xsl:with-param name="Test1" select="enjoinedInvestmentRelatedActivity/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="enjoinedInvestmentRelatedActivity/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(b)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="enjoinedInvestmentRelatedActivity/enjoinedInvestmentRelatedActivityDetails" />
               <xsl:with-param name="Test" select="enjoinedInvestmentRelatedActivity/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(b)(2)'" />
               <xsl:with-param name="Question" select="'found that the applicant or a control affiliate was involved in a violation of investment-related statutes or regulations?'" />
               <xsl:with-param name="Test1" select="violationOfInvestmentRelatedRegulation/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="violationOfInvestmentRelatedRegulation/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(b)(2)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="violationOfInvestmentRelatedRegulation/violationOfInvestmentRelatedRegulationDetails" />
               <xsl:with-param name="Test" select="violationOfInvestmentRelatedRegulation/involved" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10(c)'" />
               <xsl:with-param name="Question" select="'Has the U.S. Securities and Exchange Commission or the Commodity Futures Trading Commission ever: '" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(c)(1)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have made a false statement or omission?'" />
               <xsl:with-param name="Test1" select="falseStatementOrOmission/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="falseStatementOrOmission/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(c)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="falseStatementOrOmission/falseStatementOrOmissionDetails" />
               <xsl:with-param name="Test" select="falseStatementOrOmission/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(c)(2)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have been involved in a violation of its regulations or statutes?'" />
               <xsl:with-param name="Test1" select="violationOfRegulations/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="violationOfRegulations/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(c)(2)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="violationOfRegulations/violationOfRegulationsDetails" />
               <xsl:with-param name="Test" select="violationOfRegulations/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(c)(3)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have been a cause of an investment-related business having its authorization to do business denied, suspended, revoked or restricted?'" />
               <xsl:with-param name="Test1" select="authorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="authorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(c)(3)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="authorizationDeniedOrSuspended/authorizationDeniedOrSuspendedDetails" />
               <xsl:with-param name="Test" select="authorizationDeniedOrSuspended/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(c)(4)'" />
               <xsl:with-param name="Question" select="'entered an order denying, suspending or revoking the applicant`s or a control affiliate`s registration or otherwise disciplined it by restricting its activities? '" />
               <xsl:with-param name="Test1" select="registrationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="registrationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(c)(4)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="registrationDeniedOrSuspended/registrationDeniedOrSuspendedDetails" />
               <xsl:with-param name="Test" select="registrationDeniedOrSuspended/involved" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10(d)'" />
               <xsl:with-param name="Question" select="'Has any other Federal regulatory agency or any state regulatory agency: '" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(1)'" />
               <xsl:with-param name="Question" select="'ever found the applicant or a control affiliate to have made a false statement or omission or to have been dishonest, unfair, or unethical?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrFalseStatementOrOmission/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrFalseStatementOrOmission/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrFalseStatementOrOmission/fsrFalseStatementOrOmissionDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrFalseStatementOrOmission/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(2)'" />
               <xsl:with-param name="Question" select="'ever found the applicant or a control affiliate to have been involved in a violation of investment-related regulations or statutes?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrViolationOfInvestmentRelatedRegulation/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrViolationOfInvestmentRelatedRegulation/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(2)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrViolationOfInvestmentRelatedRegulation/fsrViolationOfInvestmentRelatedRegulationDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrViolationOfInvestmentRelatedRegulation/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(3)'" />
               <xsl:with-param name="Question" select="'ever found the applicant or a control affiliate to have been a cause of an investment-related business having its authorization to do business denied, suspended, revoked, or restricted?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrAuthorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrAuthorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(3)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrAuthorizationDeniedOrSuspended/fsrAuthorizationDeniedOrSuspendedDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrAuthorizationDeniedOrSuspended/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(4)'" />
               <xsl:with-param name="Question" select="'in the past ten years entered an order against the applicant or a control affiliate in connection with investment-related activity?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrFoundOrderAgainstApplicant/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrFoundOrderAgainstApplicant/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(4)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrFoundOrderAgainstApplicant/fsrFoundOrderAgainstApplicantDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrFoundOrderAgainstApplicant/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(5)'" />
               <xsl:with-param name="Question" select="'ever denied, suspended, or revoked the applicant`s or a control affiliate`s registration or license, or prevented it from associating with an investment-related business, or otherwise disciplined it by restricting its activities?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrRegistrationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrRegistrationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(5)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrRegistrationDeniedOrSuspended/fsrRegistrationDeniedOrSuspendedDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrRegistrationDeniedOrSuspended/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(d)(6)'" />
               <xsl:with-param name="Question" select="'ever revoked or suspended the applicant`s or a control affiliate`s license as an attorney or accountant?'" />
               <xsl:with-param name="Test1" select="federalOrStateRegulatoryAgency/fsrRevokedSuspendedLicense/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="federalOrStateRegulatoryAgency/fsrRevokedSuspendedLicense/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(d)(6)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="federalOrStateRegulatoryAgency/fsrRevokedSuspendedLicense/fsrRevokedSuspendedLicenseDetails" />
               <xsl:with-param name="Test" select="federalOrStateRegulatoryAgency/fsrRevokedSuspendedLicense/involved" />
            </xsl:call-template>
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10(e)'" />
               <xsl:with-param name="Question" select="'Has any self-regulatory organization or commodities exchange ever: '" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(e)(1)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have made a false statement or omission?'" />
               <xsl:with-param name="Test1" select="selfRegulatoryAgency/sraFalseStatementOrOmission/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="selfRegulatoryAgency/sraFalseStatementOrOmission/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(e)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="selfRegulatoryAgency/sraFalseStatementOrOmission/sraFalseStatementOrOmissionDetails" />
               <xsl:with-param name="Test" select="selfRegulatoryAgency/sraFalseStatementOrOmission/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(e)(2)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have been involved in a violation of its rules?'" />
               <xsl:with-param name="Test1" select="selfRegulatoryAgency/sraViolationOfRules/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="selfRegulatoryAgency/sraViolationOfRules/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(e)(2)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="selfRegulatoryAgency/sraViolationOfRules/sraViolationOfRulesDetails" />
               <xsl:with-param name="Test" select="selfRegulatoryAgency/sraViolationOfRules/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(e)(3)'" />
               <xsl:with-param name="Question" select="'found the applicant or a control affiliate to have been the cause of an investment-related business losing its authorization to do business?'" />
               <xsl:with-param name="Test1" select="selfRegulatoryAgency/sraAuthorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="selfRegulatoryAgency/sraAuthorizationDeniedOrSuspended/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(e)(3)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="selfRegulatoryAgency/sraAuthorizationDeniedOrSuspended/sraAuthorizationDeniedOrSuspendedDetails" />
               <xsl:with-param name="Test" select="selfRegulatoryAgency/sraAuthorizationDeniedOrSuspended/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(e)(4)'" />
               <xsl:with-param name="Question" select="'disciplined the applicant or a control affiliate by expelling or suspending it from membership, by barring or suspending its association with other members, or by otherwise restricting its activities?'" />
               <xsl:with-param name="Test1" select="selfRegulatoryAgency/sraRevokedSuspendedLicense/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="selfRegulatoryAgency/sraRevokedSuspendedLicense/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(e)(4)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="selfRegulatoryAgency/sraRevokedSuspendedLicense/sraRevokedSuspendedLicenseDetails" />
               <xsl:with-param name="Test" select="selfRegulatoryAgency/sraRevokedSuspendedLicense/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(f)'" />
               <xsl:with-param name="Question" select="'Has any foreign government, court, regulatory agency, or exchange ever entered an order against the applicant or a control affiliate related to investments or fraud? '" />
               <xsl:with-param name="Test1" select="foreignAgency/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="foreignAgency/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(f)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="foreignAgency/foreignAgencyDetails" />
               <xsl:with-param name="Test" select="foreignAgency/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(g)'" />
               <xsl:with-param name="Question" select="'Is the applicant or a control affiliate now the subject of any proceeding that could result in a yes answer to questions 10(a) - 10(f)?'" />
               <xsl:with-param name="Test1" select="subjectOfProceedings/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="subjectOfProceedings/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(g)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="subjectOfProceedings/subjectOfProceedingsDetails" />
               <xsl:with-param name="Test" select="subjectOfProceedings/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(h)'" />
               <xsl:with-param name="Question" select="'Has a bonding company denied, paid out on, or revoked a bond for the applicant or a control affiliate?'" />
               <xsl:with-param name="Test1" select="revokedBond/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="revokedBond/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(h)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="revokedBond/revokedBondDetails" />
               <xsl:with-param name="Test" select="revokedBond/involved" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBFT">
               <xsl:with-param name="Number" select="'10(i)'" />
               <xsl:with-param name="Question" select="'Does the applicant or a control affiliate have any unsatisfied judgments or liens against it?'" />
               <xsl:with-param name="Test1" select="unsatisfiedJudgementsOrLiens/involved" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="unsatisfiedJudgementsOrLiens/involved" />
               <xsl:with-param name="Label2" select="'No'" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionClaimInfo">
               <xsl:with-param name="Number" select="'10(i)(1)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="Details" select="unsatisfiedJudgementsOrLiens/unsatisfiedJudgementOrLiensDetails" />
               <xsl:with-param name="Test" select="unsatisfiedJudgementsOrLiens/involved" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10'" />
               <xsl:with-param name="Question" select="'Number of open-end investment company securities purchases and redemptions (transactions) excluding dividend, interest and distribution postings, and address changes processed during the reporting period:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'10(a)'" />
               <xsl:with-param name="Question" select="'Total number of transactions processed: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/purchaseRedemptionPricingShares/total" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'10(b)'" />
               <xsl:with-param name="Question" select="'Number of transactions processed on a date other than date of receipt of order (as ofs): '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/securityHolderData/purchaseRedemptionPricingShares/totalOtherThanReceiptOrderDate" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'10'" />
               <xsl:with-param name="Question" select="'For each issue for which registrant acted as transfer agent and for any issues for which registrant assumed transfer agent functions since the last amendment to Form TA-1, furnish:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'10(a)'" />
               <xsl:with-param name="Question" select="'Is there a successor transfer agent?'" />
               <xsl:with-param name="Test1" select="tawDetails/tawSuccessors/successorTransferAgents" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="NotTest2" select="tawDetails/tawSuccessors/successorTransferAgents" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'10(b)'" />
               <xsl:with-param name="Question" select="'Name of successor transfer agents:'" />
               <xsl:with-param name="Answer" select="tawDetails/tawSuccessors/tawSuccessorDetails/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'10(c)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="AddressInfo" select="tawDetails/tawSuccessors/tawSuccessorDetails/tawSuccessorAddress" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer2RBs">
               <xsl:with-param name="Number" select="'10(d)'" />
               <xsl:with-param name="Question" select="'Is the successor transfer agent registered as a transfer agent pursuant to the Act?'" />
               <xsl:with-param name="Test1" select="tawDetails/tawSuccessors/tawSuccessorDetails/successorRegistered='true'" />
               <xsl:with-param name="Label1" select="'Yes'" />
               <xsl:with-param name="Test2" select="tawDetails/tawSuccessors/tawSuccessorDetails/successorRegistered='false'" />
               <xsl:with-param name="Label2" select="'No'" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>
   <xsl:template name="Section11">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
            <table border="0" width="100%" summary="Attention Notice">
              <tr>
                <th align="center" class="FormText">ATTENTION: INTENTIONAL MISSTATEMENTS OR OMISSIONS OF FACT CONSTITUTE FEDERAL CRIMINAL VIOLATIONS. See 18 U.S.C. 1001 and 15 U.S.C. 78ff(a)</th>
              </tr>
            </table>
            <table border="1" cellspacing="0" width="100%" summary="Description of Responsibility of Signatures">
              <tr>
                <th align="left" class="FormText">SIGNATURE:</th>
                <td class="FormText">The Registrant submitting this Form, and as required, the SEC supplement and Schedules A-D, And the executing official hereby represent that all the information contained herein is true, correct and complete.</td>
              </tr>
            </table>
            <xsl:call-template name="SignatureBlock">
               <xsl:with-param name="Number" select="'11'" />
               <xsl:with-param name="SignatureData" select="signatureData" />
            </xsl:call-template>
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'11(a)'" />
               <xsl:with-param name="Question" select="'During the reporting period, provide the date of all database searches conducted for lost securityholder accounts listed on the transfer agent`s master securityholder files, the number of lost securityholder accounts for which a database search has been conducted, and the number of lost securityholder accounts for which a different address has been obtained as a result of a database search:'" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:for-each select="serviceCompanyData/databaseSearch">
               <table border="1" cellspacing="0" cellpadding="10" summary="Database Searches">
                 <tr>
                    <th>
                       <xsl:call-template name="Question">
                          <xsl:with-param name="Number" select="'11(a)(i)'" />
                          <xsl:with-param name="Question" select="'Date of Database Search'" />
                          <xsl:with-param name="Breaks" select="1" />
                       </xsl:call-template>
                    </th>
                    <th>
                       <xsl:call-template name="Question">
                          <xsl:with-param name="Number" select="'11(a)(ii)'" />
                          <xsl:with-param name="Question" select="'Number of Lost Securityholder Accounts Submitted for Database Search'" />
                          <xsl:with-param name="Breaks" select="1" />
                       </xsl:call-template>
                    </th>
                    <th>
                       <xsl:call-template name="Question">
                          <xsl:with-param name="Number" select="'11(a)(iii)'" />
                          <xsl:with-param name="Question" select="'Addresses Obtained from Database Search'" />
                          <xsl:with-param name="Breaks" select="1" />
                       </xsl:call-template>
                    </th>
                 </tr>
                 <xsl:call-template name="Answer3ColTable2">
                    <xsl:with-param name="AnswerCol1" select="./databaseSearchDate" />
                    <xsl:with-param name="AnswerCol2" select="./numberLostAccountsSearched" />
                    <xsl:with-param name="AnswerCol3" select="./numberAddressesFromSearch" />
                    <xsl:with-param name="ADate1" select="1" />
                 </xsl:call-template>
               </table>
            </xsl:for-each>
            <xsl:call-template name="QuestionAnswerTable">
               <xsl:with-param name="Number" select="'11(b)'" />
               <xsl:with-param name="Question" select="'Number of lost securityholder accounts that have been remitted to states during the reporting period: '" />
               <xsl:with-param name="Answer" select="serviceCompanyData/numberLostAccountsRemittedToStates" />
               <xsl:with-param name="QWidth" select="'80%'" />
            </xsl:call-template>
            <hr />
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'11'" />
               <xsl:with-param name="Question" select="'For each issue for which registrant acted as transfer agent and for any issues for which registrant assumed transfer agent functions since the last amendment to Form TA-1, furnish: name(s) and address(es) of the person(s) who has or will have custody or possession of the books and records which the registrant maintained in connection with its performance of transfer agent functions. '" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'11(a)'" />
               <xsl:with-param name="Question" select="'Name of Custodian'" />
               <xsl:with-param name="Answer" select="tawDetails/tawCustodians/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'11(b)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="AddressInfo" select="tawDetails/tawCustodians/tawCustodianAddress" />
            </xsl:call-template>
         </xsl:when>
      </xsl:choose>
      <br />
   </xsl:template>

   <xsl:template name="Section12">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
            <table border="0" width="100%" summary="Description of Responsibility of Signatures">
              <tr>
                <th align="left" class="FormText">SIGNATURE:</th>
                <td class="FormText">The Registrant submitting this Form, and the person signing the Form, hereby represent that all the information contained in the Form is true, correct, and complete.</td>
              </tr>
            </table>
            <xsl:call-template name="SignatureBlock">
               <xsl:with-param name="Number" select="'12'" />
               <xsl:with-param name="SignatureData" select="signatureData" />
            </xsl:call-template>
            <br />
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <xsl:call-template name="Question">
               <xsl:with-param name="Number" select="'12'" />
               <xsl:with-param name="Question" select="'Furnish the name(s) and address(es), if different from Item 11, where such books and records will be located. '" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="QuestionAnswer">
               <xsl:with-param name="Number" select="'12(a)'" />
               <xsl:with-param name="Question" select="'Name of Custodian'" />
               <xsl:with-param name="Answer" select="tawDetails/tawLocations/entityName" />
               <xsl:with-param name="Breaks" select="1" />
            </xsl:call-template>
            <xsl:call-template name="AddressBlockI">
               <xsl:with-param name="Number" select="'12(b)'" />
               <xsl:with-param name="Question" select="''" />
               <xsl:with-param name="AddressInfo" select="tawDetails/tawLocations/tawLocationAddress" />
            </xsl:call-template>
            <br />
         </xsl:when>
     </xsl:choose>

   </xsl:template>

   <xsl:template name="Section13">
      <xsl:choose>
         <xsl:when test="starts-with(submissionType,'TA-1')">
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-2')">
         </xsl:when>
         <xsl:when test="starts-with(submissionType,'TA-W')">
            <table border="0" width="100%" summary="Description of Responsibility of Signatures">
              <tr>
                <th align="left" valign="top" class="FormText">SIGNATURE:</th>
                <td class="FormText">The registrant submitting this Form and its attachments and the person executing it represent that it and all materials filed in connection with it contain a true, correct and complete statement of all required information. Registrant also consents to make the books and records it is required to preserve by Rules 17Ad-6 and 17Ad-7 under the Securities Exchange Act of 1934 (17 CFR 240.17Ad-6 and 240.17Ad-7) available for examination by authorized representatives of the Commission during the period the rules require registrant to preserve such books and records and authorizes the person having custody of such books and records to make them available to such representatives.</td>
              </tr>
            </table>
            <xsl:call-template name="SignatureBlock">
               <xsl:with-param name="Number" select="'13'" />
               <xsl:with-param name="SignatureData" select="signatureData" />
            </xsl:call-template>
            <br />
         </xsl:when>
      </xsl:choose>
   </xsl:template>
   
</xsl:stylesheet>
